@@ -2,26 +2,20 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
+/* globals sortCalendarArray, gDataMigrator, calendarUpdateNewItemsCommand, currentView */
+
 /* exported promptDeleteCalendar, loadCalendarManager, unloadCalendarManager,
- *         calendarListTooltipShowing, calendarListSetupContextMenu,
- *         ensureCalendarVisible, toggleCalendarVisible, showAllCalendars,
- *         showOnlyCalendar, calendarOfflineManager, openLocalCalendar
+ *   calendarListTooltipShowing, calendarListSetupContextMenu,
+ *   ensureCalendarVisible, toggleCalendarVisible, showAllCalendars,
+ *   showOnlyCalendar, calendarOfflineManager, openLocalCalendar,
  */
 
-/* import-globals-from calendar-migration.js */
-/* import-globals-from calendar-command-controller.js */
-/* import-globals-from calendar-ui-utils.js */
-
-var { cal } = ChromeUtils.import("resource:///modules/calendar/calUtils.jsm");
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
-// Temporary bundle for 78 to get the "Enable" string from the addons.properties file.
-var bundle;
+var { cal } = ChromeUtils.importESModule("resource:///modules/calendar/calUtils.sys.mjs");
 
 /**
  * Get this window's currently selected calendar.
  *
- * @return      The currently selected calendar.
+ * @returns The currently selected calendar.
  */
 function getSelectedCalendar() {
   return cal.view.getCompositeCalendar(window).defaultCalendar;
@@ -35,43 +29,40 @@ function getSelectedCalendar() {
  * @param aCalendar     The calendar to delete.
  */
 function promptDeleteCalendar(aCalendar) {
-  const nIPS = Ci.nsIPromptService;
-  const cICM = Ci.calICalendarManager;
-
-  let calMgr = cal.getCalendarManager();
-  let calendars = calMgr.getCalendars();
+  const calendars = cal.manager.getCalendars();
   if (calendars.length <= 1) {
     // If this is the last calendar, don't delete it.
     return;
   }
 
-  let modes = new Set(aCalendar.getProperty("capabilities.removeModes") || ["unsubscribe"]);
-  let title = cal.l10n.getCalString("removeCalendarTitle");
+  const modes = new Set(aCalendar.getProperty("capabilities.removeModes") || ["unsubscribe"]);
+  const title = cal.l10n.getCalString("removeCalendarTitle");
 
   let textKey, b0text, b2text;
   let removeFlags = 0;
   let promptFlags =
-    nIPS.BUTTON_POS_0 * nIPS.BUTTON_TITLE_IS_STRING + nIPS.BUTTON_POS_1 * nIPS.BUTTON_TITLE_CANCEL;
+    Ci.nsIPromptService.BUTTON_POS_0 * Ci.nsIPromptService.BUTTON_TITLE_IS_STRING +
+    Ci.nsIPromptService.BUTTON_POS_1 * Ci.nsIPromptService.BUTTON_TITLE_CANCEL;
 
   if (modes.has("delete") && !modes.has("unsubscribe")) {
     textKey = "removeCalendarMessageDelete";
-    promptFlags += nIPS.BUTTON_DELAY_ENABLE;
+    promptFlags += Ci.nsIPromptService.BUTTON_DELAY_ENABLE;
     b0text = cal.l10n.getCalString("removeCalendarButtonDelete");
   } else if (modes.has("delete")) {
     textKey = "removeCalendarMessageDeleteOrUnsubscribe";
-    promptFlags += nIPS.BUTTON_POS_2 * nIPS.BUTTON_TITLE_IS_STRING;
+    promptFlags += Ci.nsIPromptService.BUTTON_POS_2 * Ci.nsIPromptService.BUTTON_TITLE_IS_STRING;
     b0text = cal.l10n.getCalString("removeCalendarButtonUnsubscribe");
     b2text = cal.l10n.getCalString("removeCalendarButtonDelete");
   } else if (modes.has("unsubscribe")) {
     textKey = "removeCalendarMessageUnsubscribe";
-    removeFlags |= cICM.REMOVE_NO_DELETE;
+    removeFlags |= Ci.calICalendarManager.REMOVE_NO_DELETE;
     b0text = cal.l10n.getCalString("removeCalendarButtonUnsubscribe");
   } else {
     return;
   }
 
-  let text = cal.l10n.getCalString(textKey, [aCalendar.name]);
-  let res = Services.prompt.confirmEx(
+  const text = cal.l10n.getCalString(textKey, [aCalendar.name]);
+  const res = Services.prompt.confirmEx(
     window,
     title,
     text,
@@ -88,10 +79,10 @@ function promptDeleteCalendar(aCalendar) {
     if (textKey == "removeCalendarMessageDeleteOrUnsubscribe" && res == 0) {
       // Both unsubscribing and deleting is possible, but unsubscribing was
       // requested. Make sure no delete is executed.
-      removeFlags |= cICM.REMOVE_NO_DELETE;
+      removeFlags |= Ci.calICalendarManager.REMOVE_NO_DELETE;
     }
 
-    calMgr.removeCalendar(aCalendar, removeFlags);
+    cal.manager.removeCalendar(aCalendar, removeFlags);
   }
 }
 
@@ -101,16 +92,16 @@ function promptDeleteCalendar(aCalendar) {
  *
  * @param {MozRichlistitem} item - The calendar item to update.
  */
-function updatedCalendarReadStatus(item) {
-  let calendarName = item.querySelector(".calendar-name").value;
-  let image = item.querySelector("img.calendar-readstatus");
+function updateCalendarStatusIndicators(item) {
+  const calendarName = item.querySelector(".calendar-name").textContent;
+  const image = item.querySelector("img.calendar-readstatus");
   if (item.hasAttribute("calendar-readfailed")) {
-    image.setAttribute("src", "chrome://calendar/skin/shared/icons/warn.svg");
-    let tooltip = cal.l10n.getCalString("tooltipCalendarDisabled", [calendarName]);
+    image.setAttribute("src", "chrome://messenger/skin/icons/new/compact/warning.svg");
+    const tooltip = cal.l10n.getCalString("tooltipCalendarDisabled", [calendarName]);
     image.setAttribute("title", tooltip);
   } else if (item.hasAttribute("calendar-readonly")) {
-    image.setAttribute("src", "chrome://calendar/skin/shared/icons/locked.svg");
-    let tooltip = cal.l10n.getCalString("tooltipCalendarReadOnly", [calendarName]);
+    image.setAttribute("src", "chrome://messenger/skin/icons/new/compact/lock.svg");
+    const tooltip = cal.l10n.getCalString("tooltipCalendarReadOnly", [calendarName]);
     image.setAttribute("title", tooltip);
   } else {
     image.removeAttribute("src");
@@ -121,21 +112,21 @@ function updatedCalendarReadStatus(item) {
 /**
  * Called to initialize the calendar manager for a window.
  */
-function loadCalendarManager() {
-  let calendarList = document.getElementById("calendar-list");
+async function loadCalendarManager() {
+  const calendarList = document.getElementById("calendar-list");
 
   // Set up the composite calendar in the calendar list widget.
-  let compositeCalendar = cal.view.getCompositeCalendar(window);
+  const compositeCalendar = cal.view.getCompositeCalendar(window);
 
   // Initialize our composite observer
   compositeCalendar.addObserver(compositeObserver);
 
   // Create the home calendar if no calendar exists.
-  let calendars = cal.getCalendarManager().getCalendars();
+  const calendars = cal.manager.getCalendars();
   if (calendars.length) {
     // migration code to make sure calendars, which do not support caching have cache enabled
     // required to further clean up on top of bug 1182264
-    for (let calendar of calendars) {
+    for (const calendar of calendars) {
       if (
         calendar.getProperty("cache.supported") === false &&
         calendar.getProperty("cache.enabled") === true
@@ -147,29 +138,39 @@ function loadCalendarManager() {
     initHomeCalendar();
   }
 
-  let calendarManager = cal.getCalendarManager();
-
-  for (let calendar of sortCalendarArray(calendarManager.getCalendars())) {
+  for (const calendar of sortCalendarArray(cal.manager.getCalendars())) {
     addCalendarItem(calendar);
   }
 
-  reportCalendars();
-
   function addCalendarItem(calendar) {
-    let item = document.createXULElement("richlistitem");
+    const item = document
+      .getElementById("calendar-list-item")
+      .content.firstElementChild.cloneNode(true);
+    const forceDisabled = calendar.getProperty("force-disabled");
+    item.id = `calendar-listitem-${calendar.id}`;
     item.searchLabel = calendar.name;
+    item.setAttribute("aria-label", calendar.name);
     item.setAttribute("calendar-id", calendar.id);
     item.toggleAttribute("calendar-disabled", calendar.getProperty("disabled"));
     item.toggleAttribute(
       "calendar-readfailed",
-      !Components.isSuccessCode(calendar.getProperty("currentStatus"))
+      !Components.isSuccessCode(calendar.getProperty("currentStatus")) || forceDisabled
     );
     item.toggleAttribute("calendar-readonly", calendar.readOnly);
+    item.toggleAttribute("calendar-muted", calendar.getProperty("suppressAlarms"));
+    document.l10n.setAttributes(
+      item.querySelector(".calendar-mute-status"),
+      "calendar-no-reminders-tooltip",
+      { calendarName: calendar.name }
+    );
+    document.l10n.setAttributes(
+      item.querySelector(".calendar-more-button"),
+      "calendar-list-item-context-button",
+      { calendarName: calendar.name }
+    );
 
-    let cssSafeId = cal.view.formatStringForCSSRule(calendar.id);
-    let colorMarker = document.createElement("div");
-    colorMarker.classList.add("calendar-color");
-    item.appendChild(colorMarker);
+    const cssSafeId = cal.view.formatStringForCSSRule(calendar.id);
+    const colorMarker = item.querySelector(".calendar-color");
     if (calendar.getProperty("disabled")) {
       colorMarker.style.backgroundColor = "transparent";
       colorMarker.style.border = `2px solid var(--calendar-${cssSafeId}-backcolor)`;
@@ -177,49 +178,35 @@ function loadCalendarManager() {
       colorMarker.style.backgroundColor = `var(--calendar-${cssSafeId}-backcolor)`;
     }
 
-    let label = document.createXULElement("label");
-    label.setAttribute("crop", "end");
-    label.classList.add("calendar-name");
-    label.value = calendar.name;
-    item.appendChild(label);
+    const label = item.querySelector(".calendar-name");
+    label.textContent = calendar.name;
 
-    let image = document.createElement("img");
-    image.classList.add("calendar-readstatus");
-    item.appendChild(image);
-    updatedCalendarReadStatus(item);
+    updateCalendarStatusIndicators(item);
 
-    let enable = document.createXULElement("button");
-    if (calendar.getProperty("disabled")) {
-      if (!bundle) {
-        bundle = Services.strings.createBundle("chrome://messenger/locale/addons.properties");
-      }
-      enable.label = bundle.GetStringFromName("webextPerms.sideloadEnable.label");
-    }
-    enable.classList.add("calendar-enable-button");
-    enable.hidden = !calendar.getProperty("disabled");
-    item.appendChild(enable);
+    const enable = item.querySelector(".calendar-enable-button");
+    document.l10n.setAttributes(enable, "calendar-enable-button");
 
-    let displayedCheckbox = document.createXULElement("checkbox");
-    displayedCheckbox.classList.add("calendar-displayed");
+    enable.hidden = forceDisabled || !calendar.getProperty("disabled");
+
+    const displayedCheckbox = item.querySelector(".calendar-displayed");
     displayedCheckbox.checked = calendar.getProperty("calendar-main-in-composite");
     displayedCheckbox.hidden = calendar.getProperty("disabled");
-    let stringName = cal.view.getCompositeCalendar(window).getCalendarById(calendar.id)
+    const stringName = cal.view.getCompositeCalendar(window).getCalendarById(calendar.id)
       ? "hideCalendar"
       : "showCalendar";
-    displayedCheckbox.setAttribute(
-      "tooltiptext",
-      cal.l10n.getCalString(stringName, [calendar.name])
-    );
-    item.appendChild(displayedCheckbox);
+    displayedCheckbox.setAttribute("title", cal.l10n.getCalString(stringName, [calendar.name]));
 
     calendarList.appendChild(item);
     if (calendar.getProperty("calendar-main-default")) {
-      calendarList.selectedItem = item;
+      // The list needs to handle the addition of the row before we can select it.
+      setTimeout(() => {
+        calendarList.selectedIndex = calendarList.rows.indexOf(item);
+      });
     }
   }
 
   function saveSortOrder() {
-    let order = [...calendarList.children].map(i => i.getAttribute("calendar-id"));
+    const order = [...calendarList.children].map(i => i.getAttribute("calendar-id"));
     Services.prefs.setStringPref("calendar.list.sortOrder", order.join(" "));
     try {
       Services.prefs.savePrefFile(null);
@@ -230,21 +217,21 @@ function loadCalendarManager() {
 
   calendarList.addEventListener("click", event => {
     if (event.target.matches(".calendar-enable-button")) {
-      let calendar = calendarManager.getCalendarById(
-        event.target.closest("richlistitem").getAttribute("calendar-id")
+      const calendar = cal.manager.getCalendarById(
+        event.target.closest("li").getAttribute("calendar-id")
       );
       calendar.setProperty("disabled", false);
       calendarList.focus();
       return;
     }
 
-    if (!event.target.matches("checkbox.calendar-displayed")) {
+    if (!event.target.matches(".calendar-displayed")) {
       return;
     }
 
-    let item = event.target.closest("richlistitem");
-    let calendarId = item.getAttribute("calendar-id");
-    let calendar = calendarManager.getCalendarById(calendarId);
+    const item = event.target.closest("li");
+    const calendarId = item.getAttribute("calendar-id");
+    const calendar = cal.manager.getCalendarById(calendarId);
 
     if (event.target.checked) {
       compositeCalendar.addCalendar(calendar);
@@ -252,118 +239,38 @@ function loadCalendarManager() {
       compositeCalendar.removeCalendar(calendar);
     }
 
-    let stringName = event.target.checked ? "hideCalendar" : "showCalendar";
-    event.target.setAttribute("tooltiptext", cal.l10n.getCalString(stringName, [calendar.name]));
+    const stringName = event.target.checked ? "hideCalendar" : "showCalendar";
+    event.target.setAttribute("title", cal.l10n.getCalString(stringName, [calendar.name]));
 
     calendarList.focus();
   });
   calendarList.addEventListener("dblclick", event => {
     if (
-      event.target.matches("checkbox.calendar-displayed") ||
+      event.target.matches(".calendar-displayed") ||
       event.target.matches(".calendar-enable-button")
     ) {
       return;
     }
 
-    let item = event.target.closest("richlistitem");
+    const item = event.target.closest("li");
     if (!item) {
       // Click on an empty part of the richlistbox.
       cal.window.openCalendarWizard(window);
       return;
     }
 
-    let calendarId = item.getAttribute("calendar-id");
-    let calendar = calendarManager.getCalendarById(calendarId);
-    cal.window.openCalendarProperties(window, calendar);
+    const calendarId = item.getAttribute("calendar-id");
+    const calendar = cal.manager.getCalendarById(calendarId);
+    cal.window.openCalendarProperties(window, { calendar });
   });
-  calendarList.addEventListener("dragstart", event => {
-    let item = event.target.closest("richlistitem");
-    if (!item) {
-      return;
-    }
-
-    let calendarId = item.getAttribute("calendar-id");
-    event.dataTransfer.setData("application/x-moz-calendarid", calendarId);
-    event.dataTransfer.effectAllowed = "move";
-  });
-  calendarList.addEventListener("dragenter", event => {
-    if (
-      event.target == calendarList &&
-      event.dataTransfer.types.includes("application/x-moz-calendarid")
-    ) {
-      event.dataTransfer.dropEffect = "move";
-      event.preventDefault();
-    }
-  });
-  calendarList.addEventListener("dragover", event => {
-    event.preventDefault();
-
-    let existing = calendarList.querySelector("[drop-on]");
-    if (existing) {
-      existing.removeAttribute("drop-on");
-    }
-
-    if (event.target == calendarList) {
-      calendarList.lastElementChild.setAttribute("drop-on", "bottom");
-      return;
-    }
-
-    let item = event.target.closest("richlistitem");
-    if (item) {
-      // If we're dragging/dropping in bottom half of attachmentitem,
-      // adjust target to target.nextElementSibling (to show dropmarker above that).
-      if ((event.screenY - item.screenY) / item.getBoundingClientRect().height >= 0.5) {
-        item = item.nextElementSibling;
-      }
-      if (item) {
-        item.setAttribute("drop-on", "top");
-      } else {
-        calendarList.lastElementChild.setAttribute("drop-on", "bottom");
-      }
-    }
-  });
-  calendarList.addEventListener("dragexit", event => {
-    if (event.target != calendarList) {
-      return;
-    }
-
-    let existing = calendarList.querySelector("[drop-on]");
-    if (existing) {
-      existing.removeAttribute("drop-on");
-    }
-  });
-  calendarList.addEventListener("dragend", event => {
-    let existing = calendarList.querySelector("[drop-on]");
-    if (existing) {
-      existing.removeAttribute("drop-on");
-    }
-  });
-  calendarList.addEventListener("drop", event => {
-    let existing = calendarList.querySelector("[drop-on]");
-    let position = existing.getAttribute("drop-on");
-    if (!existing) {
-      return;
-    }
-
-    existing.removeAttribute("drop-on");
-
-    let calendarId = event.dataTransfer.getData("application/x-moz-calendarid");
-    if (calendarId == existing.getAttribute("calendar-id")) {
-      return;
-    }
-
-    let item = calendarList.getElementsByAttribute("calendar-id", calendarId)[0];
-    if (position == "bottom") {
-      existing = null;
-    }
-    calendarList.insertBefore(item, existing);
-
+  calendarList.addEventListener("ordered", event => {
     saveSortOrder();
+    calendarList.selectedIndex = calendarList.rows.indexOf(event.detail);
   });
   calendarList.addEventListener("keypress", event => {
-    let item = calendarList.selectedItem;
-    let calendarId = item.getAttribute("calendar-id");
-    let calendar = calendarManager.getCalendarById(calendarId);
+    const item = calendarList.rows[calendarList.selectedIndex];
+    const calendarId = item.getAttribute("calendar-id");
+    const calendar = cal.manager.getCalendarById(calendarId);
 
     switch (event.key) {
       case "Delete":
@@ -375,20 +282,20 @@ function loadCalendarManager() {
         } else {
           compositeCalendar.addCalendar(calendar);
         }
-        let stringName = item.querySelector(".calendar-displayed").checked
+        const stringName = item.querySelector(".calendar-displayed").checked
           ? "hideCalendar"
           : "showCalendar";
         item
           .querySelector(".calendar-displayed")
-          .setAttribute("tooltiptext", cal.l10n.getCalString(stringName, [calendar.name]));
+          .setAttribute("title", cal.l10n.getCalString(stringName, [calendar.name]));
         break;
       }
     }
   });
   calendarList.addEventListener("select", event => {
-    let item = calendarList.selectedItem;
-    let calendarId = item.getAttribute("calendar-id");
-    let calendar = calendarManager.getCalendarById(calendarId);
+    const item = calendarList.rows[calendarList.selectedIndex];
+    const calendarId = item.getAttribute("calendar-id");
+    const calendar = cal.manager.getCalendarById(calendarId);
 
     compositeCalendar.defaultCalendar = calendar;
   });
@@ -405,28 +312,21 @@ function loadCalendarManager() {
     onError(calendar, errNo, message) {},
 
     onPropertyChanged(calendar, name, value, oldValue) {
-      let item = calendarList.getElementsByAttribute("calendar-id", calendar.id)[0];
+      const item = calendarList.getElementsByAttribute("calendar-id", calendar.id)[0];
       if (!item) {
         return;
       }
 
       switch (name) {
-        case "disabled":
+        case "disabled": {
           item.toggleAttribute("calendar-disabled", value);
           item.querySelector(".calendar-displayed").hidden = value;
           // Update the "ENABLE" button.
-          let enableButton = item.querySelector(".calendar-enable-button");
+          const enableButton = item.querySelector(".calendar-enable-button");
           enableButton.hidden = !value;
-          // We need to set the string if the button was hidden on creation.
-          if (value && enableButton.label == "") {
-            if (!bundle) {
-              bundle = Services.strings.createBundle("chrome://messenger/locale/addons.properties");
-            }
-            enableButton.label = bundle.GetStringFromName("webextPerms.sideloadEnable.label");
-          }
           // Update the color preview.
-          let cssSafeId = cal.view.formatStringForCSSRule(calendar.id);
-          let colorMarker = item.querySelector(".calendar-color");
+          const cssSafeId = cal.view.formatStringForCSSRule(calendar.id);
+          const colorMarker = item.querySelector(".calendar-color");
           colorMarker.style.backgroundColor = value
             ? "transparent"
             : `var(--calendar-${cssSafeId}-backcolor)`;
@@ -434,9 +334,10 @@ function loadCalendarManager() {
             ? `2px solid var(--calendar-${cssSafeId}-backcolor)`
             : "none";
           break;
+        }
         case "calendar-main-default":
           if (value) {
-            calendarList.selectedItem = item;
+            calendarList.selectedIndex = calendarList.rows.indexOf(item);
           }
           break;
         case "calendar-main-in-composite":
@@ -444,15 +345,22 @@ function loadCalendarManager() {
           break;
         case "name":
           item.searchLabel = calendar.name;
-          item.querySelector(".calendar-name").value = value;
+          item.querySelector(".calendar-name").textContent = value;
           break;
         case "currentStatus":
-          item.toggleAttribute("calendar-readfailed", !Components.isSuccessCode(value));
-          updatedCalendarReadStatus(item);
+        case "force-disabled":
+          item.toggleAttribute(
+            "calendar-readfailed",
+            name == "currentStatus" ? !Components.isSuccessCode(value) : value
+          );
+          updateCalendarStatusIndicators(item);
           break;
         case "readOnly":
           item.toggleAttribute("calendar-readonly", value);
-          updatedCalendarReadStatus(item);
+          updateCalendarStatusIndicators(item);
+          break;
+        case "suppressAlarms":
+          item.toggleAttribute("calendar-muted", value);
           break;
       }
     },
@@ -463,7 +371,7 @@ function loadCalendarManager() {
       this.onPropertyChanged(calendar, name, null, null);
     },
   };
-  calendarManager.addCalendarObserver(calendarList._calendarObserver);
+  cal.manager.addCalendarObserver(calendarList._calendarObserver);
 
   calendarList._calendarManagerObserver = {
     QueryInterface: ChromeUtils.generateQI(["calICalendarManagerObserver"]),
@@ -473,53 +381,26 @@ function loadCalendarManager() {
       saveSortOrder();
     },
     onCalendarUnregistering(calendar) {
-      let item = calendarList.getElementsByAttribute("calendar-id", calendar.id)[0];
+      const item = calendarList.getElementsByAttribute("calendar-id", calendar.id)[0];
       item.remove();
       saveSortOrder();
     },
     onCalendarDeleting(calendar) {},
   };
-  calendarManager.addObserver(calendarList._calendarManagerObserver);
-}
-
-/**
- * A telemetry probe to report calendar count and read only calendar count.
- */
-function reportCalendars() {
-  let telemetryReport = {};
-
-  for (let calendar of cal.getCalendarManager().getCalendars()) {
-    if (!telemetryReport[calendar.type]) {
-      telemetryReport[calendar.type] = { count: 0, readOnlyCount: 0 };
-    }
-    telemetryReport[calendar.type].count++;
-    if (calendar.readOnly) {
-      telemetryReport[calendar.type].readOnlyCount++;
-    }
-  }
-
-  for (let [type, { count, readOnlyCount }] of Object.entries(telemetryReport)) {
-    Services.telemetry.keyedScalarSet("tb.calendar.calendar_count", type.toLowerCase(), count);
-    Services.telemetry.keyedScalarSet(
-      "tb.calendar.read_only_calendar_count",
-      type.toLowerCase(),
-      readOnlyCount
-    );
-  }
+  cal.manager.addObserver(calendarList._calendarManagerObserver);
 }
 
 /**
  * Creates the initial "Home" calendar if no calendar exists.
  */
 function initHomeCalendar() {
-  let calMgr = cal.getCalendarManager();
-  let composite = cal.view.getCompositeCalendar(window);
-  let url = Services.io.newURI("moz-storage-calendar://");
-  let homeCalendar = calMgr.createCalendar("storage", url);
+  const composite = cal.view.getCompositeCalendar(window);
+  const url = Services.io.newURI("moz-storage-calendar://");
+  const homeCalendar = cal.manager.createCalendar("storage", url);
   homeCalendar.name = cal.l10n.getCalString("homeCalendarName");
   homeCalendar.setProperty("disabled", true);
 
-  calMgr.registerCalendar(homeCalendar);
+  cal.manager.registerCalendar(homeCalendar);
   Services.prefs.setStringPref("calendar.list.sortOrder", homeCalendar.id);
   composite.addCalendar(homeCalendar);
 
@@ -529,7 +410,7 @@ function initHomeCalendar() {
     try {
       gDataMigrator.checkAndMigrate();
     } catch (e) {
-      Cu.reportError("Migrator error: " + e);
+      console.error("Migrator error: " + e);
     }
   }
 
@@ -540,61 +421,79 @@ function initHomeCalendar() {
  * Called to clean up the calendar manager for a window.
  */
 function unloadCalendarManager() {
-  let compositeCalendar = cal.view.getCompositeCalendar(window);
+  const compositeCalendar = cal.view.getCompositeCalendar(window);
   compositeCalendar.setStatusObserver(null, null);
   compositeCalendar.removeObserver(compositeObserver);
 
-  let calendarList = document.getElementById("calendar-list");
-  let calendarManager = cal.getCalendarManager();
-  calendarManager.removeCalendarObserver(calendarList._calendarObserver);
-  calendarManager.removeObserver(calendarList._calendarManagerObserver);
+  const calendarList = document.getElementById("calendar-list");
+  cal.manager.removeCalendarObserver(calendarList._calendarObserver);
+  cal.manager.removeObserver(calendarList._calendarManagerObserver);
 }
 
 /**
  * A handler called to set up the context menu on the calendar list.
  *
- * @param event         The DOM event that caused the context menu to open.
- * @return              Returns true if the context menu should be shown.
+ * @param {Event} event - The click DOMEvent.
  */
+
 function calendarListSetupContextMenu(event) {
   let calendar;
-  let composite = cal.view.getCompositeCalendar(window);
+  const composite = cal.view.getCompositeCalendar(window);
 
-  if (event.target.triggerNode.matches("checkbox.calendar-displayed")) {
+  if (event.target.matches(".calendar-displayed")) {
     return;
   }
 
-  let item = event.target.triggerNode.closest("richlistitem");
+  const item = event.target.closest("li");
   if (item) {
-    let calendarId = item.getAttribute("calendar-id");
-    calendar = cal.getCalendarManager().getCalendarById(calendarId);
+    const calendarList = document.getElementById("calendar-list");
+    calendarList.selectedIndex = calendarList.rows.indexOf(item);
+    const calendarId = item.getAttribute("calendar-id");
+    calendar = cal.manager.getCalendarById(calendarId);
   }
 
   document.getElementById("list-calendars-context-menu").contextCalendar = calendar;
 
+  for (const elem of document.querySelectorAll("#list-calendars-context-menu .needs-calendar")) {
+    elem.hidden = !calendar;
+  }
   if (calendar) {
-    let stringName = composite.getCalendarById(calendar.id) ? "hideCalendar" : "showCalendar";
-    document.getElementById(
-      "list-calendars-context-togglevisible"
-    ).label = cal.l10n.getCalString(stringName, [calendar.name]);
-    let accessKey = document
+    const stringName = composite.getCalendarById(calendar.id) ? "hideCalendar" : "showCalendar";
+    document.getElementById("list-calendars-context-togglevisible").label = cal.l10n.getCalString(
+      stringName,
+      [calendar.name]
+    );
+    const accessKey = document
       .getElementById("list-calendars-context-togglevisible")
       .getAttribute(composite.getCalendarById(calendar.id) ? "accesskeyhide" : "accesskeyshow");
     document.getElementById("list-calendars-context-togglevisible").accessKey = accessKey;
-    document.getElementById(
-      "list-calendars-context-showonly"
-    ).label = cal.l10n.getCalString("showOnlyCalendar", [calendar.name]);
+    document.getElementById("list-calendars-context-showonly").label = cal.l10n.getCalString(
+      "showOnlyCalendar",
+      [calendar.name]
+    );
     setupDeleteMenuitem("list-calendars-context-delete", calendar);
-    for (let elem of event.target.querySelectorAll(".needs-calendar")) {
-      elem.removeAttribute("collapsed");
-    }
-  } else {
-    for (let elem of event.target.querySelectorAll(".needs-calendar")) {
-      elem.setAttribute("collapsed", "true");
-    }
+    document.getElementById("list-calendar-context-reload").hidden = !calendar.canRefresh;
+    document.getElementById("list-calendars-context-reload-menuseparator").hidden =
+      !calendar.canRefresh;
   }
 }
 
+/**
+ * Trigger the opening of the calendar list item context menu.
+ *
+ * @param {Event} event - The click DOMEvent.
+ */
+function openCalendarListItemContext(event) {
+  calendarListSetupContextMenu(event);
+  const popUpCalListMenu = document.getElementById("list-calendars-context-menu");
+  if (event.type == "contextmenu" && event.button == 2) {
+    // This is a right-click. Open where it happened.
+    popUpCalListMenu.openPopupAtScreen(event.screenX, event.screenY, true);
+    return;
+  }
+  popUpCalListMenu.openPopup(event.target, "after_start", 0, 0, true);
+}
+
 /**
  * Changes the "delete calendar" menuitem to have the right label based on the
  * removeModes. The menuitem must have the attributes "labelremove",
@@ -603,8 +502,8 @@ function calendarListSetupContextMenu(event) {
  * @param aDeleteId     The id of the menuitem to delete the calendar
  */
 function setupDeleteMenuitem(aDeleteId, aCalendar) {
-  let calendar = aCalendar === undefined ? getSelectedCalendar() : aCalendar;
-  let modes = new Set(
+  const calendar = aCalendar === undefined ? getSelectedCalendar() : aCalendar;
+  const modes = new Set(
     calendar ? calendar.getProperty("capabilities.removeModes") || ["unsubscribe"] : []
   );
 
@@ -615,7 +514,7 @@ function setupDeleteMenuitem(aDeleteId, aCalendar) {
     type = "unsubscribe";
   }
 
-  let deleteItem = document.getElementById(aDeleteId);
+  const deleteItem = document.getElementById(aDeleteId);
   // Dynamically set labelremove, labeldelete, labelunsubscribe
   deleteItem.label = deleteItem.getAttribute("label" + type);
   // Dynamically set accesskeyremove, accesskeydelete, accesskeyunsubscribe
@@ -632,9 +531,9 @@ function ensureCalendarVisible(aCalendar) {
   // If the main window has been closed this function may still be called,
   // like when an event/task window is still open and the user clicks 'save',
   // thus we have the extra checks.
-  let calendarList = document.getElementById("calendar-list");
+  const calendarList = document.getElementById("calendar-list");
   if (calendarList) {
-    let compositeCalendar = cal.view.getCompositeCalendar(window);
+    const compositeCalendar = cal.view.getCompositeCalendar(window);
     compositeCalendar.addCalendar(aCalendar);
   }
 }
@@ -645,7 +544,7 @@ function ensureCalendarVisible(aCalendar) {
  * @param aCalendar   The calendar to show or hide
  */
 function toggleCalendarVisible(aCalendar) {
-  let composite = cal.view.getCompositeCalendar(window);
+  const composite = cal.view.getCompositeCalendar(window);
   if (composite.getCalendarById(aCalendar.id)) {
     composite.removeCalendar(aCalendar);
   } else {
@@ -657,11 +556,11 @@ function toggleCalendarVisible(aCalendar) {
  * Shows all hidden calendars.
  */
 function showAllCalendars() {
-  let composite = cal.view.getCompositeCalendar(window);
-  let cals = cal.getCalendarManager().getCalendars();
+  const composite = cal.view.getCompositeCalendar(window);
+  const cals = cal.manager.getCalendars();
 
   composite.startBatch();
-  for (let calendar of cals) {
+  for (const calendar of cals) {
     if (!composite.getCalendarById(calendar.id)) {
       composite.addCalendar(calendar);
     }
@@ -675,11 +574,11 @@ function showAllCalendars() {
  * @param aCalendar   The calendar to show as the only visible calendar
  */
 function showOnlyCalendar(aCalendar) {
-  let composite = cal.view.getCompositeCalendar(window);
-  let cals = composite.getCalendars() || [];
+  const composite = cal.view.getCompositeCalendar(window);
+  const cals = composite.getCalendars() || [];
 
   composite.startBatch();
-  for (let calendar of cals) {
+  for (const calendar of cals) {
     if (calendar.id != aCalendar.id) {
       composite.removeCalendar(calendar);
     }
@@ -705,7 +604,7 @@ var compositeObserver = {
   onError() {},
 
   onPropertyChanged(calendar, name, value, oldValue) {
-    if (name == "disabled") {
+    if (name == "disabled" || name == "readOnly") {
       // Update commands when a calendar has been enabled or disabled.
       calendarUpdateNewItemsCommand();
       document.commandDispatcher.updateCommands("calendar_commands");
@@ -716,13 +615,15 @@ var compositeObserver = {
 
   onCalendarAdded(aCalendar) {
     // Update the calendar commands for number of remote calendars and for
-    // more than one calendar
+    // more than one calendar.
+    calendarUpdateNewItemsCommand();
     document.commandDispatcher.updateCommands("calendar_commands");
   },
 
   onCalendarRemoved(aCalendar) {
     // Update commands to disallow deleting the last calendar and only
     // allowing reload remote calendars when there are remote calendars.
+    calendarUpdateNewItemsCommand();
     document.commandDispatcher.updateCommands("calendar_commands");
   },
 
@@ -739,10 +640,10 @@ var compositeObserver = {
  * provider.
  */
 function openLocalCalendar() {
-  let picker = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
-  picker.init(window, cal.l10n.getCalString("Open"), Ci.nsIFilePicker.modeOpen);
-  let wildmat = "*.ics";
-  let description = cal.l10n.getCalString("filterIcs", [wildmat]);
+  const picker = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
+  picker.init(window.browsingContext, cal.l10n.getCalString("Open"), Ci.nsIFilePicker.modeOpen);
+  const wildmat = "*.ics";
+  const description = cal.l10n.getCalString("filterIcs", [wildmat]);
   picker.appendFilter(description, wildmat);
   picker.appendFilters(Ci.nsIFilePicker.filterAll);
 
@@ -751,26 +652,29 @@ function openLocalCalendar() {
       return;
     }
 
-    let calMgr = cal.getCalendarManager();
-    let calendars = calMgr.getCalendars();
+    const calendars = cal.manager.getCalendars();
     let calendar = calendars.find(x => x.uri.equals(picker.fileURL));
     if (!calendar) {
-      calendar = calMgr.createCalendar("ics", picker.fileURL);
+      calendar = cal.manager.createCalendar("ics", picker.fileURL);
 
       // Strip ".ics" from filename for use as calendar name.
-      let prettyName = picker.fileURL.spec.match(/([^/:]+)\.ics$/);
+      const prettyName = picker.fileURL.spec.match(/([^/:]+)\.ics$/);
       if (prettyName) {
         calendar.name = decodeURIComponent(prettyName[1]);
       } else {
         calendar.name = cal.l10n.getCalString("untitledCalendarName");
       }
 
-      calMgr.registerCalendar(calendar);
+      cal.manager.registerCalendar(calendar);
     }
 
-    let calendarList = document.getElementById("calendar-list");
-    let item = calendarList.getElementsByAttribute("calendar-id", calendar.id)[0];
-    calendarList.selectedItem = item;
+    const calendarList = document.getElementById("calendar-list");
+    for (let index = 0; index < calendarList.rowCount; index++) {
+      if (calendarList.rows[index].getAttribute("calendar-id") == calendar.id) {
+        calendarList.selectedIndex = index;
+        break;
+      }
+    }
   });
 }
 
