@@ -4,13 +4,10 @@
 
 /* exported gCategoriesPane */
 
-/* import-globals-from ../../../lightning/content/messenger-overlay-preferences.js */
-// From categories.xul.
-/* globals noneLabel, newTitle, editTitle, overwrite, overwriteTitle, noBlankCategories */
+/* globals gSubDialog, Preferences */
 
-var { cal } = ChromeUtils.import("resource://calendar/modules/calUtils.jsm");
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-var { AppConstants } = ChromeUtils.import("resource://gre/modules/AppConstants.jsm");
+var { cal } = ChromeUtils.importESModule("resource:///modules/calendar/calUtils.sys.mjs");
+var { AppConstants } = ChromeUtils.importESModule("resource://gre/modules/AppConstants.sys.mjs");
 
 Preferences.add({ id: "calendar.categories.names", type: "string" });
 
@@ -28,13 +25,13 @@ var gCategoriesPane = {
    * Initialize the categories pref pane. Sets up dialog controls to show the
    * categories saved in preferences.
    */
-  init: function() {
+  init() {
     // On non-instant-apply platforms, once this pane has been loaded,
     // attach our "revert all changes" function to the parent prefwindow's
     // "ondialogcancel" event.
-    let parentPrefWindow = document.documentElement;
+    const parentPrefWindow = document.documentElement;
     if (!parentPrefWindow.instantApply) {
-      let existingOnDialogCancel = parentPrefWindow.getAttribute("ondialogcancel");
+      const existingOnDialogCancel = parentPrefWindow.getAttribute("ondialogcancel");
       parentPrefWindow.setAttribute(
         "ondialogcancel",
         "gCategoriesPane.panelOnCancel(); " + existingOnDialogCancel
@@ -51,7 +48,7 @@ var gCategoriesPane = {
 
     this.updateCategoryList();
 
-    this.mCategoryDialog = "chrome://calendar/content/preferences/editCategory.xul";
+    this.mCategoryDialog = "chrome://calendar/content/preferences/editCategory.xhtml";
 
     // Workaround for Bug 1151440 - the HTML color picker won't work
     // in linux when opened from modal dialog
@@ -66,38 +63,35 @@ var gCategoriesPane = {
    * in preferences.
    */
 
-  updatePrefs: function() {
+  updatePrefs() {
     cal.l10n.sortArrayByLocaleCollator(gCategoryList);
     Preferences.get("calendar.categories.names").value = cal.category.arrayToString(gCategoryList);
   },
 
-  updateCategoryList: function() {
+  updateCategoryList() {
     this.updatePrefs();
-    let listbox = document.getElementById("categorieslist");
+    const listbox = document.getElementById("categorieslist");
 
     listbox.clearSelection();
     this.updateButtons();
 
-    while (listbox.lastChild) {
+    while (listbox.lastElementChild) {
       listbox.lastChild.remove();
     }
 
     for (let i = 0; i < gCategoryList.length; i++) {
-      let newListItem = document.createXULElement("richlistitem");
-      let categoryName = document.createXULElement("label");
+      const newListItem = document.createXULElement("richlistitem");
+      const categoryName = document.createXULElement("label");
       categoryName.setAttribute("id", gCategoryList[i]);
       categoryName.setAttribute("flex", "1");
       categoryName.setAttribute("value", gCategoryList[i]);
-      let categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[i]);
+      const categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[i]);
 
-      let categoryColor = document.createXULElement("box");
-      categoryColor.setAttribute("width", "150");
-      try {
-        let colorCode = categoryPrefBranch.getCharPref(categoryNameFix);
-        categoryColor.setAttribute("id", colorCode);
-        categoryColor.setAttribute("style", "background-color: " + colorCode + ";");
-      } catch (ex) {
-        categoryColor.setAttribute("label", noneLabel);
+      const categoryColor = document.createXULElement("box");
+      categoryColor.style.width = "150px";
+      const colorCode = categoryPrefBranch.getCharPref(categoryNameFix, "");
+      if (colorCode) {
+        categoryColor.style.backgroundColor = colorCode;
       }
 
       newListItem.appendChild(categoryName);
@@ -110,46 +104,46 @@ var gCategoriesPane = {
    * Adds a category, opening the edit category dialog to prompt the user to
    * set up the category.
    */
-  addCategory: function() {
-    let listbox = document.getElementById("categorieslist");
+  async addCategory() {
+    const listbox = document.getElementById("categorieslist");
     listbox.clearSelection();
     this.updateButtons();
-    let params = {
-      title: newTitle,
+    const params = {
+      title: await document.l10n.formatValue("category-new-label"),
       category: "",
       color: null,
     };
-    gSubDialog.open(this.mCategoryDialog, "resizable=no", params);
+    gSubDialog.open(this.mCategoryDialog, { features: "resizable=no" }, params);
   },
 
   /**
    * Edits the currently selected category using the edit category dialog.
    */
-  editCategory: function() {
-    let list = document.getElementById("categorieslist");
-    let categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[list.selectedIndex]);
-    let currentColor = categoryPrefBranch.getCharPref(categoryNameFix, "");
+  async editCategory() {
+    const list = document.getElementById("categorieslist");
+    const categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[list.selectedIndex]);
+    const currentColor = categoryPrefBranch.getCharPref(categoryNameFix, "");
 
-    let params = {
-      title: editTitle,
+    const params = {
+      title: await document.l10n.formatValue("category-edit-label"),
       category: gCategoryList[list.selectedIndex],
       color: currentColor,
     };
     if (list.selectedItem) {
-      gSubDialog.open(this.mCategoryDialog, "resizable=no", params);
+      gSubDialog.open(this.mCategoryDialog, { features: "resizable=no" }, params);
     }
   },
 
   /**
    * Removes the selected category.
    */
-  deleteCategory: function() {
-    let list = document.getElementById("categorieslist");
+  deleteCategory() {
+    const list = document.getElementById("categorieslist");
     if (list.selectedCount < 1) {
       return;
     }
 
-    let categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[list.selectedIndex]);
+    const categoryNameFix = cal.view.formatStringForCSSRule(gCategoryList[list.selectedIndex]);
     this.backupData(categoryNameFix);
     try {
       categoryPrefBranch.clearUserPref(categoryNameFix);
@@ -158,12 +152,13 @@ var gCategoriesPane = {
     }
 
     // Remove category entry from listbox and gCategoryList.
-    let newSelection = list.selectedItem.nextSibling || list.selectedItem.previousSibling;
-    let selectedItems = Array.from(list.selectedItems);
+    let newSelection =
+      list.selectedItem.nextElementSibling || list.selectedItem.previousElementSibling;
+    const selectedItems = Array.from(list.selectedItems);
     for (let i = list.selectedCount - 1; i >= 0; i--) {
-      let item = selectedItems[i];
+      const item = selectedItems[i];
       if (item == newSelection) {
-        newSelection = newSelection.nextSibling || newSelection.previousSibling;
+        newSelection = newSelection.nextElementSibling || newSelection.previousElementSibling;
       }
       gCategoryList.splice(list.getIndexOfItem(item), 1);
       item.remove();
@@ -181,8 +176,8 @@ var gCategoriesPane = {
    * @param categoryName      The name of the category.
    * @param categoryColor     The color of the category
    */
-  saveCategory: function(categoryName, categoryColor) {
-    let list = document.getElementById("categorieslist");
+  async saveCategory(categoryName, categoryColor) {
+    const list = document.getElementById("categorieslist");
     // Check to make sure another category doesn't have the same name
     let toBeDeleted = -1;
     for (let i = 0; i < gCategoryList.length; i++) {
@@ -191,7 +186,12 @@ var gCategoriesPane = {
       }
 
       if (categoryName.toLowerCase() == gCategoryList[i].toLowerCase()) {
-        if (Services.prompt.confirm(null, overwriteTitle, overwrite)) {
+        const [title, description] = await document.l10n.formatValues([
+          { id: "category-overwrite-title" },
+          { id: "category-overwrite" },
+        ]);
+
+        if (Services.prompt.confirm(null, title, description)) {
           if (list.selectedIndex != -1) {
             // Don't delete the old category yet. It will mess up indices.
             toBeDeleted = list.selectedIndex;
@@ -204,11 +204,12 @@ var gCategoriesPane = {
     }
 
     if (categoryName.length == 0) {
-      Services.prompt.alert(null, null, noBlankCategories);
+      const warning = await document.l10n.formatValue("category-blank-warning");
+      Services.prompt.alert(null, null, warning);
       return;
     }
 
-    let categoryNameFix = cal.view.formatStringForCSSRule(categoryName);
+    const categoryNameFix = cal.view.formatStringForCSSRule(categoryName);
     if (list.selectedIndex == -1) {
       this.backupData(categoryNameFix);
       gCategoryList.push(categoryName);
@@ -218,15 +219,7 @@ var gCategoriesPane = {
     } else {
       this.backupData(categoryNameFix);
       gCategoryList.splice(list.selectedIndex, 1, categoryName);
-      if (categoryColor) {
-        categoryPrefBranch.setCharPref(categoryNameFix, categoryColor);
-      } else {
-        try {
-          categoryPrefBranch.clearUserPref(categoryNameFix);
-        } catch (ex) {
-          dump("Exception caught in 'saveCategory': " + ex + "\n");
-        }
-      }
+      categoryPrefBranch.setCharPref(categoryNameFix, categoryColor || "");
     }
 
     // If 'Overwrite' was chosen, delete category that was being edited
@@ -237,7 +230,7 @@ var gCategoriesPane = {
 
     this.updateCategoryList();
 
-    let updatedCategory = gCategoryList.indexOf(categoryName);
+    const updatedCategory = gCategoryList.indexOf(categoryName);
     list.ensureIndexIsVisible(updatedCategory);
     list.selectedIndex = updatedCategory;
   },
@@ -245,8 +238,8 @@ var gCategoriesPane = {
   /**
    * Enable the edit and delete category buttons.
    */
-  updateButtons: function() {
-    let categoriesList = document.getElementById("categorieslist");
+  updateButtons() {
+    const categoriesList = document.getElementById("categorieslist");
     document.getElementById("deleteCButton").disabled = categoriesList.selectedCount <= 0;
     document.getElementById("editCButton").disabled = categoriesList.selectedCount != 1;
   },
@@ -257,8 +250,8 @@ var gCategoriesPane = {
    * @see formatStringForCSSRule
    * @param categoryNameFix     The formatted category name.
    */
-  backupData: function(categoryNameFix) {
-    let currentColor = categoryPrefBranch.getCharPref(categoryNameFix, "##NEW");
+  backupData(categoryNameFix) {
+    const currentColor = categoryPrefBranch.getCharPref(categoryNameFix, "##NEW");
 
     for (let i = 0; i < parent.backupPrefList.length; i++) {
       if (categoryNameFix == parent.backupPrefList[i].name) {
@@ -276,7 +269,7 @@ var gCategoriesPane = {
    * list. If the edit function is enabled and the user doubleclicked on a
    * list item, then edit the selected category.
    */
-  listOnDblClick: function(event) {
+  listOnDblClick(event) {
     if (event.target.localName == "listitem" && !document.getElementById("editCButton").disabled) {
       this.editCategory();
     }
@@ -285,7 +278,7 @@ var gCategoriesPane = {
   /**
    * Reverts category preferences in case the cancel button is pressed.
    */
-  panelOnCancel: function() {
+  panelOnCancel() {
     for (let i = 0; i < parent.backupPrefList.length; i++) {
       if (parent.backupPrefList[i].color == "##NEW") {
         try {
