@@ -7,21 +7,22 @@
 /* import-globals-from ../calendar-ui-utils.js */
 /* globals Preferences */
 
-var { cal } = ChromeUtils.import("resource:///modules/calendar/calUtils.jsm");
+var { cal } = ChromeUtils.importESModule("resource:///modules/calendar/calUtils.sys.mjs");
 
 Preferences.addAll([
   { id: "calendar.date.format", type: "int" },
   { id: "calendar.event.defaultlength", type: "int" },
   { id: "calendar.timezone.local", type: "string" },
+  { id: "calendar.timezone.useSystemTimezone", type: "bool" },
   { id: "calendar.task.defaultstart", type: "string" },
   { id: "calendar.task.defaultstartoffset", type: "int" },
   { id: "calendar.task.defaultstartoffsetunits", type: "string" },
   { id: "calendar.task.defaultdue", type: "string" },
   { id: "calendar.task.defaultdueoffset", type: "int" },
   { id: "calendar.task.defaultdueoffsetunits", type: "string" },
-  { id: "calendar.view.useSystemColors", type: "bool" },
-  { id: "calendar.agendaListbox.soondays", type: "int" },
+  { id: "calendar.agenda.days", type: "int" },
   { id: "calendar.item.editInTab", type: "bool" },
+  { id: "calendar.item.promptDelete", type: "bool" },
 ]);
 
 /**
@@ -33,9 +34,11 @@ var gCalendarGeneralPane = {
    * values set in prefs.
    */
   init() {
-    let formatter = cal.dtz.formatter;
-    let dateFormattedLong = formatter.formatDateLong(cal.dtz.now());
-    let dateFormattedShort = formatter.formatDateShort(cal.dtz.now());
+    this.onChangedUseSystemTimezonePref();
+
+    const formatter = cal.dtz.formatter;
+    const dateFormattedLong = formatter.formatDateLong(cal.dtz.now());
+    const dateFormattedShort = formatter.formatDateShort(cal.dtz.now());
 
     // menu items include examples of current date formats.
     document.l10n.setAttributes(
@@ -54,24 +57,23 @@ var gCalendarGeneralPane = {
     updateUnitLabelPlural("defaultlength", "defaultlengthunit", "minutes");
     this.updateDefaultTodoDates();
 
-    let tzMenuList = document.getElementById("calendar-timezone-menulist");
-    let tzMenuPopup = document.getElementById("calendar-timezone-menupopup");
+    const tzMenuList = document.getElementById("calendar-timezone-menulist");
+    const tzMenuPopup = document.getElementById("calendar-timezone-menupopup");
 
-    let tzService = cal.getTimezoneService();
-    let tzids = {};
-    let displayNames = [];
+    const tzids = {};
+    const displayNames = [];
     // don't rely on what order the timezone-service gives you
-    for (let timezoneId of tzService.timezoneIds) {
-      let timezone = tzService.getTimezone(timezoneId);
+    for (const timezoneId of cal.timezoneService.timezoneIds) {
+      const timezone = cal.timezoneService.getTimezone(timezoneId);
       if (timezone && !timezone.isFloating && !timezone.isUTC) {
-        let displayName = timezone.displayName;
+        const displayName = timezone.displayName;
         displayNames.push(displayName);
         tzids[displayName] = timezone.tzid;
       }
     }
     // the display names need to be sorted
     displayNames.sort((a, b) => a.localeCompare(b));
-    for (let displayName of displayNames) {
+    for (const displayName of displayNames) {
       addMenuItem(tzMenuPopup, displayName, tzids[displayName]);
     }
 
@@ -81,14 +83,14 @@ var gCalendarGeneralPane = {
     }
     tzMenuList.value = prefValue;
 
-    // Set the soondays menulist preference
+    // Set the agenda length menulist.
     this.initializeTodaypaneMenu();
   },
 
   updateDefaultTodoDates() {
-    let defaultDue = document.getElementById("default_task_due").value;
-    let defaultStart = document.getElementById("default_task_start").value;
-    let offsetValues = ["offsetcurrent", "offsetnexthour"];
+    const defaultDue = document.getElementById("default_task_due").value;
+    const defaultStart = document.getElementById("default_task_start").value;
+    const offsetValues = ["offsetcurrent", "offsetnexthour"];
 
     document.getElementById("default_task_due_offset").style.visibility = offsetValues.includes(
       defaultDue
@@ -107,10 +109,10 @@ var gCalendarGeneralPane = {
 
   initializeTodaypaneMenu() {
     // Assign the labels for the menuitem
-    let soondaysMenu = document.getElementById("soondays-menulist");
-    let items = soondaysMenu.getElementsByTagName("menuitem");
-    for (let menuItem of items) {
-      let menuitemValue = Number(menuItem.value);
+    const menulist = document.getElementById("agenda-days-menulist");
+    const items = menulist.getElementsByTagName("menuitem");
+    for (const menuItem of items) {
+      const menuitemValue = Number(menuItem.value);
       if (menuitemValue > 7) {
         menuItem.label = unitPluralForm(menuitemValue / 7, "weeks");
       } else {
@@ -118,19 +120,29 @@ var gCalendarGeneralPane = {
       }
     }
 
-    let pref = Preferences.get("calendar.agendaListbox.soondays");
-    let soonpref = pref.value || 5;
+    const pref = Preferences.get("calendar.agenda.days");
+    let value = pref.value;
 
-    // Check if soonDays preference has been edited with a wrong value.
-    if (soonpref > 0 && soonpref <= 28) {
-      if (soonpref % 7 != 0) {
-        let intSoonpref = Math.floor(soonpref / 7) * 7;
-        soonpref = intSoonpref == 0 ? soonpref : intSoonpref;
-        pref.value = soonpref;
+    // Check if the preference has been edited with a wrong value.
+    if (value > 0 && value <= 28) {
+      if (value % 7 != 0) {
+        const intValue = Math.floor(value / 7) * 7;
+        value = intValue == 0 ? value : intValue;
+        pref.value = value;
       }
     } else {
-      soonpref = soonpref > 28 ? 28 : 1;
-      pref.value = soonpref;
+      pref.value = 14;
     }
   },
+
+  onChangedUseSystemTimezonePref() {
+    const useSystemTimezonePref = Preferences.get("calendar.timezone.useSystemTimezone");
+
+    document.getElementById("calendar-timezone-menulist").disabled = useSystemTimezonePref.value;
+  },
 };
+
+Preferences.get("calendar.timezone.useSystemTimezone").on(
+  "change",
+  gCalendarGeneralPane.onChangedUseSystemTimezonePref
+);
