@@ -8,8 +8,15 @@
 
 // Wrap in a block to prevent leaking to window scope.
 {
-  const { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-  const { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+  const { XPCOMUtils } = ChromeUtils.importESModule("resource://gre/modules/XPCOMUtils.sys.mjs");
+
+  const lazy = {};
+  ChromeUtils.defineESModuleGetters(lazy, {
+    CalDateTime: "resource:///modules/CalDateTime.sys.mjs",
+  });
+
+  const dayFormatter = new Services.intl.DateTimeFormat(undefined, { day: "numeric" });
+  const dateFormatter = new Services.intl.DateTimeFormat(undefined, { dateStyle: "long" });
 
   /**
    * MiniMonth Calendar: day-of-month grid component.
@@ -32,8 +39,8 @@
       this.calIObserver = this.getCustomInterfaceCallback(Ci.calIObserver);
       this.calICompositeObserver = this.getCustomInterfaceCallback(Ci.calICompositeObserver);
 
-      let onPreferenceChanged = () => {
-        delete this.dayBoxes; // Days have moved, force a refresh of the grid.
+      const onPreferenceChanged = () => {
+        this.dayBoxes.clear(); // Days have moved, force a refresh of the grid.
         this.refreshDisplay();
       };
 
@@ -65,27 +72,49 @@
         return;
       }
 
+      MozXULElement.insertFTLIfNeeded("calendar/calendar-widgets.ftl");
+
       const minimonthHeader = `
-        <hbox class="minimonth-header minimonth-month-box" align="center">
-          <toolbarbutton class="months-back-button minimonth-nav-btns"
-                         dir="-1"
-                         tooltiptext="&onemonthbackward.tooltip;"></toolbarbutton>
-          <label class="minimonth-month-name" tabindex="-1"/>
-          <toolbarbutton class="months-forward-button minimonth-nav-btns"
-                         dir="1"
-                         tooltiptext="&onemonthforward.tooltip;"></toolbarbutton>
-          <toolbarbutton class="years-back-button minimonth-nav-btns"
-                         dir="-1"
-                         tooltiptext="&oneyearbackward.tooltip;"></toolbarbutton>
-          <label class="yearcell minimonth-year-name" tabindex="-1"></label>
-          <toolbarbutton class="years-forward-button minimonth-nav-btns"
-                         dir="1"
-                         tooltiptext="&oneyearforward.tooltip;"></toolbarbutton>
-          <spacer flex="1"></spacer>
-          <toolbarbutton class="today-button minimonth-nav-btns"
-                         dir="0"
-                         tooltiptext="&showToday.tooltip;"></toolbarbutton>
-        </hbox>
+        <html:div class="minimonth-header minimonth-month-box"
+                  xmlns="http://www.w3.org/1999/xhtml">
+          <div class="minimonth-nav-section">
+            <button class="button icon-button icon-only minimonth-nav-btn today-button"
+                    data-l10n-id="calendar-today-button-tooltip"
+                    type="button"
+                    dir="0">
+            </button>
+          </div>
+          <div class="minimonth-nav-section">
+            <button class="button icon-button icon-only minimonth-nav-btn months-back-button"
+                    data-l10n-id="calendar-nav-button-prev-tooltip-month"
+                    type="button"
+                    dir="-1">
+            </button>
+            <div class="minimonth-nav-item">
+              <input class="minimonth-month-name" tabindex="-1" readonly="true" disabled="disabled" />
+            </div>
+            <button class="button icon-button icon-only minimonth-nav-btn months-forward-button"
+                    data-l10n-id="calendar-nav-button-next-tooltip-month"
+                    type="button"
+                    dir="1">
+            </button>
+          </div>
+          <div class="minimonth-nav-section">
+            <button class="button icon-button icon-only minimonth-nav-btn years-back-button"
+                    data-l10n-id="calendar-nav-button-prev-tooltip-year"
+                    type="button"
+                    dir="-1">
+            </button>
+            <div class="minimonth-nav-item">
+              <input class="yearcell minimonth-year-name" tabindex="-1" readonly="true" disabled="disabled" />
+            </div>
+            <button class="button icon-button icon-only minimonth-nav-btn years-forward-button"
+                    data-l10n-id="calendar-nav-button-next-tooltip-year"
+                    type="button"
+                    dir="1">
+            </button>
+          </div>
+        </html:div>
       `;
 
       const minimonthWeekRow = `
@@ -125,30 +154,30 @@
             ${minimonthWeekRow}
           </html:table>
           `,
-          ["chrome://calendar/locale/global.dtd", "chrome://global/locale/global.dtd"]
+          ["chrome://calendar/locale/global.dtd"]
         )
       );
       this.initializeAttributeInheritance();
       this.setAttribute("orient", "vertical");
 
       // Set up header buttons.
-      this.querySelector(".months-back-button").addEventListener("command", () =>
+      this.querySelector(".months-back-button").addEventListener("click", () =>
         this.advanceMonth(-1)
       );
-      this.querySelector(".months-forward-button").addEventListener("command", () =>
+      this.querySelector(".months-forward-button").addEventListener("click", () =>
         this.advanceMonth(1)
       );
-      this.querySelector(".years-back-button").addEventListener("command", () =>
+      this.querySelector(".years-back-button").addEventListener("click", () =>
         this.advanceYear(-1)
       );
-      this.querySelector(".years-forward-button").addEventListener("command", () =>
+      this.querySelector(".years-forward-button").addEventListener("click", () =>
         this.advanceYear(1)
       );
-      this.querySelector(".today-button").addEventListener("command", () => {
+      this.querySelector(".today-button").addEventListener("click", () => {
         this.value = new Date();
       });
 
-      this.dayBoxes = null;
+      this.dayBoxes = new Map();
       this.mValue = null;
       this.mEditorDate = null;
       this.mExtraDate = null;
@@ -164,7 +193,7 @@
       // Start loop from 1 as it is needed to get the first month name string
       // and avoid extra computation of adding one.
       for (let i = 1; i <= 12; i++) {
-        let dateString = cal.l10n.getDateFmtString(`month.${i}.name`);
+        const dateString = cal.l10n.getDateFmtString(`month.${i}.name`);
         width = Math.max(dateString.length, width);
       }
       this.querySelector(".minimonth-month-name").style.width = `${width + 1}ch`;
@@ -294,7 +323,7 @@
      * Returns the first (inclusive) date of the minimonth as a calIDateTime object.
      */
     get firstDate() {
-      let date = this._getCalBoxNode(1, 1).date;
+      const date = this._getCalBoxNode(1, 1).date;
       return cal.dtz.jsDateToDateTime(date);
     }
 
@@ -302,8 +331,8 @@
      * Returns the last (exclusive) date of the minimonth as a calIDateTime object.
      */
     get lastDate() {
-      let date = this._getCalBoxNode(6, 7).date;
-      let lastDateTime = cal.dtz.jsDateToDateTime(date);
+      const date = this._getCalBoxNode(6, 7).date;
+      const lastDateTime = cal.dtz.jsDateToDateTime(date);
       lastDateTime.day = lastDateTime.day + 1;
       return lastDateTime;
     }
@@ -313,20 +342,20 @@
     }
 
     setBusyDaysForItem(aItem, aState) {
-      let items = aItem.recurrenceInfo
+      const items = aItem.recurrenceInfo
         ? aItem.getOccurrencesBetween(this.firstDate, this.lastDate)
         : [aItem];
       items.forEach(item => this.setBusyDaysForOccurrence(item, aState));
     }
 
     parseBoxBusy(aBox) {
-      let boxBusy = {};
+      const boxBusy = {};
 
-      let busyStr = aBox.getAttribute("busy");
+      const busyStr = aBox.getAttribute("busy");
       if (busyStr && busyStr.length > 0) {
-        let calChunks = busyStr.split("\u001A");
-        for (let chunk of calChunks) {
-          let expr = chunk.split("=");
+        const calChunks = busyStr.split("\u001A");
+        for (const chunk of calChunks) {
+          const expr = chunk.split("=");
           boxBusy[expr[0]] = parseInt(expr[1], 10);
         }
       }
@@ -335,16 +364,16 @@
     }
 
     updateBoxBusy(aBox, aBoxBusy) {
-      let calChunks = [];
+      const calChunks = [];
 
-      for (let calId in aBoxBusy) {
+      for (const calId in aBoxBusy) {
         if (aBoxBusy[calId]) {
           calChunks.push(calId + "=" + aBoxBusy[calId]);
         }
       }
 
       if (calChunks.length > 0) {
-        let busyStr = calChunks.join("\u001A");
+        const busyStr = calChunks.join("\u001A");
         aBox.setAttribute("busy", busyStr);
       } else {
         aBox.removeAttribute("busy");
@@ -352,7 +381,7 @@
     }
 
     removeCalendarFromBoxBusy(aBox, aCalendar) {
-      let boxBusy = this.parseBoxBusy(aBox);
+      const boxBusy = this.parseBoxBusy(aBox);
       if (boxBusy[aCalendar.id]) {
         delete boxBusy[aCalendar.id];
       }
@@ -381,19 +410,19 @@
 
       // We need to compare with midnight of the current day, so reset the
       // time here.
-      let current = start.clone().getInTimezone(cal.dtz.defaultTimezone);
+      const current = start.clone().getInTimezone(cal.dtz.defaultTimezone);
       current.hour = 0;
       current.minute = 0;
       current.second = 0;
 
       // Cache the result so the compare isn't called in each iteration.
-      let compareResult = start.compare(end) == 0 ? 1 : 0;
+      const compareResult = start.compare(end) == 0 ? 1 : 0;
 
       // Setup the busy days.
       while (current.compare(end) < compareResult) {
-        let box = this.getBoxForDate(current);
+        const box = this.getBoxForDate(current);
         if (box) {
-          let busyCalendars = this.parseBoxBusy(box);
+          const busyCalendars = this.parseBoxBusy(box);
           if (!busyCalendars[aOccurrence.calendar.id]) {
             busyCalendars[aOccurrence.calendar.id] = 0;
           }
@@ -466,7 +495,7 @@
 
     onCalendarRemoved(aCalendar) {
       if (!aCalendar.getProperty("disabled")) {
-        for (let { box } of this.dayBoxes) {
+        for (const box of this.dayBoxes.values()) {
           this.removeCalendarFromBoxBusy(box, aCalendar);
         }
       }
@@ -494,9 +523,9 @@
 
     setHeader() {
       // Reset the headers.
-      let dayList = new Array(7);
-      let longDayList = new Array(7);
-      let tempDate = new Date();
+      const dayList = new Array(7);
+      const longDayList = new Array(7);
+      const tempDate = new Date();
       let i, j;
       let useOSFormat;
       tempDate.setDate(tempDate.getDate() - (tempDate.getDay() - this.weekStart));
@@ -518,14 +547,14 @@
         // be as narrow as 2 digits.
         //
         // 1. Compute the minLength of the day name abbreviations.
-        let minLength = dayList.map(name => name.length).reduce((min, len) => Math.min(min, len));
+        const minLength = dayList.map(name => name.length).reduce((min, len) => Math.min(min, len));
 
         // 2. If some day name abbrev. is longer than 2 chars (not Catalan),
         //    and ALL localized day names share same prefix (as in Chinese),
         //    then trim shared "day-" prefix.
         if (dayList.some(dayAbbr => dayAbbr.length > 2)) {
           for (let endPrefix = 0; endPrefix < minLength; endPrefix++) {
-            let suffix = dayList[0][endPrefix];
+            const suffix = dayList[0][endPrefix];
             if (dayList.some(dayAbbr => dayAbbr[endPrefix] != suffix)) {
               if (endPrefix > 0) {
                 for (i = 0; i < dayList.length; i++) {
@@ -554,7 +583,7 @@
 
       this._getCalBoxNode(0, 0).hidden = !this.showWeekNumber;
       for (let column = 1; column < 8; column++) {
-        let node = this._getCalBoxNode(0, column);
+        const node = this._getCalBoxNode(0, column);
         node.textContent = dayList[column - 1];
         node.setAttribute("aria-label", longDayList[column - 1]);
       }
@@ -573,7 +602,7 @@
       aDate.setSeconds(0);
       aDate.setMilliseconds(0);
       // Don't fire onmonthchange event upon initialization
-      let monthChanged = this.mEditorDate && this.mEditorDate.valueOf() != aDate.valueOf();
+      const monthChanged = this.mEditorDate && this.mEditorDate.valueOf() != aDate.valueOf();
       this.mEditorDate = aDate; // Only place mEditorDate is set.
 
       if (this.mSelected) {
@@ -582,15 +611,15 @@
       }
 
       // Get today's date.
-      let today = new Date();
+      const today = new Date();
 
-      if (!monthChanged && this.dayBoxes) {
+      if (!monthChanged && this.dayBoxes.size > 0) {
         this.mSelected = this.getBoxForDate(this.value);
         if (this.mSelected) {
           this.mSelected.setAttribute("selected", "true");
         }
 
-        let todayBox = this.getBoxForDate(today);
+        const todayBox = this.getBoxForDate(today);
         if (this.mToday != todayBox) {
           if (this.mToday) {
             this.mToday.removeAttribute("today");
@@ -615,42 +644,43 @@
 
       // Update the month and year title.
       this.setAttribute("year", aDate.getFullYear());
+      this.setAttribute("month", aDate.getMonth());
 
-      let miniMonthName = this.querySelector(".minimonth-month-name");
-      let dateString = cal.l10n.getDateFmtString(`month.${aDate.getMonth() + 1}.name`);
+      const miniMonthName = this.querySelector(".minimonth-month-name");
+      const dateString = cal.l10n.getDateFmtString(`month.${aDate.getMonth() + 1}.name`);
       miniMonthName.setAttribute("value", dateString);
       miniMonthName.setAttribute("monthIndex", aDate.getMonth());
       this.mReadOnlyHeader.textContent = dateString + " " + aDate.getFullYear();
 
       // Update the calendar.
-      let calbox = this.querySelector(".minimonth-calendar");
-      let date = this._getStartDate(aDate);
+      const calbox = this.querySelector(".minimonth-calendar");
+      const date = this._getStartDate(aDate);
 
       if (aDate.getFullYear() == (this.mValue || this.mExtraDate).getFullYear()) {
         calbox.setAttribute("aria-label", dateString);
       } else {
-        let monthName = cal.l10n.formatMonth(aDate.getMonth() + 1, "calendar", "monthInYear");
-        let label = cal.l10n.getCalString("monthInYear", [monthName, aDate.getFullYear()]);
+        const monthName = cal.l10n.formatMonth(aDate.getMonth() + 1, "calendar", "monthInYear");
+        const label = cal.l10n.getCalString("monthInYear", [monthName, aDate.getFullYear()]);
         calbox.setAttribute("aria-label", label);
       }
 
-      this.dayBoxes = [];
-      let defaultTz = cal.dtz.defaultTimezone;
+      this.dayBoxes.clear();
+      const defaultTz = cal.dtz.defaultTimezone;
       for (let k = 1; k < 7; k++) {
         // Set the week number.
-        let firstElement = this._getCalBoxNode(k, 0);
+        const firstElement = this._getCalBoxNode(k, 0);
         firstElement.hidden = !this.showWeekNumber;
         if (this.showWeekNumber) {
-          let weekNumber = cal.weekInfoService.getWeekTitle(
+          const weekNumber = cal.weekInfoService.getWeekTitle(
             cal.dtz.jsDateToDateTime(date, defaultTz)
           );
-          let weekTitle = cal.l10n.getCalString("WeekTitle", [weekNumber]);
+          const weekTitle = cal.l10n.getCalString("WeekTitle", [weekNumber]);
           firstElement.textContent = weekNumber;
           firstElement.setAttribute("aria-label", weekTitle);
         }
 
         for (let i = 1; i < 8; i++) {
-          let day = this._getCalBoxNode(k, i);
+          const day = this._getCalBoxNode(k, i);
           this.setBoxForDate(date, day);
 
           if (this.getAttribute("readonly") != "true") {
@@ -670,7 +700,7 @@
           }
 
           // Highlight the current date.
-          let val = this.value;
+          const val = this.value;
           if (this._sameDay(val, date)) {
             this.mSelected = day;
             day.setAttribute("selected", "true");
@@ -683,9 +713,9 @@
           }
 
           if (aDate.getMonth() == date.getMonth() && aDate.getFullYear() == date.getFullYear()) {
-            day.setAttribute("aria-label", date.toLocaleDateString(undefined, { day: "numeric" }));
+            day.setAttribute("aria-label", dayFormatter.format(date));
           } else {
-            day.setAttribute("aria-label", this.dateFormatter.format(date));
+            day.setAttribute("aria-label", dateFormatter.format(date));
           }
 
           day.removeAttribute("busy");
@@ -694,7 +724,7 @@
           day.textContent = date.getDate();
           date.setDate(date.getDate() + 1);
 
-          this.resetAttributesForDate(day.date);
+          this.resetAttributesForBox(day);
         }
       }
 
@@ -716,17 +746,25 @@
       this.dispatchEvent(new CustomEvent(aEventName, { bubbles: true }));
     }
 
+    _boxKeyForDate(aDate) {
+      if (aDate instanceof lazy.CalDateTime || aDate instanceof Ci.calIDateTime) {
+        return aDate.getInTimezone(cal.dtz.defaultTimezone).toString().substring(0, 10);
+      }
+      return [
+        aDate.getFullYear(),
+        (aDate.getMonth() + 1).toString().padStart(2, "0"),
+        aDate.getDate().toString().padStart(2, "0"),
+      ].join("-");
+    }
+
     /**
      * Fetches the table cell for the given date, or null if the date isn't displayed.
      *
      * @param {calIDateTime|Date} aDate
-     * @return {HTMLTableCellElement|null}
+     * @returns {HTMLTableCellElement|null}
      */
     getBoxForDate(aDate) {
-      if (!(aDate instanceof Ci.calIDateTime)) {
-        aDate = cal.dtz.jsDateToDateTime(aDate, cal.dtz.floating);
-      }
-      return this.dayBoxes.find(obj => cal.dtz.sameDay(obj.date, aDate))?.box || null;
+      return this.dayBoxes.get(this._boxKeyForDate(aDate)) ?? null;
     }
 
     /**
@@ -736,41 +774,52 @@
      * @param {HTMLTableCellElement} aBox
      */
     setBoxForDate(aDate, aBox) {
-      this.dayBoxes.push({ date: cal.dtz.jsDateToDateTime(aDate, cal.dtz.floating), box: aBox });
+      this.dayBoxes.set(this._boxKeyForDate(aDate), aBox);
     }
 
-    resetAttributesForDate(aDate) {
-      function removeForBox(aBox) {
-        let allowedAttributes = 0;
-        while (aBox.attributes.length > allowedAttributes) {
-          switch (aBox.attributes[allowedAttributes].nodeName) {
-            case "selected":
-            case "othermonth":
-            case "today":
-            case "extra":
-            case "interactive":
-            case "class":
-            case "tabindex":
-            case "role":
-            case "aria-label":
-              allowedAttributes++;
-              break;
-            default:
-              aBox.removeAttribute(aBox.attributes[allowedAttributes].nodeName);
-              break;
-          }
+    /**
+     * Remove attributes that may have been added to a table cell.
+     *
+     * @param {HTMLTableCellElement} aBox
+     */
+    resetAttributesForBox(aBox) {
+      let allowedAttributes = 0;
+      while (aBox.attributes.length > allowedAttributes) {
+        switch (aBox.attributes[allowedAttributes].nodeName) {
+          case "selected":
+          case "othermonth":
+          case "today":
+          case "extra":
+          case "interactive":
+          case "class":
+          case "tabindex":
+          case "role":
+          case "aria-label":
+            allowedAttributes++;
+            break;
+          default:
+            aBox.removeAttribute(aBox.attributes[allowedAttributes].nodeName);
+            break;
         }
       }
+    }
 
+    /**
+     * Remove attributes that may have been added to a table cell, or all table cells.
+     *
+     * @param {Date} [aDate] - If specified, the date of the cell to reset,
+     *   otherwise all date cells will be reset.
+     */
+    resetAttributesForDate(aDate) {
       if (aDate) {
-        let box = this.getBoxForDate(aDate);
+        const box = this.getBoxForDate(aDate);
         if (box) {
-          removeForBox(box);
+          this.resetAttributesForBox(box);
         }
       } else {
         for (let k = 1; k < 7; k++) {
           for (let i = 1; i < 8; i++) {
-            removeForBox(this._getCalBoxNode(k, i));
+            this.resetAttributesForBox(this._getCalBoxNode(k, i));
           }
         }
       }
@@ -807,14 +856,14 @@
       // The minimonth automatically clears extra styles on a month change.
       // Therefore we only need to fill the minimonth with new info.
 
-      let calendar = aCalendar || cal.view.getCompositeCalendar(window);
-      let filter =
+      const calendar = aCalendar || cal.view.getCompositeCalendar(window);
+      const filter =
         calendar.ITEM_FILTER_COMPLETED_ALL |
         calendar.ITEM_FILTER_CLASS_OCCURRENCES |
         calendar.ITEM_FILTER_ALL_ITEMS;
 
       // Get new info.
-      for await (let items of cal.iterate.streamValues(
+      for await (const items of cal.iterate.streamValues(
         calendar.getItems(filter, 0, this.firstDate, this.lastDate)
       )) {
         items.forEach(item => this.setBusyDaysForOccurrence(item, true));
@@ -824,7 +873,7 @@
     updateAccessibleLabel() {
       let label;
       if (this.mValue) {
-        label = this.dateFormatter.format(this.mValue);
+        label = dateFormatter.format(this.mValue);
       } else {
         label = cal.l10n.getCalString("minimonthNoSelectedDate");
       }
@@ -832,7 +881,7 @@
     }
 
     update(aValue) {
-      let changed =
+      const changed =
         this.mValue &&
         aValue &&
         (this.mValue.getFullYear() != aValue.getFullYear() ||
@@ -851,7 +900,7 @@
     }
 
     setFocusedDate(aDate, aForceFocus) {
-      let newFocused = this.getBoxForDate(aDate);
+      const newFocused = this.getBoxForDate(aDate);
       if (!newFocused) {
         return;
       }
@@ -862,7 +911,7 @@
       this.mFocused.setAttribute("tabindex", "0");
       // Only actually move the focus if it is already in the calendar box.
       if (!aForceFocus) {
-        let calbox = this.querySelector(".minimonth-calendar");
+        const calbox = this.querySelector(".minimonth-calendar");
         aForceFocus = calbox.contains(document.commandDispatcher.focusedElement);
       }
       if (aForceFocus) {
@@ -876,13 +925,13 @@
     }
 
     switchMonth(aMonth) {
-      let newMonth = new Date(this.mEditorDate);
+      const newMonth = new Date(this.mEditorDate);
       newMonth.setMonth(aMonth);
       this.showMonth(newMonth);
     }
 
     switchYear(aYear) {
-      let newMonth = new Date(this.mEditorDate);
+      const newMonth = new Date(this.mEditorDate);
       newMonth.setFullYear(aYear);
       this.showMonth(newMonth);
     }
@@ -898,8 +947,8 @@
       }
       // Note that aMainDate and this.mEditorDate refer to the first day
       // of the corresponding month.
-      let sameMonth = this._sameDay(aMainDate, this.mEditorDate);
-      let sameDate = this._sameDay(aDate, this.mValue);
+      const sameMonth = this._sameDay(aMainDate, this.mEditorDate);
+      const sameDate = this._sameDay(aDate, this.mValue);
       if (!sameMonth && !sameDate) {
         // Change month and select day.
         this.mValue = aDate;
@@ -909,7 +958,7 @@
         this.showMonth(aMainDate);
       } else if (!sameDate) {
         // Select day only.
-        let day = this.getBoxForDate(aDate);
+        const day = this.getBoxForDate(aDate);
         if (this.mSelected) {
           this.mSelected.removeAttribute("selected");
         }
@@ -921,16 +970,16 @@
     }
 
     _getStartDate(aMainDate) {
-      let date = new Date(aMainDate);
-      let firstWeekday = (7 + aMainDate.getDay() - this.weekStart) % 7;
+      const date = new Date(aMainDate);
+      const firstWeekday = (7 + aMainDate.getDay() - this.weekStart) % 7;
       date.setDate(date.getDate() - firstWeekday);
       return date;
     }
 
     _getEndDate(aMainDate) {
-      let date = this._getStartDate(aMainDate);
-      let calbox = this.querySelector(".minimonth-calendar");
-      let days = (calbox.children.length - 1) * 7;
+      const date = this._getStartDate(aMainDate);
+      const calbox = this.querySelector(".minimonth-calendar");
+      const days = (calbox.children.length - 1) * 7;
       date.setDate(date.getDate() + days - 1);
       return date;
     }
@@ -949,15 +998,15 @@
     }
 
     advanceMonth(aDir) {
-      let advEditorDate = new Date(this.mEditorDate); // At 1st of month.
-      let advMonth = this.mEditorDate.getMonth() + aDir;
+      const advEditorDate = new Date(this.mEditorDate); // At 1st of month.
+      const advMonth = this.mEditorDate.getMonth() + aDir;
       advEditorDate.setMonth(advMonth);
       this.showMonth(advEditorDate);
     }
 
     advanceYear(aDir) {
-      let advEditorDate = new Date(this.mEditorDate); // At 1st of month.
-      let advYear = this.mEditorDate.getFullYear() + aDir;
+      const advEditorDate = new Date(this.mEditorDate); // At 1st of month.
+      const advYear = this.mEditorDate.getFullYear() + aDir;
       advEditorDate.setFullYear(advYear);
       this.showMonth(advEditorDate);
     }
@@ -1000,12 +1049,6 @@
     }
   }
 
-  XPCOMUtils.defineLazyGetter(
-    CalendarMinimonth.prototype,
-    "dateFormatter",
-    () => new Services.intl.DateTimeFormat(undefined, { dateStyle: "long" })
-  );
-
   MozXULElement.implementCustomInterface(CalendarMinimonth, [
     Ci.calIObserver,
     Ci.calICompositeObserver,
