@@ -4,6 +4,10 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+// This file contains Thunderbird specific settings and overrides to settings
+// from mailnews.js, all.js etc. Settings in this file will take
+// precedence for Thunderbird.
+
 #ifdef XP_UNIX
 #ifndef XP_MACOSX
 #define UNIX_BUT_NOT_MAC
@@ -226,10 +230,6 @@ pref("security.content.signature.root_hash", "[CONTENT SIGNING DISABLED - see bu
 // Show new install UI with permission lists
 pref("extensions.webextOptionalPermissionPrompts", true);
 
-// 1 = allow "Man In The Middle" (local proxy, web filter, etc.) for certificate
-//     pinning checks.
-pref("security.cert_pinning.enforcement_level", 1);
-
 // Whether to use client certificates stored in OS certificate storage.
 // This does not work for S/MIME. See bug 1726442.
 pref("security.osclientcerts.autoload", false);
@@ -277,8 +277,6 @@ pref("general.autoScroll", true);
 pref("mail.shell.checkDefaultClient", true);
 pref("mail.spellcheck.inline", true);
 
-pref("mail.folder.views.version", 0);
-
 // Force the unit shown for the size of all folders. If empty, the unit
 // is determined automatically for each folder. Allowed values: KB/MB/<empty string>
 pref("mail.folderpane.sizeUnits", "");
@@ -334,7 +332,6 @@ pref("mail.showCondensedAddresses", true); // show the friendly display name for
 pref("mailnews.attachments.display.start_expanded", false);
 // hidden pref for changing how we present attachments in the message pane
 pref("mail.pane_config.dynamic", 2);
-pref("mailnews.reuse_thread_window2",     true);
 pref("editor.singleLine.pasteNewlines", 4);  // substitute commas for new lines in single line text boxes
 pref("editor.CR_creates_new_p", true);
 pref("mail.compose.default_to_paragraph", true);
@@ -374,8 +371,6 @@ pref("mail.forward_message_mode", 2);
 
 pref("mailnews.send.loglevel", "Warn");
 
-pref("mail.import.in_new_tab", true);
-
 // End core mailnews.js pref overrides
 /////////////////////////////////////////////////////////////////
 
@@ -486,8 +481,6 @@ pref("browser.display.auto_quality_min_font_size", 0);
 
 pref("view_source.syntax_highlight", false);
 
-pref("dom.serviceWorkers.enabled", true);
-
 /////////////////////////////////////////////////////////////////
 // End core all.js pref overrides
 /////////////////////////////////////////////////////////////////
@@ -537,10 +530,6 @@ pref("alerts.useSystemBackend", false);
 
 // analyze urls in mail messages for scams
 pref("mail.phishing.detection.enabled", true);
-// If phishing detection is enabled, allow fine grained control
-// of the local, static tests
-pref("mail.phishing.detection.ipaddresses", true);
-pref("mail.phishing.detection.mismatched_hosts", true);
 pref("mail.phishing.detection.disallow_form_actions", true);
 
 pref("browser.safebrowsing.reportPhishURL", "https://%LOCALE%.phish-report.mozilla.com/?hl=%LOCALE%");
@@ -553,7 +542,6 @@ pref("dom.disable_window_status_change",          true);
 // 1 - open it in an existing window
 // 2 - open it in a new tab
 pref("mail.openMessageBehavior", 2);
-pref("mail.openMessageBehavior.version", 0);
 // If messages or folders are opened using the context menu or a middle click,
 // should we open them in the foreground or in the background?
 pref("mail.tabs.loadInBackground", true);
@@ -756,13 +744,8 @@ pref("browser.link.open_newwindow.restriction", 0);
 
 pref("browser.tabs.loadDivertedInBackground", false);
 
-// Enable multi-process.
-pref("browser.tabs.remote.autostart", true);
-pref("browser.tabs.remote.desktopbehavior", true);
 pref("extensions.webextensions.remote", true);
 
-pref("extensions.webextensions.background-delayed-startup", true);
-
 // Browser icon prefs
 pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", true);
@@ -821,6 +804,7 @@ pref("mail.taskbar.lists.tasks.enabled", true);
 pref("mail.provider.providerList", "https://broker.thunderbird.net/provider/list");
 pref("mail.provider.suggestFromName", "https://broker.thunderbird.net/provider/suggest");
 pref("mail.provider.enabled", true);
+pref("mail.provider.loglevel", "Warn");
 
 pref("mail.chat.enabled", true);
 // Whether to show chat notifications or not.
@@ -886,10 +870,8 @@ pref("mail.main_menu.collapse_by_default", true);
 // instead of space in the file name.
 pref("mail.save_msg_filename_underscores_for_space", false);
 
-#ifdef NIGHTLY_BUILD
 // See bug 1572568 for details. Disallow eval() with system principal.
 pref("security.allow_eval_with_system_principal", false);
-#endif
 
 // Enable FIDO U2F
 pref("security.webauth.u2f", true);
@@ -1080,8 +1062,6 @@ pref("devtools.netmonitor.features.requestBlocking", true);
 pref("devtools.application.enabled", false);
 
 // Enable the custom formatters feature
-// TODO remove once the custom formatters feature is stable (see bug 1734614)
-pref("devtools.custom-formatters", false);
 // This preference represents the user's choice to enable the custom formatters feature.
 // While the preference above will be removed once the feature is stable, this one is menat to stay.
 pref("devtools.custom-formatters.enabled", false);
@@ -1412,14 +1392,9 @@ pref("services.sync.engine.prefs", false);
 #endif
 
 // Donation appeal.
-pref("app.donation.eoy.version", 5);
+pref("app.donation.eoy.version", 4);
 pref("app.donation.eoy.version.viewed", 0);
-pref("app.donation.eoy.url", "https://www.thunderbird.net/thunderbird/115.0/spring24/");
-
-// Survey
-pref("app.survey.version", 1);
-pref("app.survey.version.viewed", 0);
-pref("app.survey.url", "https://www.thunderbird.net/survey/?utm_campaign=survey-May_24");
+pref("app.donation.eoy.url", "https://www.thunderbird.net/thunderbird/115.0/holidayeoy/");
 
 // IMAP-JS disabled, Bug 1707547.
 pref("mailnews.imap.jsmodule", false);
@@ -1431,3 +1406,7 @@ pref("mailnews.imap.jsmodule", false);
 // 2: icons only
 // 3: text only
 pref("toolbar.unifiedtoolbar.buttonstyle", 0);
+
+// Bug 1773079 : check if true causes issues for Thunderbird
+// prevent JS from monkeying with window focus, etc
+pref("dom.disable_window_flip", true);
