@@ -2,41 +2,40 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at http://mozilla.org/MPL/2.0/. */
 
-const { MessageGenerator } = ChromeUtils.import(
-  "resource://testing-common/mailnews/MessageGenerator.jsm"
+const { MessageGenerator } = ChromeUtils.importESModule(
+  "resource://testing-common/mailnews/MessageGenerator.sys.mjs"
 );
-const { PromiseTestUtils } = ChromeUtils.import(
-  "resource://testing-common/mailnews/PromiseTestUtils.jsm"
+const { PromiseTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/mailnews/PromiseTestUtils.sys.mjs"
 );
 
-let tabmail = document.getElementById("tabmail");
-let about3Pane = tabmail.currentAbout3Pane;
-let threadTree = about3Pane.threadTree;
+const tabmail = document.getElementById("tabmail");
+const about3Pane = tabmail.currentAbout3Pane;
+const threadTree = about3Pane.threadTree;
 // Not `currentAboutMessage` as (a) that's null right now, and (b) we'll be
 // testing things that happen when about:message is hidden.
-let aboutMessage = about3Pane.messageBrowser.contentWindow;
-let messagePaneBrowser = aboutMessage.getMessagePaneBrowser();
+const aboutMessage = about3Pane.messageBrowser.contentWindow;
+const messagePaneBrowser = aboutMessage.getMessagePaneBrowser();
 let rootFolder, folderA, folderB, trashFolder, sourceMessages, sourceMessageIDs;
 
 add_setup(async function () {
-  let generator = new MessageGenerator();
+  const generator = new MessageGenerator();
 
-  MailServices.accounts.createLocalMailAccount();
-  let account = MailServices.accounts.accounts[0];
+  const account = MailServices.accounts.createLocalMailAccount();
   account.addIdentity(MailServices.accounts.createIdentity());
-  rootFolder = account.incomingServer.rootFolder;
+  rootFolder = account.incomingServer.rootFolder.QueryInterface(
+    Ci.nsIMsgLocalMailFolder
+  );
 
-  rootFolder.createSubfolder("threadTreeQuirksA", null);
   folderA = rootFolder
-    .getChildNamed("threadTreeQuirksA")
+    .createLocalSubfolder("threadTreeQuirksA")
     .QueryInterface(Ci.nsIMsgLocalMailFolder);
 
-  rootFolder.createSubfolder("threadTreeQuirksB", null);
-  folderB = rootFolder.getChildNamed("threadTreeQuirksB");
+  folderB = rootFolder.createLocalSubfolder("threadTreeQuirksB");
   trashFolder = rootFolder.getFolderWithFlags(Ci.nsMsgFolderFlags.Trash);
 
   // Make some messages, then change their dates to simulate a different order.
-  let syntheticMessages = generator.makeMessages({
+  const syntheticMessages = generator.makeMessages({
     count: 15,
     msgsPerThread: 5,
   });
@@ -46,7 +45,7 @@ add_setup(async function () {
   syntheticMessages[4].date = generator.makeDate();
 
   folderA.addMessageBatch(
-    syntheticMessages.map(message => message.toMboxString())
+    syntheticMessages.map(message => message.toMessageString())
   );
   sourceMessages = [...folderA.messages];
   sourceMessageIDs = sourceMessages.map(m => m.messageId);
@@ -74,14 +73,14 @@ add_task(async function testExpandCollapseUpdates() {
     about3Pane
   );
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 11, "thread collapsed");
-  Assert.equal(threadTree.selectedIndex, 5, "thread root still selected");
+  // Thread root still selected.
+  await validateTree(11, [5], 5);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.messageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.messageBrowser),
     "messageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became visible"
   );
 
@@ -93,31 +92,30 @@ add_task(async function testExpandCollapseUpdates() {
     about3Pane
   );
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 15, "thread expanded");
-  Assert.equal(threadTree.selectedIndex, 5, "thread root still selected");
+  await messageLoaded(10);
+  await validateTree(15, [5], 5);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.messageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.messageBrowser),
     "messageBrowser became visible"
   );
-  await messageLoaded(10);
 
   // Collapsing all rows while the first message in a thread is selected should
   // update the message display.
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_collapseAllThreads");
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 3, "all threads collapsed");
-  Assert.equal(threadTree.selectedIndex, 1, "thread root still selected");
+  // Thread root still selected.
+  await validateTree(3, [1], 1);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.messageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.messageBrowser),
     "messageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became visible"
   );
 
@@ -126,17 +124,16 @@ add_task(async function testExpandCollapseUpdates() {
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_expandAllThreads");
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 15, "all threads expanded");
-  Assert.equal(threadTree.selectedIndex, 5, "thread root still selected");
+  await messageLoaded(10);
+  await validateTree(15, [5], 5);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.messageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.messageBrowser),
     "messageBrowser became visible"
   );
-  await messageLoaded(10);
 
   // Collapsing all rows while a message inside a thread is selected should
   // select the first message in the thread and update the message display.
@@ -146,14 +143,14 @@ add_task(async function testExpandCollapseUpdates() {
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_collapseAllThreads");
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 3, "all threads collapsed");
-  Assert.equal(threadTree.selectedIndex, 0, "thread root became selected");
+  // Thread root became selected.
+  await validateTree(3, [0], 0);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.messageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.messageBrowser),
     "messageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became visible"
   );
 
@@ -162,46 +159,41 @@ add_task(async function testExpandCollapseUpdates() {
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_expandAllThreads");
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 15, "all threads expanded");
-  Assert.equal(threadTree.selectedIndex, 0, "thread root still selected");
+  await messageLoaded(5);
+  await validateTree(15, [0], 0);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.messageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.messageBrowser),
     "messageBrowser became visible"
   );
-  await messageLoaded(5);
 
   // Select several things and collapse all.
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   threadTree.selectedIndices = [2, 3, 5];
   await selectPromise;
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.messageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.messageBrowser),
     "messageBrowser became hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.multiMessageBrowser),
     "multiMessageBrowser became visible"
   );
 
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_collapseAllThreads");
   await selectPromise;
-  Assert.equal(threadTree.view.rowCount, 3, "all threads collapsed");
-  Assert.deepEqual(
-    threadTree.selectedIndices,
-    [0, 1],
-    "thread roots became selected"
-  );
+  // Thread roots became selected.
+  await validateTree(3, [0, 1], 1);
   Assert.ok(
-    BrowserTestUtils.is_hidden(about3Pane.messageBrowser),
+    BrowserTestUtils.isHidden(about3Pane.messageBrowser),
     "messageBrowser stayed hidden"
   );
   Assert.ok(
-    BrowserTestUtils.is_visible(about3Pane.multiMessageBrowser),
+    BrowserTestUtils.isVisible(about3Pane.multiMessageBrowser),
     "multiMessageBrowser stayed visible"
   );
 });
@@ -223,7 +215,8 @@ add_task(async function testThreadUpdateKeepsSelection() {
   threadTree.addEventListener("select", reportBadSelectEvent);
   messagePaneBrowser.addEventListener("load", reportBadLoad, true);
   await move([sourceMessages[1]], folderA, folderB);
-  Assert.equal(threadTree.selectedIndex, 0, "selection should have moved");
+  // Selection should have moved.
+  await validateTree(2, [0], 0);
   Assert.equal(
     aboutMessage.gMessage.messageId,
     sourceMessageIDs[5],
@@ -247,48 +240,48 @@ add_task(async function testArchiveDeleteUpdates() {
   });
   about3Pane.sortController.sortUnthreaded();
 
-  threadTree.focus();
+  threadTree.table.body.focus();
   threadTree.selectedIndex = 3;
   await messageLoaded(7);
 
   let selectCount = 0;
-  let onSelect = () => selectCount++;
+  const onSelect = () => selectCount++;
   threadTree.addEventListener("select", onSelect);
 
   let selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_delete");
   await selectPromise;
-  Assert.equal(selectCount, 1, "'select' event should've happened only once");
-  Assert.equal(threadTree.selectedIndex, 3, "selection should have updated");
   await messageLoaded(8);
+  await validateTree(14, [3], 3);
+  Assert.equal(selectCount, 1, "'select' event should've happened only once");
 
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_delete");
   await selectPromise;
-  Assert.equal(selectCount, 2, "'select' event should've happened only once");
-  Assert.equal(threadTree.selectedIndex, 3, "selection should have updated");
   await messageLoaded(9);
+  await validateTree(13, [3], 3);
+  Assert.equal(selectCount, 2, "'select' event should've happened only once");
 
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_archive");
   await selectPromise;
-  Assert.equal(selectCount, 3, "'select' event should've happened only once");
-  Assert.equal(threadTree.selectedIndex, 3, "selection should have updated");
   await messageLoaded(10);
+  await validateTree(12, [3], 3);
+  Assert.equal(selectCount, 3, "'select' event should've happened only once");
 
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_archive");
   await selectPromise;
-  Assert.equal(selectCount, 4, "'select' event should've happened only once");
-  Assert.equal(threadTree.selectedIndex, 3, "selection should have updated");
   await messageLoaded(11);
+  await validateTree(11, [3], 3);
+  Assert.equal(selectCount, 4, "'select' event should've happened only once");
 
   selectPromise = BrowserTestUtils.waitForEvent(threadTree, "select");
   goDoCommand("cmd_delete");
   await selectPromise;
-  Assert.equal(selectCount, 5, "'select' event should've happened only once");
-  Assert.equal(threadTree.selectedIndex, 3, "selection should have updated");
   await messageLoaded(12);
+  await validateTree(10, [3], 3);
+  Assert.equal(selectCount, 5, "'select' event should've happened only once");
 
   threadTree.removeEventListener("select", onSelect);
 
@@ -305,13 +298,14 @@ add_task(async function testMessagePaneSelection() {
   about3Pane.sortController.sortThreadPane("byDate");
   about3Pane.sortController.sortDescending();
 
-  threadTree.focus();
+  threadTree.table.body.focus();
   threadTree.selectedIndex = 1;
   await messageLoaded(7);
+  await validateTree(3, [1], 1);
 
   // Check the initial selection in about:message.
   Assert.equal(aboutMessage.gDBView.selection.getRangeCount(), 1);
-  let min = {},
+  const min = {},
     max = {};
   aboutMessage.gDBView.selection.getRangeAt(0, min, max);
   Assert.equal(min.value, 1);
@@ -321,6 +315,7 @@ add_task(async function testMessagePaneSelection() {
   threadTree.addEventListener("select", reportBadSelectEvent);
   messagePaneBrowser.addEventListener("load", reportBadLoad, true);
   await move(sourceMessages.slice(9, 10), folderA, folderB);
+  await validateTree(4, [2], 2);
 
   Assert.deepEqual(
     Array.from(folderB.messages, m => m.messageId),
@@ -341,11 +336,11 @@ add_task(async function testMessagePaneSelection() {
   messagePaneBrowser.removeEventListener("load", reportBadLoad, true);
 
   // Now click the delete button in about:message.
-  let deletePromise = PromiseTestUtils.promiseFolderEvent(
+  const deletePromise = PromiseTestUtils.promiseFolderEvent(
     folderB,
     "DeleteOrMoveMsgCompleted"
   );
-  let loadPromise = messageLoaded(6);
+  const loadPromise = messageLoaded(6);
   EventUtils.synthesizeMouseAtCenter(
     aboutMessage.document.getElementById("hdrTrashButton"),
     {},
@@ -365,6 +360,8 @@ add_task(async function testMessagePaneSelection() {
     "the right messages were kept"
   );
 
+  await validateTree(3, [2], 2);
+
   // Check the selection in about:message again.
   Assert.equal(aboutMessage.gDBView.selection.getRangeCount(), 1);
   aboutMessage.gDBView.selection.getRangeAt(0, min, max);
@@ -375,11 +372,13 @@ add_task(async function testMessagePaneSelection() {
 });
 
 add_task(async function testNonSelectionContextMenu() {
-  let mailContext = about3Pane.document.getElementById("mailContext");
-  let openNewTabItem = about3Pane.document.getElementById(
+  const mailContext = about3Pane.document.getElementById("mailContext");
+  const openNewTabItem = about3Pane.document.getElementById(
     "mailContext-openNewTab"
   );
-  let replyItem = about3Pane.document.getElementById("mailContext-replySender");
+  const replyItem = about3Pane.document.getElementById(
+    "mailContext-replySender"
+  );
 
   about3Pane.restoreState({
     messagePaneVisible: true,
@@ -388,8 +387,9 @@ add_task(async function testNonSelectionContextMenu() {
   about3Pane.sortController.sortUnthreaded();
   threadTree.scrollToIndex(0, true);
 
-  threadTree.selectedIndices = [0];
+  threadTree.selectedIndex = 0;
   await messageLoaded(0);
+  await validateTree(15, [0], 0);
   await subtestOpenTab(1, sourceMessageIDs[5]);
   await subtestReply(6, sourceMessageIDs[10]);
 
@@ -402,14 +402,19 @@ add_task(async function testNonSelectionContextMenu() {
   await subtestOpenTab(0, sourceMessageIDs[0]);
 
   async function doContextMenu(testIndex, messageId, itemToActivate) {
-    let originalSelection = threadTree.selectedIndices;
+    const originalSelection = threadTree.selectedIndices;
 
     threadTree.addEventListener("select", reportBadSelectEvent);
     messagePaneBrowser.addEventListener("load", reportBadLoad, true);
 
-    let shownPromise = BrowserTestUtils.waitForEvent(mailContext, "popupshown");
+    const shownPromise = BrowserTestUtils.waitForEvent(
+      mailContext,
+      "popupshown"
+    );
     EventUtils.synthesizeMouseAtCenter(
-      threadTree.getRowAtIndex(testIndex).querySelector(".subjectcol-column"),
+      threadTree
+        .getRowAtIndex(testIndex)
+        .querySelector(".thread-card-subject-container"),
       { type: "contextmenu" },
       about3Pane
     );
@@ -421,8 +426,21 @@ add_task(async function testNonSelectionContextMenu() {
       [testIndex],
       "selection should be only the right-clicked-on row"
     );
+    const contextTargetRows = threadTree.querySelectorAll(
+      ".context-menu-target"
+    );
+    Assert.equal(
+      contextTargetRows.length,
+      1,
+      "one row should have .context-menu-target"
+    );
+    Assert.equal(
+      contextTargetRows[0].index,
+      testIndex,
+      "correct row has .context-menu-target"
+    );
 
-    let hiddenPromise = BrowserTestUtils.waitForEvent(
+    const hiddenPromise = BrowserTestUtils.waitForEvent(
       mailContext,
       "popuphidden"
     );
@@ -430,10 +448,22 @@ add_task(async function testNonSelectionContextMenu() {
     await hiddenPromise;
 
     Assert.ok(!about3Pane.mailContextMenu.selectionIsOverridden);
-    Assert.deepEqual(
+    Assert.equal(
+      document.activeElement,
+      tabmail.tabInfo[0].chromeBrowser,
+      "about:3pane should have focus after context menu"
+    );
+    Assert.equal(
+      about3Pane.document.activeElement,
+      threadTree.table.body,
+      "table body should have focus after context menu"
+    );
+
+    // Selection should be restored.
+    await validateTree(
+      15,
       threadTree.selectedIndices,
-      originalSelection,
-      "selection should be restored"
+      originalSelection.at(-1)
     );
 
     // Wait to prove unwanted selection or load didn't happen.
@@ -446,7 +476,7 @@ add_task(async function testNonSelectionContextMenu() {
 
   // Opening a new tab should open the clicked-on message, not the selected.
   async function subtestOpenTab(testIndex, messageId) {
-    let newAboutMessagePromise = BrowserTestUtils.waitForEvent(
+    const newAboutMessagePromise = BrowserTestUtils.waitForEvent(
       tabmail,
       "aboutMessageLoaded"
     ).then(async function (event) {
@@ -457,7 +487,7 @@ add_task(async function testNonSelectionContextMenu() {
     });
     await doContextMenu(testIndex, messageId, openNewTabItem);
 
-    let newAboutMessage = await newAboutMessagePromise;
+    const newAboutMessage = await newAboutMessagePromise;
     Assert.equal(
       newAboutMessage.gMessage.messageId,
       messageId,
@@ -482,11 +512,11 @@ add_task(async function testNonSelectionContextMenu() {
       .getSelection()
       .selectAllChildren(messagePaneBrowser.contentDocument.body);
 
-    let composeWindowPromise = BrowserTestUtils.domWindowOpenedAndLoaded();
+    const composeWindowPromise = BrowserTestUtils.domWindowOpenedAndLoaded();
     await doContextMenu(testIndex, messageId, replyItem);
-    let composeWindow = await composeWindowPromise;
-    let composeEditor = composeWindow.GetCurrentEditorElement();
-    let composeBody = await TestUtils.waitForCondition(
+    const composeWindow = await composeWindowPromise;
+    const composeEditor = composeWindow.GetCurrentEditorElement();
+    const composeBody = await TestUtils.waitForCondition(
       () => composeEditor.contentDocument.body.textContent
     );
 
@@ -504,6 +534,70 @@ add_task(async function testNonSelectionContextMenu() {
   }
 });
 
+add_task(async function testThreadTreeA11yRoles() {
+  Assert.equal(
+    threadTree.table.body.getAttribute("role"),
+    "listbox",
+    "The tree view should be presented as ListBox"
+  );
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.getRowAtIndex(0),
+    "row0 should become available"
+  );
+  Assert.equal(
+    threadTree.getRowAtIndex(0).getAttribute("role"),
+    "option",
+    "The message row should be presented as Option"
+  );
+
+  about3Pane.sortController.sortThreaded();
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.dataset.showGroupedBySort == "false",
+    "The tree view should not be grouped by sort"
+  );
+
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.table.body.getAttribute("role") == "treegrid",
+    "The tree view should switch to a Tree Grid View role"
+  );
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.getRowAtIndex(0),
+    "row0 should become available"
+  );
+  Assert.equal(
+    threadTree.getRowAtIndex(0).getAttribute("role"),
+    "row",
+    "The message row should be presented as Row"
+  );
+
+  about3Pane.sortController.groupBySort();
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.dataset.showGroupedBySort == "true",
+    "The tree view should be grouped by sort"
+  );
+  threadTree.scrollToIndex(0, true);
+
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.table.body.getAttribute("role") == "treegrid",
+    "The message list table should remain presented as Tree Grid View"
+  );
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.getRowAtIndex(0),
+    "row0 should become available"
+  );
+  Assert.equal(
+    threadTree.getRowAtIndex(0).getAttribute("role"),
+    "row",
+    "The first dummy message row should be presented as Row"
+  );
+
+  about3Pane.sortController.sortUnthreaded();
+  await BrowserTestUtils.waitForCondition(
+    () => threadTree.dataset.showGroupedBySort == "false",
+    "The tree view should not be grouped by sort"
+  );
+});
+
 async function messageLoaded(index) {
   await BrowserTestUtils.browserLoaded(messagePaneBrowser);
   Assert.equal(
@@ -513,8 +607,51 @@ async function messageLoaded(index) {
   );
 }
 
+async function validateTree(rowCount, selectedIndices, currentIndex) {
+  Assert.equal(threadTree.view.rowCount, rowCount, "row count of view");
+  await TestUtils.waitForCondition(
+    () => threadTree.table.body.rows.length == rowCount,
+    "waiting table row count to match the view's row count"
+  );
+
+  Assert.deepEqual(
+    threadTree.selectedIndices,
+    selectedIndices,
+    "table's selected indices"
+  );
+  const selectedRows = Array.from(threadTree.querySelectorAll(".selected"));
+  Assert.equal(
+    selectedRows.length,
+    selectedIndices.length,
+    "number of rows with .selected class"
+  );
+  for (const index of selectedIndices) {
+    const row = threadTree.getRowAtIndex(index);
+    Assert.ok(
+      selectedRows.includes(row),
+      `.selected row at ${index} is expected`
+    );
+  }
+
+  Assert.equal(threadTree.currentIndex, currentIndex, "table's current index");
+  const currentRows = threadTree.querySelectorAll(".current");
+  Assert.equal(currentRows.length, 1, "one row should have .current");
+  Assert.equal(
+    currentRows[0],
+    threadTree.getRowAtIndex(currentIndex),
+    ".current row is expected"
+  );
+
+  const contextTargetRows = threadTree.querySelectorAll(".context-menu-target");
+  Assert.equal(
+    contextTargetRows.length,
+    0,
+    "no rows should have .context-menu-target"
+  );
+}
+
 async function move(messages, source, dest) {
-  let copyListener = new PromiseTestUtils.PromiseCopyListener();
+  const copyListener = new PromiseTestUtils.PromiseCopyListener();
   MailServices.copy.copyMessages(
     source,
     messages,
@@ -543,11 +680,11 @@ function reportBadLoad() {
 async function restoreMessages() {
   // Move all of the messages back to folder A.
   await move([...folderB.messages], folderB, folderA);
-  let archiveFolder = rootFolder.getFolderWithFlags(
+  const archiveFolder = rootFolder.getFolderWithFlags(
     Ci.nsMsgFolderFlags.Archive
   );
   if (archiveFolder) {
-    for (let folder of archiveFolder.subFolders) {
+    for (const folder of archiveFolder.subFolders) {
       await move([...folder.messages], folder, folderA);
     }
   }
@@ -560,43 +697,3 @@ async function restoreMessages() {
       sourceMessageIDs.indexOf(b.messageId)
   );
 }
-
-add_task(async function testThreadTreeA11yRoles() {
-  Assert.equal(
-    threadTree.table.body.getAttribute("role"),
-    "listbox",
-    "The tree view should be presented as ListBox"
-  );
-  Assert.equal(
-    threadTree.getRowAtIndex(0).getAttribute("role"),
-    "option",
-    "The message row should be presented as Option"
-  );
-
-  about3Pane.sortController.sortThreaded();
-
-  await BrowserTestUtils.waitForCondition(
-    () => threadTree.table.body.getAttribute("role") == "tree",
-    "The tree view should switch to a Tree View role"
-  );
-  Assert.equal(
-    threadTree.getRowAtIndex(0).getAttribute("role"),
-    "treeitem",
-    "The message row should be presented as Tree Item"
-  );
-
-  about3Pane.sortController.groupBySort();
-  threadTree.scrollToIndex(0, true);
-
-  await BrowserTestUtils.waitForCondition(
-    () => threadTree.table.body.getAttribute("role") == "tree",
-    "The message list table should remain presented as Tree View"
-  );
-  Assert.equal(
-    threadTree.getRowAtIndex(0).getAttribute("role"),
-    "treeitem",
-    "The first dummy message row should be presented as Tree Item"
-  );
-
-  about3Pane.sortController.sortUnthreaded();
-});
