@@ -1,5 +1,5 @@
 // Set some prefs that apply to all the tests in this file.
-add_setup(async function() {
+add_setup(async function () {
   await SpecialPowers.pushPrefEnv({
     set: [
       // We don't have pre-pinned certificates for the local mochitest server.
@@ -29,7 +29,7 @@ async function testUpdateNoPrompt(
   is(addon.version, initialVersion, "Version 1 of the addon is installed");
 
   // Go to Extensions in about:addons
-  let win = await openAddonsMgr("addons://list/extension");
+  const win = await openAddonsMgr("addons://list/extension");
 
   await waitAboutAddonsViewLoaded(win.document);
 
@@ -40,7 +40,7 @@ async function testUpdateNoPrompt(
   PopupNotifications.panel.addEventListener("popupshown", popupListener);
 
   // Trigger an update check, we should see the update get applied
-  let updatePromise = waitForUpdate(addon);
+  const updatePromise = waitForUpdate(addon);
   triggerPageOptionsAction(win, "check-for-updates");
   await updatePromise;
 
@@ -50,7 +50,7 @@ async function testUpdateNoPrompt(
   ok(!sawPopup, "Should not have seen a permission notification");
   PopupNotifications.panel.removeEventListener("popupshown", popupListener);
 
-  let tabmail = document.getElementById("tabmail");
+  const tabmail = document.getElementById("tabmail");
   tabmail.closeTab(tabmail.currentTabInfo);
   await addon.uninstall();
 }
@@ -59,7 +59,7 @@ async function testUpdateNoPrompt(
 // are added.
 add_task(() =>
   testUpdateNoPrompt(
-    "browser_webext_update_perms1.xpi",
+    "addons/browser_webext_update_perms1.xpi",
     "update_perms@tests.mozilla.org"
   )
 );
@@ -68,7 +68,7 @@ add_task(() =>
 // showing a notification prompt.
 add_task(() =>
   testUpdateNoPrompt(
-    "browser_webext_update_origins1.xpi",
+    "addons/browser_webext_update_origins1.xpi",
     "update_origins@tests.mozilla.org"
   )
 );
@@ -76,7 +76,7 @@ add_task(() =>
 // Test that an Experiment is not prompting for additional permissions.
 add_task(() =>
   testUpdateNoPrompt(
-    "browser_webext_experiment.xpi",
+    "addons/browser_webext_experiment.xpi",
     "experiment_test@tests.mozilla.org"
   )
 );
