@@ -8,7 +8,6 @@
  */
 
 "use strict";
-
 var { MailServices } = ChromeUtils.import(
   "resource:///modules/MailServices.jsm"
 );
@@ -16,26 +15,95 @@ var { MailServices } = ChromeUtils.import(
 var {
   close_compose_window,
   open_compose_new_mail,
+  open_compose_with_reply_to_all,
   setup_msg_contents,
-} = ChromeUtils.import("resource://testing-common/mozmill/ComposeHelpers.jsm");
-var { close_window } = ChromeUtils.import(
-  "resource://testing-common/mozmill/WindowHelpers.jsm"
+} = ChromeUtils.importESModule(
+  "resource://testing-common/mozmill/ComposeHelpers.sys.mjs"
+);
+var {
+  add_message_to_folder,
+  assert_selected_and_displayed,
+  be_in_folder,
+  create_message,
+  select_click_row,
+} = ChromeUtils.importESModule(
+  "resource://testing-common/mozmill/FolderDisplayHelpers.sys.mjs"
 );
 
-let publicRecipientLimit = Services.prefs.getIntPref(
+const publicRecipientLimit = Services.prefs.getIntPref(
   "mail.compose.warn_public_recipients.threshold"
 );
 
 requestLongerTimeout(5);
 
+/**
+ * Test we only show one warning when "To" recipients goes over the limit
+ * for a reply all.
+ */
+add_task(async function testWarningShowsOnceWhenToFieldOverLimit() {
+  // Now set up an account with some identities.
+  const account = MailServices.accounts.createAccount();
+  account.incomingServer = MailServices.accounts.createIncomingServer(
+    "nobody",
+    "BCC Reply Testing",
+    "pop3"
+  );
+
+  const folder = account.incomingServer.rootFolder
+    .QueryInterface(Ci.nsIMsgLocalMailFolder)
+    .createLocalSubfolder("Msgs4Reply");
+
+  const identity = MailServices.accounts.createIdentity();
+  identity.email = "bcc@example.com";
+  account.addIdentity(identity);
+
+  registerCleanupFunction(() => {
+    MailServices.accounts.removeAccount(account, true);
+  });
+
+  let i = 1;
+  const msg0 = create_message({
+    from: "Homer <homer@example.com>",
+    to: "test@example.org,"
+      .repeat(publicRecipientLimit + 100)
+      .replace(/test@/g, () => `test${i++}@`),
+    cc: "Lisa <lisa@example.com>",
+    subject: "msg over the limit for bulk warning",
+  });
+  await add_message_to_folder([folder], msg0);
+
+  await be_in_folder(folder);
+  const msg = await select_click_row(0);
+  await assert_selected_and_displayed(window, msg);
+  const cwc = await open_compose_with_reply_to_all();
+
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warning shown when "To" recipients >= ${publicRecipientLimit}`
+  );
+
+  Assert.equal(
+    1,
+    cwc.document.querySelectorAll(
+      `notification-message[value="warnPublicRecipientsNotification"]`
+    ).length,
+    "should have exactly one notification about it"
+  );
+
+  await close_compose_window(cwc);
+});
+
 /**
  * Test the warning displays when the "To" recipients list hits the limit.
  */
 add_task(async function testWarningShowsWhenToFieldHitsLimit() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
   let i = 1;
 
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -44,39 +112,40 @@ add_task(async function testWarningShowsWhenToFieldHitsLimit() {
     ""
   );
 
-  Assert.ok(
-    cwc.window.gComposeNotification.getNotificationWithValue(
-      "warnPublicRecipientsNotification"
-    ),
-    `warning shown when "To" recipients >= ${publicRecipientLimit}`
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warning shown when "To" recipients >= ${publicRecipientLimit}`
   );
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
  * Test the warning displays when the "Cc" recipients list hits the limit.
  */
 add_task(async function testWarningShowsWhenCcFieldHitLimit() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
 
   // Click on the Cc recipient label.
   EventUtils.synthesizeMouseAtCenter(
-    cwc.window.document.getElementById("addr_cc"),
+    cwc.document.getElementById("addr_ccShowAddressRowButton"),
     {},
-    cwc.window
+    cwc
   );
   // The Cc field should now be visible.
   Assert.ok(
-    !cwc.window.document
+    !cwc.document
       .getElementById("ccAddrInput")
-      .closest(".addressingWidgetItem")
+      .closest(".address-row")
       .classList.contains("hidden"),
     "The Cc field is visible"
   );
 
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -86,14 +155,15 @@ add_task(async function testWarningShowsWhenCcFieldHitLimit() {
     "ccAddrInput"
   );
 
-  Assert.ok(
-    cwc.window.gComposeNotification.getNotificationWithValue(
-      "warnPublicRecipientsNotification"
-    ),
-    `warning shown when "Cc" recipients >= ${publicRecipientLimit}`
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warning shown when "Cc" recipients >= ${publicRecipientLimit}`
   );
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -101,10 +171,10 @@ add_task(async function testWarningShowsWhenCcFieldHitLimit() {
  * combined hit the limit.
  */
 add_task(async function testWarningShowsWhenToAndCcFieldHitLimit() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
 
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit - 1)
@@ -115,29 +185,30 @@ add_task(async function testWarningShowsWhenToAndCcFieldHitLimit() {
 
   // Click on the Cc recipient label.
   EventUtils.synthesizeMouseAtCenter(
-    cwc.window.document.getElementById("addr_cc"),
+    cwc.document.getElementById("addr_ccShowAddressRowButton"),
     {},
-    cwc.window
+    cwc
   );
   // The Cc field should now be visible.
   Assert.ok(
-    !cwc.window.document
+    !cwc.document
       .getElementById("ccAddrInput")
-      .closest(".addressingWidgetItem")
+      .closest(".address-row")
       .classList.contains("hidden"),
     "The Cc field is visible"
   );
 
-  setup_msg_contents(cwc, "test@example.org", "", "", "ccAddrInput");
+  await setup_msg_contents(cwc, "test@example.org", "", "", "ccAddrInput");
 
-  Assert.ok(
-    cwc.window.gComposeNotification.getNotificationWithValue(
-      "warnPublicRecipientsNotification"
-    ),
-    `warning shown when "To" and "Cc" recipients >= ${publicRecipientLimit}`
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warning shown "To" and "Cc" recipients >= ${publicRecipientLimit}`
   );
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -145,9 +216,9 @@ add_task(async function testWarningShowsWhenToAndCcFieldHitLimit() {
  * that option.
  */
 add_task(async function testToRecipientsMovedToBcc() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -156,38 +227,39 @@ add_task(async function testToRecipientsMovedToBcc() {
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
-
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.firstElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     publicRecipientLimit,
     "Bcc field populated with addresses"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#toAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#toAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the To field"
@@ -195,7 +267,7 @@ add_task(async function testToRecipientsMovedToBcc() {
 
   await notificationHidden;
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -203,48 +275,50 @@ add_task(async function testToRecipientsMovedToBcc() {
  * address count is over the limit.
  */
 add_task(async function testAllToRecipientsMovedToBccWhenOverLimit() {
-  let cwc = open_compose_new_mail();
-  let limit = publicRecipientLimit + 1;
+  const cwc = await open_compose_new_mail();
+  const limit = publicRecipientLimit + 1;
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,".repeat(limit).replace(/test@/g, () => `test${i++}@`),
     "Testing move to Bcc",
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
 
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.firstElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     limit,
     "Bcc field populated with addresses"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#toAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#toAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the To field"
@@ -252,7 +326,7 @@ add_task(async function testAllToRecipientsMovedToBccWhenOverLimit() {
 
   await notificationHidden;
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -260,25 +334,25 @@ add_task(async function testAllToRecipientsMovedToBccWhenOverLimit() {
  * that option.
  */
 add_task(async function testCcRecipientsMovedToBcc() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
 
   // Click on the Cc recipient label.
   EventUtils.synthesizeMouseAtCenter(
-    cwc.window.document.getElementById("addr_cc"),
+    cwc.document.getElementById("addr_ccShowAddressRowButton"),
     {},
-    cwc.window
+    cwc
   );
   // The Cc field should now be visible.
   Assert.ok(
-    !cwc.window.document
+    !cwc.document
       .getElementById("ccAddrInput")
-      .closest(".addressingWidgetItem")
+      .closest(".address-row")
       .classList.contains("hidden"),
     "The Cc field is visible"
   );
 
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -287,38 +361,40 @@ add_task(async function testCcRecipientsMovedToBcc() {
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
 
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.firstElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     publicRecipientLimit,
     "Bcc field populated with addresses"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the Cc field"
@@ -326,7 +402,7 @@ add_task(async function testCcRecipientsMovedToBcc() {
 
   await notificationHidden;
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -334,64 +410,65 @@ add_task(async function testCcRecipientsMovedToBcc() {
  * address count is over the limit.
  */
 add_task(async function testAllCcRecipientsMovedToBccWhenOverLimit() {
-  let cwc = open_compose_new_mail();
-  let limit = publicRecipientLimit + 1;
+  const cwc = await open_compose_new_mail();
+  const limit = publicRecipientLimit + 1;
 
   // Click on the Cc recipient label.
   EventUtils.synthesizeMouseAtCenter(
-    cwc.window.document.getElementById("addr_cc"),
+    cwc.document.getElementById("addr_ccShowAddressRowButton"),
     {},
-    cwc.window
+    cwc
   );
   // The Cc field should now be visible.
   Assert.ok(
-    !cwc.window.document
+    !cwc.document
       .getElementById("ccAddrInput")
-      .closest(".addressingWidgetItem")
+      .closest(".address-row")
       .classList.contains("hidden"),
     "The Cc field is visible"
   );
 
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,".repeat(limit).replace(/test@/g, () => `test${i++}@`),
     "Testing move to Bcc",
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
-
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.firstElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     limit,
     "Bcc field populated with addresses"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the Cc field"
@@ -399,7 +476,7 @@ add_task(async function testAllCcRecipientsMovedToBccWhenOverLimit() {
 
   await notificationHidden;
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
@@ -407,9 +484,9 @@ add_task(async function testAllCcRecipientsMovedToBccWhenOverLimit() {
  * the user selects that option.
  */
 add_task(async function testToAndCcRecipientsMovedToBcc() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit - 1)
@@ -420,59 +497,61 @@ add_task(async function testToAndCcRecipientsMovedToBcc() {
 
   // Click on the Cc recipient label.
   EventUtils.synthesizeMouseAtCenter(
-    cwc.window.document.getElementById("addr_cc"),
+    cwc.document.getElementById("addr_ccShowAddressRowButton"),
     {},
-    cwc.window
+    cwc
   );
   // The Cc field should now be visible.
   Assert.ok(
-    !cwc.window.document
+    !cwc.document
       .getElementById("ccAddrInput")
-      .closest(".addressingWidgetItem")
+      .closest(".address-row")
       .classList.contains("hidden"),
     "The Cc field is visible"
   );
-  setup_msg_contents(cwc, "test@example.org", "", "");
+  await setup_msg_contents(cwc, "test@example.org", "", "");
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
 
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.firstElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     publicRecipientLimit,
     "Bcc field populated with addresses"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#toAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#toAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the To field"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#ccAddrContainer > mail-address-pill")
       .length,
     0,
     "addresses removed from the Cc field"
@@ -480,16 +559,16 @@ add_task(async function testToAndCcRecipientsMovedToBcc() {
 
   await notificationHidden;
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
  * Test the warning is removed when the user chooses to "Keep Recipients Public".
  */
 add_task(async function testWarningRemovedWhenKeepPublic() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -498,55 +577,56 @@ add_task(async function testWarningRemovedWhenKeepPublic() {
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
-
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
   EventUtils.synthesizeMouseAtCenter(
     notification.buttonContainer.lastElementChild,
     {},
-    cwc.window
+    cwc
   );
 
   await notificationHidden;
 
   Assert.equal(
-    cwc.window.document.querySelectorAll("#toAddrContainer > mail-address-pill")
+    cwc.document.querySelectorAll("#toAddrContainer > mail-address-pill")
       .length,
     publicRecipientLimit,
     "addresses were not removed from the field"
   );
 
   Assert.equal(
-    cwc.window.document.querySelectorAll(
-      "#bccAddrContainer > mail-address-pill"
-    ).length,
+    cwc.document.querySelectorAll("#bccAddrContainer > mail-address-pill")
+      .length,
     0,
     "no addresses added to the Bcc field"
   );
 
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
  * Test that the warning is not shown again if the user dismisses it.
  */
 add_task(async function testWarningNotShownAfterDismissal() {
-  let cwc = open_compose_new_mail();
+  const cwc = await open_compose_new_mail();
   let i = 1;
-  setup_msg_contents(
+  await setup_msg_contents(
     cwc,
     "test@example.org,"
       .repeat(publicRecipientLimit)
@@ -555,54 +635,54 @@ add_task(async function testWarningNotShownAfterDismissal() {
     ""
   );
 
-  let notificationBox = cwc.window.gComposeNotification;
-
-  let notification = notificationBox.getNotificationWithValue(
-    "warnPublicRecipientsNotification"
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
   );
 
-  Assert.ok(notification, "public recipients warning appeared");
-
-  let notificationHidden = BrowserTestUtils.waitForCondition(
+  const notificationHidden = BrowserTestUtils.waitForCondition(
     () =>
-      !notificationBox.getNotificationWithValue(
+      !cwc.gComposeNotification.getNotificationWithValue(
         "warnPublicRecipientsNotification"
       ),
     "public recipients warning was not removed in time"
   );
-
-  EventUtils.synthesizeMouseAtCenter(notification.closeButton, {}, cwc.window);
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
+    "warnPublicRecipientsNotification"
+  );
+  EventUtils.synthesizeMouseAtCenter(notification.closeButtonEl, {}, cwc);
 
   await notificationHidden;
 
-  let input = cwc.window.document.getElementById("toAddrInput");
+  const input = cwc.document.getElementById("toAddrInput");
   input.focus();
 
-  cwc.type(
-    input,
-    "test@example.org,"
-      .repeat(publicRecipientLimit)
-      .replace(/test@/g, () => `test${i++}@`)
-  );
+  const recipString = "test@example.org,"
+    .repeat(publicRecipientLimit)
+    .replace(/test@/g, () => `test${i++}@`);
+  EventUtils.sendString(recipString, cwc);
 
   // Wait a little in case the notification bar mistakenly appears.
   // eslint-disable-next-line mozilla/no-arbitrary-setTimeout
   await new Promise(resolve => setTimeout(resolve, 500));
 
   Assert.ok(
-    !notificationBox.getNotificationWithValue(
+    !cwc.gComposeNotification.getNotificationWithValue(
       "warnPublicRecipientsNotification"
     ),
     "public recipients warning did not appear after dismissal"
   );
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
 
 /**
  * Tests that the individual addresses of a mailing list are considered.
  */
 add_task(async function testMailingListMembersCounted() {
-  let book = MailServices.ab.getDirectoryFromId(
+  const book = MailServices.ab.getDirectoryFromId(
     MailServices.ab.newAddressBook("Mochitest", null, 101)
   );
   let list = Cc["@mozilla.org/addressbook/directoryproperty;1"].createInstance(
@@ -613,7 +693,7 @@ add_task(async function testMailingListMembersCounted() {
   list = book.addMailList(list);
 
   for (let i = 0; i < publicRecipientLimit; i++) {
-    let card = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
+    const card = Cc["@mozilla.org/addressbook/cardproperty;1"].createInstance(
       Ci.nsIAbCard
     );
     card.primaryEmail = `test${i}@example`;
@@ -621,14 +701,20 @@ add_task(async function testMailingListMembersCounted() {
   }
   list.editMailListToDatabase(null);
 
-  let cwc = open_compose_new_mail();
-  setup_msg_contents(cwc, "Test List", "Testing mailing lists", "");
+  const cwc = await open_compose_new_mail();
+  await setup_msg_contents(cwc, "Test List", "Testing mailing lists", "");
 
-  let notification = cwc.window.gComposeNotification.getNotificationWithValue(
+  await BrowserTestUtils.waitForCondition(
+    () =>
+      cwc.gComposeNotification.getNotificationWithValue(
+        "warnPublicRecipientsNotification"
+      ),
+    `Timeout waiting for warnPublicRecipientsNotification`
+  );
+
+  const notification = cwc.gComposeNotification.getNotificationWithValue(
     "warnPublicRecipientsNotification"
   );
-  Assert.ok(notification, "public recipients warning appeared");
-
   Assert.equal(
     notification.messageText.textContent,
     `The ${publicRecipientLimit} recipients in To and Cc will see each other’s address. You can avoid disclosing recipients by using Bcc instead.`,
@@ -636,5 +722,5 @@ add_task(async function testMailingListMembersCounted() {
   );
 
   MailServices.ab.deleteAddressBook(book.URI);
-  close_compose_window(cwc);
+  await close_compose_window(cwc);
 });
