@@ -10,8 +10,8 @@
 
 "use strict";
 
-var { wait_for_content_tab_load } = ChromeUtils.import(
-  "resource://testing-common/mozmill/ContentTabHelpers.jsm"
+var { promise_content_tab_load } = ChromeUtils.importESModule(
+  "resource://testing-common/mozmill/ContentTabHelpers.sys.mjs"
 );
 var {
   add_message_sets_to_folders,
@@ -27,24 +27,25 @@ var {
   make_display_threaded,
   make_display_unthreaded,
   make_message_sets_in_folders,
-  mc,
   press_delete,
   right_click_on_row,
   select_click_row,
   select_control_click_row,
   select_shift_click_row,
   wait_for_popup_to_open,
-} = ChromeUtils.import(
-  "resource://testing-common/mozmill/FolderDisplayHelpers.jsm"
+} = ChromeUtils.importESModule(
+  "resource://testing-common/mozmill/FolderDisplayHelpers.sys.mjs"
 );
-var { click_menus_in_sequence } = ChromeUtils.import(
-  "resource://testing-common/mozmill/WindowHelpers.jsm"
+var { click_menus_in_sequence } = ChromeUtils.importESModule(
+  "resource://testing-common/mozmill/WindowHelpers.sys.mjs"
 );
 
 var { MailServices } = ChromeUtils.import(
   "resource:///modules/MailServices.jsm"
 );
-var { MailUtils } = ChromeUtils.import("resource:///modules/MailUtils.jsm");
+var { MailUtils } = ChromeUtils.importESModule(
+  "resource:///modules/MailUtils.sys.mjs"
+);
 
 var unreadFolder, shiftDeleteFolder, threadDeleteFolder;
 var archiveSrcFolder = null;
@@ -112,16 +113,17 @@ function check_read_status(messages, read) {
  */
 async function check_read_menuitems(index, canMarkRead, canMarkUnread) {
   await right_click_on_row(index);
-  let hiddenPromise = BrowserTestUtils.waitForEvent(
+  const hiddenPromise = BrowserTestUtils.waitForEvent(
     getMailContext(),
     "popuphidden"
   );
   await click_menus_in_sequence(getMailContext(), [{ id: "mailContext-mark" }]);
 
-  let readEnabled = !getMailContext().querySelector("#mailContext-markRead")
-    .disabled;
-  let unreadEnabled = !getMailContext().querySelector("#mailContext-markUnread")
+  const readEnabled = !getMailContext().querySelector("#mailContext-markRead")
     .disabled;
+  const unreadEnabled = !getMailContext().querySelector(
+    "#mailContext-markUnread"
+  ).disabled;
 
   Assert.ok(
     readEnabled == canMarkRead,
@@ -152,19 +154,19 @@ function enable_archiving(enabled) {
  * @param read true the message should be marked read, false otherwise
  */
 async function mark_read_via_menu(index, read) {
-  let menuItem = read ? "mailContext-markRead" : "mailContext-markUnread";
+  const menuItem = read ? "mailContext-markRead" : "mailContext-markUnread";
   await right_click_on_row(index);
   await wait_for_popup_to_open(getMailContext());
   await click_menus_in_sequence(getMailContext(), [
     { id: "mailContext-mark" },
     { id: menuItem },
   ]);
-  await close_popup(mc, getMailContext());
+  await close_popup(window, getMailContext());
 }
 
 add_task(async function test_mark_one_read() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(false);
   await mark_read_via_menu(0, true);
@@ -173,7 +175,7 @@ add_task(async function test_mark_one_read() {
 
 add_task(async function test_mark_one_unread() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(true);
   await mark_read_via_menu(0, false);
@@ -182,8 +184,8 @@ add_task(async function test_mark_one_unread() {
 
 add_task(async function test_mark_n_read() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   for (let i = 0; i < curMessages.length; i++) {
     curMessages[i].markRead(false);
@@ -194,8 +196,8 @@ add_task(async function test_mark_n_read() {
 
 add_task(async function test_mark_n_unread() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   for (let i = 0; i < curMessages.length; i++) {
     curMessages[i].markRead(true);
@@ -206,8 +208,8 @@ add_task(async function test_mark_n_unread() {
 
 add_task(async function test_mark_n_read_mixed() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   curMessages[0].markRead(true);
   curMessages[1].markRead(false);
@@ -222,8 +224,8 @@ add_task(async function test_mark_n_read_mixed() {
 
 add_task(async function test_mark_n_unread_mixed() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   curMessages[0].markRead(false);
   curMessages[1].markRead(true);
@@ -238,7 +240,7 @@ add_task(async function test_mark_n_unread_mixed() {
 
 add_task(async function test_toggle_read() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(false);
   EventUtils.synthesizeKey("m", {});
@@ -247,7 +249,7 @@ add_task(async function test_toggle_read() {
 
 add_task(async function test_toggle_unread() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(true);
   EventUtils.synthesizeKey("m", {});
@@ -256,8 +258,8 @@ add_task(async function test_toggle_unread() {
 
 add_task(async function test_toggle_mixed() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   curMessages[0].markRead(false);
   curMessages[1].markRead(true);
@@ -272,7 +274,7 @@ add_task(async function test_toggle_mixed() {
 
 add_task(async function test_mark_menu_read() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(false);
   await check_read_menuitems(0, true, false);
@@ -280,7 +282,7 @@ add_task(async function test_mark_menu_read() {
 
 add_task(async function test_mark_menu_unread() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   curMessage.markRead(true);
   await check_read_menuitems(0, false, true);
@@ -288,8 +290,8 @@ add_task(async function test_mark_menu_unread() {
 
 add_task(async function test_mark_menu_mixed() {
   await be_in_folder(unreadFolder);
-  select_click_row(0);
-  let curMessages = select_shift_click_row(1);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
 
   curMessages[0].markRead(false);
   curMessages[1].markRead(true);
@@ -299,7 +301,7 @@ add_task(async function test_mark_menu_mixed() {
 
 add_task(async function test_mark_all_read() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
   curMessage.markRead(false);
 
   // Make sure we can mark all read with >0 messages unread.
@@ -309,14 +311,14 @@ add_task(async function test_mark_all_read() {
     { id: "mailContext-mark" },
     { id: "mailContext-markAllRead" },
   ]);
-  await close_popup(mc, getMailContext());
+  await close_popup(window, getMailContext());
 
   Assert.ok(curMessage.isRead, "Message should have been marked read!");
 
   // Make sure we can't mark all read, now that all messages are already read.
   await right_click_on_row(0);
   await wait_for_popup_to_open(getMailContext());
-  let hiddenPromise = BrowserTestUtils.waitForEvent(
+  const hiddenPromise = BrowserTestUtils.waitForEvent(
     getMailContext(),
     "popuphidden"
   );
@@ -324,19 +326,19 @@ add_task(async function test_mark_all_read() {
   await hiddenPromise;
   await new Promise(resolve => requestAnimationFrame(resolve));
 
-  let allReadDisabled = getMailContext().querySelector(
+  const allReadDisabled = getMailContext().querySelector(
     "#mailContext-markAllRead"
   ).disabled;
   Assert.ok(allReadDisabled, "Mark All Read menu item should be disabled!");
 });
 
 add_task(async function test_mark_thread_as_read() {
-  let unreadThreadFolder = await create_folder("UnreadThreadFolder");
+  const unreadThreadFolder = await create_folder("UnreadThreadFolder");
   await add_message_sets_to_folders([unreadThreadFolder], [create_thread(3)]);
   await be_in_folder(unreadThreadFolder);
-  make_display_threaded();
+  await make_display_threaded();
 
-  let serviceState = Services.prefs.getBoolPref(
+  const serviceState = Services.prefs.getBoolPref(
     "mailnews.mark_message_read.auto"
   );
   if (serviceState) {
@@ -349,7 +351,7 @@ add_task(async function test_mark_thread_as_read() {
   await wait_for_popup_to_open(getMailContext());
   await click_menus_in_sequence(getMailContext(), [{ id: "mailContext-mark" }]);
 
-  let markThreadAsReadDisabled = mc.window.document.getElementById(
+  let markThreadAsReadDisabled = document.getElementById(
     "mailContext-markThreadAsRead"
   ).disabled;
   Assert.ok(
@@ -364,9 +366,9 @@ add_task(async function test_mark_thread_as_read() {
     { id: "mailContext-mark" },
     { id: "mailContext-markThreadAsRead" },
   ]);
-  await close_popup(mc, getMailContext());
+  await close_popup(window, getMailContext());
 
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
   Assert.ok(curMessage.isRead, "Message should have been marked read!");
 
   // Make sure Mark Thread as Read is now disabled with all messages read.
@@ -374,7 +376,7 @@ add_task(async function test_mark_thread_as_read() {
   await wait_for_popup_to_open(getMailContext());
   await click_menus_in_sequence(getMailContext(), [{ id: "mailContext-mark" }]);
 
-  markThreadAsReadDisabled = mc.window.document.getElementById(
+  markThreadAsReadDisabled = document.getElementById(
     "mailContext-markThreadAsRead"
   ).disabled;
   Assert.ok(
@@ -388,7 +390,7 @@ add_task(async function test_mark_thread_as_read() {
   await wait_for_popup_to_open(getMailContext());
   await click_menus_in_sequence(getMailContext(), [{ id: "mailContext-mark" }]);
 
-  markThreadAsReadDisabled = mc.window.document.getElementById(
+  markThreadAsReadDisabled = document.getElementById(
     "mailContext-markThreadAsRead"
   ).disabled;
   Assert.ok(
@@ -399,9 +401,77 @@ add_task(async function test_mark_thread_as_read() {
   Services.prefs.setBoolPref("mailnews.mark_message_read.auto", true);
 }).__skipMe = true; // See bug 654362.
 
+add_task(async function roving_multi_message_buttons() {
+  await be_in_folder(unreadFolder);
+  await select_click_row(0);
+  const curMessages = await select_shift_click_row(1);
+  await assert_selected_and_displayed(curMessages);
+
+  const multiMsgView = get_about_3pane().multiMessageBrowser;
+  const BUTTONS_SELECTOR = `toolbarbutton:not([hidden="true"]`;
+  const headerToolbar = multiMsgView.contentDocument.getElementById(
+    "header-view-toolbar"
+  );
+  const headerButtons = headerToolbar.querySelectorAll(BUTTONS_SELECTOR);
+
+  // Press tab while on the message selected to access the multi message view
+  // header buttons.
+  if (
+    !Services.prefs.getBoolPref("dom.disable_tab_focus_to_root_element", true)
+  ) {
+    EventUtils.synthesizeKey("KEY_Tab", {});
+  }
+  EventUtils.synthesizeKey("KEY_Tab", {});
+  Assert.equal(
+    headerButtons[0].id,
+    multiMsgView.contentDocument.activeElement.id,
+    "focused on first msgHdr toolbar button"
+  );
+
+  // Simulate the Arrow Right keypress to make sure the correct button gets the
+  // focus.
+  for (let i = 1; i < headerButtons.length; i++) {
+    const previousElement = document.activeElement;
+    EventUtils.synthesizeKey("KEY_ArrowRight", {});
+    Assert.equal(
+      multiMsgView.contentDocument.activeElement.id,
+      headerButtons[i].id,
+      "The next button is focused"
+    );
+    Assert.ok(
+      multiMsgView.contentDocument.activeElement.tabIndex == 0 &&
+        previousElement.tabIndex == -1,
+      "The roving tab index was updated"
+    );
+  }
+
+  // Simulate the Arrow Left keypress to make sure the correct button gets the
+  // focus.
+  for (let i = headerButtons.length - 2; i > -1; i--) {
+    const previousElement = document.activeElement;
+    EventUtils.synthesizeKey("KEY_ArrowLeft", {});
+    Assert.equal(
+      multiMsgView.contentDocument.activeElement.id,
+      headerButtons[i].id,
+      "The previous button is focused"
+    );
+    Assert.ok(
+      multiMsgView.contentDocument.activeElement.tabIndex == 0 &&
+        previousElement.tabIndex == -1,
+      "The roving tab index was updated"
+    );
+  }
+
+  // Check that once the Escape key is pressed twice, focus will move back to
+  // the selected messages.
+  EventUtils.synthesizeKey("KEY_Escape", {});
+  EventUtils.synthesizeKey("KEY_Escape", {});
+  await assert_selected_and_displayed(curMessages);
+}).__skipMe = AppConstants.platform == "macosx";
+
 add_task(async function test_shift_delete_prompt() {
   await be_in_folder(shiftDeleteFolder);
-  let curMessage = select_click_row(0);
+  let curMessage = await select_click_row(0);
   goUpdateCommand("cmd_shiftDelete");
 
   // First, try shift-deleting and then cancelling at the prompt.
@@ -414,32 +484,32 @@ add_task(async function test_shift_delete_prompt() {
   SimpleTest.ignoreAllUncaughtExceptions(false);
   await dialogPromise;
   // Make sure we didn't actually delete the message.
-  Assert.equal(curMessage, select_click_row(0));
+  Assert.equal(curMessage, await select_click_row(0));
 
   // Second, try shift-deleting and then accepting the deletion.
   dialogPromise = BrowserTestUtils.promiseAlertDialog("accept");
-  press_delete(mc, { shiftKey: true });
+  await press_delete(window, { shiftKey: true });
   await dialogPromise;
   // Make sure we really did delete the message.
-  Assert.notEqual(curMessage, select_click_row(0));
+  Assert.notEqual(curMessage, await select_click_row(0));
 
   // Finally, try shift-deleting when we turned off the prompt.
   Services.prefs.setBoolPref("mail.warn_on_shift_delete", false);
-  curMessage = select_click_row(0);
-  press_delete(mc, { shiftKey: true });
+  curMessage = await select_click_row(0);
+  await press_delete(window, { shiftKey: true });
 
   // Make sure we really did delete the message.
-  Assert.notEqual(curMessage, select_click_row(0));
+  Assert.notEqual(curMessage, await select_click_row(0));
 
   Services.prefs.clearUserPref("mail.warn_on_shift_delete");
 });
 
 add_task(async function test_thread_delete_prompt() {
   await be_in_folder(threadDeleteFolder);
-  make_display_threaded();
-  collapse_all_threads();
+  await make_display_threaded();
+  await collapse_all_threads();
 
-  let curMessage = select_click_row(0);
+  let curMessage = await select_click_row(0);
   goUpdateCommand("cmd_delete");
   // First, try deleting and then cancelling at the prompt.
   Services.prefs.setBoolPref("mail.warn_on_collapsed_thread_operation", true);
@@ -451,22 +521,22 @@ add_task(async function test_thread_delete_prompt() {
   SimpleTest.ignoreAllUncaughtExceptions(false);
   await dialogPromise;
   // Make sure we didn't actually delete the message.
-  Assert.equal(curMessage, select_click_row(0));
+  Assert.equal(curMessage, await select_click_row(0));
 
   // Second, try deleting and then accepting the deletion.
   dialogPromise = BrowserTestUtils.promiseAlertDialog("accept");
-  press_delete(mc);
+  await press_delete(window);
   await dialogPromise;
   // Make sure we really did delete the message.
-  Assert.notEqual(curMessage, select_click_row(0));
+  Assert.notEqual(curMessage, await select_click_row(0));
 
   // Finally, try shift-deleting when we turned off the prompt.
   Services.prefs.setBoolPref("mail.warn_on_collapsed_thread_operation", false);
-  curMessage = select_click_row(0);
-  press_delete(mc);
+  curMessage = await select_click_row(0);
+  await press_delete(window);
 
   // Make sure we really did delete the message.
-  Assert.notEqual(curMessage, select_click_row(0));
+  Assert.notEqual(curMessage, await select_click_row(0));
 
   Services.prefs.clearUserPref("mail.warn_on_collapsed_thread_operation");
 }).skip(); // TODO: not working
@@ -477,53 +547,53 @@ add_task(async function test_yearly_archive() {
 
 async function yearly_archive(keep_structure) {
   await be_in_folder(archiveSrcFolder);
-  make_display_unthreaded();
+  await make_display_unthreaded();
 
-  let win = get_about_3pane();
+  const win = get_about_3pane();
   win.sortController.sortThreadPane("byDate");
   win.sortController.sortAscending();
 
-  let identity = MailServices.accounts.getFirstIdentityForServer(
+  const identity = MailServices.accounts.getFirstIdentityForServer(
     win.gDBView.getMsgHdrAt(0).folder.server
   );
   identity.archiveGranularity = Ci.nsIMsgIdentity.perYearArchiveFolders;
   // We need to get all the info about the messages before we do the archive,
   // because deleting the headers could make extracting values from them fail.
-  let firstMsgHdr = win.gDBView.getMsgHdrAt(0);
-  let lastMsgHdr = win.gDBView.getMsgHdrAt(12);
-  let firstMsgHdrMsgId = firstMsgHdr.messageId;
-  let lastMsgHdrMsgId = lastMsgHdr.messageId;
-  let firstMsgDate = new Date(firstMsgHdr.date / 1000);
-  let firstMsgYear = firstMsgDate.getFullYear().toString();
-  let lastMsgDate = new Date(lastMsgHdr.date / 1000);
-  let lastMsgYear = lastMsgDate.getFullYear().toString();
+  const firstMsgHdr = win.gDBView.getMsgHdrAt(0);
+  const lastMsgHdr = win.gDBView.getMsgHdrAt(12);
+  const firstMsgHdrMsgId = firstMsgHdr.messageId;
+  const lastMsgHdrMsgId = lastMsgHdr.messageId;
+  const firstMsgDate = new Date(firstMsgHdr.date / 1000);
+  const firstMsgYear = firstMsgDate.getFullYear().toString();
+  const lastMsgDate = new Date(lastMsgHdr.date / 1000);
+  const lastMsgYear = lastMsgDate.getFullYear().toString();
 
   win.threadTree.scrollToIndex(0, true);
   await TestUtils.waitForCondition(
     () => win.threadTree.getRowAtIndex(0),
     "Row 0 scrolled into view"
   );
-  select_click_row(0);
+  await select_click_row(0);
   win.threadTree.scrollToIndex(12, true);
   await TestUtils.waitForCondition(
     () => win.threadTree.getRowAtIndex(12),
     "Row 12 scrolled into view"
   );
-  select_control_click_row(12);
+  await select_control_click_row(12);
 
   // Press the archive key. The results should go into two separate years.
-  archive_selected_messages();
+  await archive_selected_messages();
 
   // Figure out where the messages should have gone.
-  let archiveRoot = "mailbox://nobody@Local%20Folders/Archives";
+  const archiveRoot = "mailbox://nobody@Local%20Folders/Archives";
   let firstArchiveUri = archiveRoot + "/" + firstMsgYear;
   let lastArchiveUri = archiveRoot + "/" + lastMsgYear;
   if (keep_structure) {
     firstArchiveUri += "/ArchiveSrc";
     lastArchiveUri += "/ArchiveSrc";
   }
-  let firstArchiveFolder = MailUtils.getOrCreateFolder(firstArchiveUri);
-  let lastArchiveFolder = MailUtils.getOrCreateFolder(lastArchiveUri);
+  const firstArchiveFolder = MailUtils.getOrCreateFolder(firstArchiveUri);
+  const lastArchiveFolder = MailUtils.getOrCreateFolder(lastArchiveUri);
   await be_in_folder(firstArchiveFolder);
   Assert.ok(
     win.gDBView.getMsgHdrAt(0).messageId == firstMsgHdrMsgId,
@@ -549,36 +619,36 @@ add_task(async function test_monthly_archive() {
 async function monthly_archive(keep_structure) {
   await be_in_folder(archiveSrcFolder);
 
-  let win = get_about_3pane();
-  let identity = MailServices.accounts.getFirstIdentityForServer(
+  const win = get_about_3pane();
+  const identity = MailServices.accounts.getFirstIdentityForServer(
     win.gDBView.getMsgHdrAt(0).folder.server
   );
   identity.archiveGranularity = Ci.nsIMsgIdentity.perMonthArchiveFolders;
-  select_click_row(0);
-  select_control_click_row(1);
+  await select_click_row(0);
+  await select_control_click_row(1);
 
-  let firstMsgHdr = win.gDBView.getMsgHdrAt(0);
-  let lastMsgHdr = win.gDBView.getMsgHdrAt(1);
-  let firstMsgHdrMsgId = firstMsgHdr.messageId;
-  let lastMsgHdrMsgId = lastMsgHdr.messageId;
-  let firstMsgDate = new Date(firstMsgHdr.date / 1000);
-  let firstMsgYear = firstMsgDate.getFullYear().toString();
-  let firstMonthFolderName =
+  const firstMsgHdr = win.gDBView.getMsgHdrAt(0);
+  const lastMsgHdr = win.gDBView.getMsgHdrAt(1);
+  const firstMsgHdrMsgId = firstMsgHdr.messageId;
+  const lastMsgHdrMsgId = lastMsgHdr.messageId;
+  const firstMsgDate = new Date(firstMsgHdr.date / 1000);
+  const firstMsgYear = firstMsgDate.getFullYear().toString();
+  const firstMonthFolderName =
     firstMsgYear +
     "-" +
     (firstMsgDate.getMonth() + 1).toString().padStart(2, "0");
-  let lastMsgDate = new Date(lastMsgHdr.date / 1000);
-  let lastMsgYear = lastMsgDate.getFullYear().toString();
-  let lastMonthFolderName =
+  const lastMsgDate = new Date(lastMsgHdr.date / 1000);
+  const lastMsgYear = lastMsgDate.getFullYear().toString();
+  const lastMonthFolderName =
     lastMsgYear +
     "-" +
     (lastMsgDate.getMonth() + 1).toString().padStart(2, "0");
 
   // Press the archive key. The results should go into two separate months.
-  archive_selected_messages();
+  await archive_selected_messages();
 
   // Figure out where the messages should have gone.
-  let archiveRoot = "mailbox://nobody@Local%20Folders/Archives";
+  const archiveRoot = "mailbox://nobody@Local%20Folders/Archives";
   let firstArchiveUri =
     archiveRoot + "/" + firstMsgYear + "/" + firstMonthFolderName;
   let lastArchiveUri =
@@ -587,8 +657,8 @@ async function monthly_archive(keep_structure) {
     firstArchiveUri += "/ArchiveSrc";
     lastArchiveUri += "/ArchiveSrc";
   }
-  let firstArchiveFolder = MailUtils.getOrCreateFolder(firstArchiveUri);
-  let lastArchiveFolder = MailUtils.getOrCreateFolder(lastArchiveUri);
+  const firstArchiveFolder = MailUtils.getOrCreateFolder(firstArchiveUri);
+  const lastArchiveFolder = MailUtils.getOrCreateFolder(lastArchiveUri);
   await be_in_folder(firstArchiveFolder);
   Assert.ok(
     win.gDBView.getMsgHdrAt(0).messageId == firstMsgHdrMsgId,
@@ -620,10 +690,10 @@ add_task(async function test_folder_structure_archiving() {
 });
 
 add_task(async function test_selection_after_archive() {
-  let win = get_about_3pane();
+  const win = get_about_3pane();
   enable_archiving(true);
   await be_in_folder(archiveSrcFolder);
-  let identity = MailServices.accounts.getFirstIdentityForServer(
+  const identity = MailServices.accounts.getFirstIdentityForServer(
     win.gDBView.getMsgHdrAt(0).folder.server
   );
   identity.archiveGranularity = Ci.nsIMsgIdentity.perMonthArchiveFolders;
@@ -631,23 +701,23 @@ add_task(async function test_selection_after_archive() {
   // archive, so test that we'll actually select the next remaining message
   // by archiving rows 1 & 2 and verifying that the 3rd message gets selected.
   // let hdrToSelect =
-  select_click_row(3);
-  select_click_row(1);
-  select_control_click_row(2);
-  archive_selected_messages();
-  // assert_selected_and_displayed(hdrToSelect); TODO
+  await select_click_row(3);
+  await select_click_row(1);
+  await select_control_click_row(2);
+  await archive_selected_messages();
+  // await assert_selected_and_displayed(hdrToSelect); TODO
 });
 
 add_task(async function test_disabled_archive() {
-  let win = get_about_message();
-  let win3 = get_about_3pane();
+  const win = get_about_message();
+  const win3 = get_about_3pane();
   enable_archiving(false);
   await be_in_folder(archiveSrcFolder);
 
   // test single message
-  let current = select_click_row(0);
+  let current = await select_click_row(0);
   EventUtils.synthesizeKey("a", {});
-  assert_selected_and_displayed(current);
+  await assert_selected_and_displayed(current);
 
   Assert.ok(
     win.document.getElementById("hdrArchiveButton").disabled,
@@ -655,10 +725,10 @@ add_task(async function test_disabled_archive() {
   );
 
   // test message summaries
-  select_click_row(0);
-  current = select_shift_click_row(2);
+  await select_click_row(0);
+  current = await select_shift_click_row(2);
   EventUtils.synthesizeKey("a", {});
-  assert_selected_and_displayed(current);
+  await assert_selected_and_displayed(current);
 
   let htmlframe = win3.multiMessageBrowser;
   let archiveBtn = htmlframe.contentDocument.getElementById("hdrArchiveButton");
@@ -669,14 +739,14 @@ add_task(async function test_disabled_archive() {
   );
 
   // test message summaries with "large" selection
-  mc.window.gFolderDisplay.MAX_COUNT_FOR_CAN_ARCHIVE_CHECK = 1;
-  select_click_row(0);
-  current = select_shift_click_row(2);
+  window.gFolderDisplay.MAX_COUNT_FOR_CAN_ARCHIVE_CHECK = 1;
+  await select_click_row(0);
+  current = await select_shift_click_row(2);
   EventUtils.synthesizeKey("a", {});
-  assert_selected_and_displayed(current);
-  mc.window.gFolderDisplay.MAX_COUNT_FOR_CAN_ARCHIVE_CHECK = 100;
+  await assert_selected_and_displayed(current);
+  window.gFolderDisplay.MAX_COUNT_FOR_CAN_ARCHIVE_CHECK = 100;
 
-  htmlframe = mc.window.document.getElementById("multimessage");
+  htmlframe = document.getElementById("multimessage");
   archiveBtn = htmlframe.contentDocument.getElementById("hdrArchiveButton");
   Assert.ok(
     archiveBtn.collapsed,
@@ -686,7 +756,7 @@ add_task(async function test_disabled_archive() {
 }).skip();
 
 function check_tag_in_message(message, tag, isSet) {
-  let tagSet = message
+  const tagSet = message
     .getStringProperty("keywords")
     .split(" ")
     .includes(tag.key);
@@ -699,7 +769,7 @@ function check_tag_in_message(message, tag, isSet) {
 
 add_task(async function test_tag_keys() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
   EventUtils.synthesizeKey("1", {});
   check_tag_in_message(curMessage, tagArray[0], true);
@@ -715,20 +785,20 @@ add_task(async function test_tag_keys() {
 
 add_task(async function test_tag_keys_disabled_in_content_tab() {
   await be_in_folder(unreadFolder);
-  let curMessage = select_click_row(0);
+  const curMessage = await select_click_row(0);
 
-  mc.window.openAddonsMgr("addons://list/theme");
+  window.openAddonsMgr("addons://list/theme");
   await new Promise(resolve => setTimeout(resolve));
 
-  let tab = mc.window.document.getElementById("tabmail").currentTabInfo;
-  wait_for_content_tab_load(tab, "about:addons", 15000);
+  const tab = document.getElementById("tabmail").currentTabInfo;
+  await promise_content_tab_load(tab, "about:addons", 15000);
 
   // Make sure pressing the "1" key in a content tab doesn't tag a message
   check_tag_in_message(curMessage, tagArray[0], false);
   EventUtils.synthesizeKey("1", {});
   check_tag_in_message(curMessage, tagArray[0], false);
 
-  mc.window.document.getElementById("tabmail").closeTab(tab);
+  document.getElementById("tabmail").closeTab(tab);
 }).skip(); // TODO: not working
 
 registerCleanupFunction(function () {
