@@ -4,7 +4,9 @@
 
 /* globals msgWindow, nsMsgStatusFeedback */ // From mailWindow.js
 
-var { MailUtils } = ChromeUtils.import("resource:///modules/MailUtils.jsm");
+var { MailUtils } = ChromeUtils.importESModule(
+  "resource:///modules/MailUtils.sys.mjs"
+);
 
 var gSubscribeTree = null;
 var gSubscribeBody = null;
@@ -36,17 +38,17 @@ function SetServerTypeSpecificTextValues() {
     return;
   }
 
-  let serverType = MailUtils.getExistingFolder(gServerURI).server.type;
+  const serverType = MailUtils.getExistingFolder(gServerURI).server.type;
 
   // Set the server specific ui elements.
-  let subscribeLabelString = gSubscribeBundle.getString(
+  const subscribeLabelString = gSubscribeBundle.getString(
     "subscribeLabel-" + serverType
   );
-  let currentListTab = "currentListTab-" + serverType;
-  let currentListTabLabel = gSubscribeBundle.getString(
+  const currentListTab = "currentListTab-" + serverType;
+  const currentListTabLabel = gSubscribeBundle.getString(
     currentListTab + ".label"
   );
-  let currentListTabAccesskey = gSubscribeBundle.getString(
+  const currentListTabAccesskey = gSubscribeBundle.getString(
     currentListTab + ".accesskey"
   );
 
@@ -64,7 +66,7 @@ function SetServerTypeSpecificTextValues() {
 
 function onServerClick(aFolder) {
   gServerURI = aFolder.server.serverURI;
-  let serverMenu = document.getElementById("serverMenu");
+  const serverMenu = document.getElementById("serverMenu");
   serverMenu.menupopup.selectFolder(aFolder);
 
   SetServerTypeSpecificTextValues();
@@ -78,6 +80,7 @@ var MySubscribeListener = {
     document.getElementById("refreshButton").disabled = false;
     document.getElementById("currentListTab").disabled = false;
     document.getElementById("newGroupsTab").disabled = false;
+    gSubscribableServer.subscribeListener = null;
   },
 };
 
@@ -100,18 +103,11 @@ function SetUpTree(forceToServer, getOnlyNew) {
     // Since there is no text, switch to the Subscription view.
     toggleSubscriptionView(false);
 
-    if (!gSubscribableServer.subscribeListener) {
-      gSubscribeTree.view = gSubscribableServer.folderView;
-      gSubscribableServer.subscribeListener = MySubscribeListener;
-    }
-
-    var currentListTab = document.getElementById("currentListTab");
-    if (currentListTab.selected) {
-      document.getElementById("newGroupsTab").disabled = true;
-    } else {
-      currentListTab.disabled = true;
-    }
+    gSubscribeTree.view = gSubscribableServer.folderView;
+    gSubscribableServer.subscribeListener = MySubscribeListener;
 
+    document.getElementById("currentListTab").disabled = true;
+    document.getElementById("newGroupsTab").disabled = true;
     document.getElementById("refreshButton").disabled = true;
 
     gStatusFeedback._startMeteors();
@@ -144,6 +140,8 @@ function SubscribeOnUnload() {
   } catch (ex) {
     dump("Failed to remove the subscribe tree: " + ex + "\n");
   }
+
+  msgWindow.closeWindow();
 }
 
 function EnableSearchUI() {
@@ -174,7 +172,6 @@ function SubscribeOnLoad() {
   gStatusFeedback = new nsMsgStatusFeedback();
   msgWindow.statusFeedback = gStatusFeedback;
   msgWindow.rootDocShell.allowAuth = true;
-  msgWindow.rootDocShell.appType = Ci.nsIDocShell.APP_TYPE_MAIL;
 
   // look in arguments[0] for parameters
   if (window.arguments && window.arguments[0]) {
@@ -186,7 +183,7 @@ function SubscribeOnLoad() {
   var serverMenu = document.getElementById("serverMenu");
 
   gServerURI = null;
-  let folder =
+  const folder =
     "folder" in window.arguments[0] ? window.arguments[0].folder : null;
   if (folder && folder.server instanceof Ci.nsISubscribableServer) {
     serverMenu.menupopup.selectFolder(folder.server.rootMsgFolder);
@@ -278,7 +275,7 @@ function SearchOnClick(event) {
     return;
   }
 
-  let treeCellInfo = gSearchTree.getCellAt(event.clientX, event.clientY);
+  const treeCellInfo = gSearchTree.getCellAt(event.clientX, event.clientY);
   if (treeCellInfo.row == -1 || treeCellInfo.row > gSearchView.rowCount - 1) {
     return;
   }
@@ -305,9 +302,9 @@ function ReverseStateFromRow(aRow) {
   // and look for the "subscribed" property.
   // If the "subscribed" string is in the list of properties
   // we are subscribed.
-  let col = gSearchTree.columns.nameColumn2;
-  let name = gSearchView.getCellValue(aRow, col);
-  let isSubscribed = gSubscribableServer.isSubscribed(name);
+  const col = gSearchTree.columns.nameColumn2;
+  const name = gSearchView.getCellValue(aRow, col);
+  const isSubscribed = gSubscribableServer.isSubscribed(name);
   SetStateFromRow(aRow, !isSubscribed);
 }
 
@@ -334,7 +331,7 @@ function SetSubscribeState(state) {
         if (inSearchMode) {
           SetStateFromRow(k, state);
         } else {
-          let name = view.getCellValue(k, gSubscribeTree.columns[colId]);
+          const name = view.getCellValue(k, gSubscribeTree.columns[colId]);
           SetState(name, state, k);
         }
       }
@@ -352,7 +349,7 @@ function SetSubscribeState(state) {
 }
 
 function ReverseStateFromNode(row) {
-  let name = gSubscribeTree.view.getCellValue(
+  const name = gSubscribeTree.view.getCellValue(
     row,
     gSubscribeTree.columns.nameColumn
   );
@@ -365,7 +362,7 @@ function SubscribeOnClick(event) {
     return;
   }
 
-  let treeCellInfo = gSubscribeTree.getCellAt(event.clientX, event.clientY);
+  const treeCellInfo = gSubscribeTree.getCellAt(event.clientX, event.clientY);
   if (
     treeCellInfo.row == -1 ||
     treeCellInfo.row > gSubscribeTree.view.rowCount - 1
@@ -437,7 +434,7 @@ function toggleSubscriptionView(toggle) {
 }
 
 function Search() {
-  let searchValue = gNameField.value;
+  const searchValue = gNameField.value;
   if (
     searchValue.length &&
     gSubscribableServer &&
