@@ -1,34 +1,39 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * This Source Code Form is subject to the terms of the Mozilla Public
+/* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /* import-globals-from ../../search/content/searchTerm.js */
 
-var gFolderTreeView;
 var gPickedFolder;
 var gMailView = null;
 var msgWindow; // important, don't change the name of this variable. it's really a global used by commandglue.js
 var gSearchTermSession; // really an in memory temporary filter we use to read in and write out the search terms
 var gSearchFolderURIs = "";
 var gMessengerBundle = null;
-var kCurrentColor = "";
-var kDefaultColor = "#363959";
-var gNeedToRestoreFolderSelection = false;
+var gFolderBundle = null;
+var gDefaultColor = "";
+var gMsgFolder;
 
-var nsMsgSearchScope = Ci.nsMsgSearchScope;
+var { FolderTreeProperties } = ChromeUtils.importESModule(
+  "resource:///modules/FolderTreeProperties.sys.mjs"
+);
+var { FolderUtils } = ChromeUtils.importESModule(
+  "resource:///modules/FolderUtils.sys.mjs"
+);
+var { MailServices } = ChromeUtils.importESModule(
+  "resource:///modules/MailServices.sys.mjs"
+);
+var { MailUtils } = ChromeUtils.importESModule(
+  "resource:///modules/MailUtils.sys.mjs"
+);
+var { PluralForm } = ChromeUtils.importESModule(
+  "resource:///modules/PluralForm.sys.mjs"
+);
+var { VirtualFolderHelper } = ChromeUtils.importESModule(
+  "resource:///modules/VirtualFolderWrapper.sys.mjs"
+);
 
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-var { PluralForm } = ChromeUtils.import(
-  "resource://gre/modules/PluralForm.jsm"
-);
-var { MailServices } = ChromeUtils.import(
-  "resource:///modules/MailServices.jsm"
-);
-var { VirtualFolderHelper } = ChromeUtils.import(
-  "resource:///modules/VirtualFolderWrapper.jsm"
-);
-var { MailUtils } = ChromeUtils.import("resource:///modules/MailUtils.jsm");
+window.addEventListener("DOMContentLoaded", onLoad);
 
 document.addEventListener("dialogaccept", onOK);
 document.addEventListener("dialogcancel", onCancel);
@@ -37,14 +42,20 @@ function onLoad() {
   var windowArgs = window.arguments[0];
   var acceptButton = document.querySelector("dialog").getButton("accept");
 
-  gMessengerBundle = document.getElementById("bundle_messenger");
+  gMessengerBundle = Services.strings.createBundle(
+    "chrome://messenger/locale/messenger.properties"
+  );
+
+  gFolderBundle = Services.strings.createBundle(
+    "chrome://messenger/locale/folderWidgets.properties"
+  );
 
   // call this when OK is pressed
   msgWindow = windowArgs.msgWindow; // eslint-disable-line no-global-assign
 
   initializeSearchWidgets();
 
-  setSearchScope(nsMsgSearchScope.offlineMail);
+  setSearchScope(Ci.nsMsgSearchScope.offlineMail);
   if (windowArgs.editExistingFolder) {
     acceptButton.label = document
       .querySelector("dialog")
@@ -68,7 +79,7 @@ function onLoad() {
 
     if (windowArgs.searchTerms) {
       // then add them to our search session
-      for (let searchTerm of windowArgs.searchTerms) {
+      for (const searchTerm of windowArgs.searchTerms) {
         gSearchTermSession.appendTerm(searchTerm);
       }
     }
@@ -91,7 +102,7 @@ function onLoad() {
       }
     }
 
-    let folderNameField = document.getElementById("name");
+    const folderNameField = document.getElementById("name");
     folderNameField.removeAttribute("hidden");
     folderNameField.focus();
     if (windowArgs.newFolderName) {
@@ -140,31 +151,63 @@ function updateOnlineSearchState() {
 }
 
 function InitDialogWithVirtualFolder(aVirtualFolder) {
-  let virtualFolderWrapper = VirtualFolderHelper.wrapVirtualFolder(
+  const virtualFolderWrapper = VirtualFolderHelper.wrapVirtualFolder(
     window.arguments[0].folder
   );
+  gMsgFolder = window.arguments[0].folder;
+
+  const styles = getComputedStyle(document.body);
+  const folderColors = {
+    Inbox: styles.getPropertyValue("--folder-color-inbox"),
+    Sent: styles.getPropertyValue("--folder-color-sent"),
+    Outbox: styles.getPropertyValue("--folder-color-outbox"),
+    Drafts: styles.getPropertyValue("--folder-color-draft"),
+    Trash: styles.getPropertyValue("--folder-color-trash"),
+    Archive: styles.getPropertyValue("--folder-color-archive"),
+    Templates: styles.getPropertyValue("--folder-color-template"),
+    Junk: styles.getPropertyValue("--folder-color-spam"),
+    Virtual: styles.getPropertyValue("--folder-color-folder-filter"),
+    RSS: styles.getPropertyValue("--folder-color-rss"),
+    Newsgroup: styles.getPropertyValue("--folder-color-newsletter"),
+  };
+  gDefaultColor = styles.getPropertyValue("--folder-color-folder");
 
   // when editing an existing folder, hide the folder picker that stores the parent location of the folder
   document.getElementById("msgNewFolderPicker").collapsed = true;
-  document.getElementById("chooseFolderLocationLabel").collapsed = true;
-  let folderNameField = document.getElementById("existingName");
+  const items = document.getElementsByClassName("chooseFolderLocation");
+  for (const item of items) {
+    item.setAttribute("hidden", true);
+  }
+  const folderNameField = document.getElementById("existingName");
   folderNameField.removeAttribute("hidden");
 
   // Show the icon color options.
   document.getElementById("iconColorContainer").collapsed = false;
-  // Store the current icon color to allow discarding edits.
-  gFolderTreeView = window.arguments[0].treeView;
-  kCurrentColor = gFolderTreeView.getFolderCacheProperty(
-    aVirtualFolder,
-    "folderIconColor"
-  );
 
-  let colorInput = document.getElementById("color");
-  colorInput.value = kCurrentColor ? kCurrentColor : kDefaultColor;
+  const folderType = FolderUtils.getSpecialFolderString(gMsgFolder);
+  if (folderType in folderColors) {
+    gDefaultColor = folderColors[folderType];
+  }
+
+  const colorInput = document.getElementById("color");
+  colorInput.value =
+    FolderTreeProperties.getColor(aVirtualFolder.URI) || gDefaultColor;
   colorInput.addEventListener("input", event => {
-    window.arguments[0].previewSelectedColorCallback(
-      aVirtualFolder,
-      event.target.value
+    // Preview the chosen color.
+    Services.obs.notifyObservers(
+      gMsgFolder,
+      "folder-color-preview",
+      colorInput.value
+    );
+  });
+  const resetColorButton = document.getElementById("resetColor");
+  resetColorButton.addEventListener("click", function () {
+    colorInput.value = gDefaultColor;
+    // Preview the default color.
+    Services.obs.notifyObservers(
+      gMsgFolder,
+      "folder-color-preview",
+      gDefaultColor
     );
   });
 
@@ -177,14 +220,13 @@ function InitDialogWithVirtualFolder(aVirtualFolder) {
   setupSearchRows(gSearchTermSession.searchTerms);
 
   // set the name of the folder
-  let folderBundle = document.getElementById("bundle_folder");
-  let name = folderBundle.getFormattedString("verboseFolderFormat", [
+  const name = gFolderBundle.formatStringFromName("verboseFolderFormat", [
     aVirtualFolder.prettyName,
     aVirtualFolder.server.prettyName,
   ]);
   folderNameField.setAttribute("value", name);
   // update the window title based on the name of the saved search
-  document.title = gMessengerBundle.getFormattedString(
+  document.title = gMessengerBundle.formatStringFromName(
     "editVirtualFolderPropertiesTitle",
     [aVirtualFolder.prettyName]
   );
@@ -203,7 +245,7 @@ function onOK(event) {
     Services.prompt.alert(
       window,
       null,
-      gMessengerBundle.getString("alertNoSearchFoldersSelected")
+      gMessengerBundle.GetStringFromName("alertNoSearchFoldersSelected")
     );
     event.preventDefault();
     return;
@@ -216,7 +258,7 @@ function onOK(event) {
       gSearchTermSession
     );
     // save the settings
-    let virtualFolderWrapper = VirtualFolderHelper.wrapVirtualFolder(
+    const virtualFolderWrapper = VirtualFolderHelper.wrapVirtualFolder(
       window.arguments[0].folder
     );
     virtualFolderWrapper.searchTerms = gSearchTermSession.searchTerms;
@@ -226,22 +268,18 @@ function onOK(event) {
 
     MailServices.accounts.saveVirtualFolders();
 
-    // Check if the icon color was updated.
-    if (
-      kCurrentColor !=
-      gFolderTreeView.getFolderCacheProperty(
-        window.arguments[0].folder,
-        "folderIconColor"
-      )
-    ) {
-      window.arguments[0].updateColorCallback(window.arguments[0].folder);
+    let color = document.getElementById("color").value;
+    if (color == gDefaultColor) {
+      color = undefined;
     }
+    FolderTreeProperties.setColor(gMsgFolder.URI, color);
+    // Tell 3-pane tabs to update the folder's color.
+    Services.obs.notifyObservers(gMsgFolder, "folder-color-changed", color);
 
     if (window.arguments[0].onOKCallback) {
-      window.arguments[0].onOKCallback(virtualFolderWrapper.virtualFolder.URI);
+      window.arguments[0].onOKCallback();
     }
 
-    restoreFolderSelection();
     return;
   }
 
@@ -257,7 +295,7 @@ function onOK(event) {
       Services.prompt.alert(
         window,
         null,
-        gMessengerBundle.getString("folderCreationFailed")
+        gMessengerBundle.GetStringFromName("folderCreationFailed")
       );
       event.preventDefault();
       return;
@@ -265,7 +303,7 @@ function onOK(event) {
       Services.prompt.alert(
         window,
         null,
-        gMessengerBundle.getString("folderExists")
+        gMessengerBundle.GetStringFromName("folderExists")
       );
       event.preventDefault();
       return;
@@ -286,31 +324,9 @@ function onOK(event) {
 }
 
 function onCancel(event) {
-  if (
-    window.arguments[0].folder &&
-    window.arguments[0].previewSelectedColorCallback
-  ) {
-    // Restore the icon to the previous color and discard edits.
-    window.arguments[0].previewSelectedColorCallback(
-      window.arguments[0].folder,
-      kCurrentColor
-    );
-  }
-
-  restoreFolderSelection();
-}
-
-/**
- * If the user interacted with the color picker, it means the folder was
- * deselected to ensure a proper preview of the color, so we need to re-select
- * the folder when done.
- */
-function restoreFolderSelection() {
-  if (
-    gNeedToRestoreFolderSelection &&
-    window.arguments[0].selectFolderCallback
-  ) {
-    window.arguments[0].selectFolderCallback(window.arguments[0].folder);
+  if (gMsgFolder) {
+    // Clear any previewed color.
+    Services.obs.notifyObservers(gMsgFolder, "folder-color-preview");
   }
 }
 
@@ -342,18 +358,18 @@ function onFolderListDialogCallback(searchFolderURIs) {
 }
 
 function updateFoldersCount() {
-  let srchFolderUriArray = gSearchFolderURIs.split("|");
-  let folderCount = gSearchFolderURIs ? srchFolderUriArray.length : 0;
-  let foldersList = document.getElementById("chosenFoldersCount");
+  const srchFolderUriArray = gSearchFolderURIs.split("|");
+  const folderCount = gSearchFolderURIs ? srchFolderUriArray.length : 0;
+  const foldersList = document.getElementById("chosenFoldersCount");
   foldersList.textContent = PluralForm.get(
     folderCount,
-    gMessengerBundle.getString("virtualFolderSourcesChosen")
+    gMessengerBundle.GetStringFromName("virtualFolderSourcesChosen")
   ).replace("#1", folderCount);
   if (folderCount > 0) {
-    let folderNames = [];
-    for (let folderURI of srchFolderUriArray) {
-      let folder = MailUtils.getOrCreateFolder(folderURI);
-      let name = this.gMessengerBundle.getFormattedString(
+    const folderNames = [];
+    for (const folderURI of srchFolderUriArray) {
+      const folder = MailUtils.getOrCreateFolder(folderURI);
+      const name = this.gMessengerBundle.formatStringFromName(
         "verboseFolderFormat",
         [folder.prettyName, folder.server.prettyName]
       );
@@ -369,24 +385,3 @@ function onEnterInSearchTerm() {
   // stub function called by the core search widget code...
   // nothing for us to do here
 }
-
-/**
- * Clear the tree selection if the user opens the color picker in order to
- * guarantee a proper color preview of the highlighted tree item.
- */
-function inputColorClicked() {
-  window.arguments[0].clearFolderSelectionCallback();
-  gNeedToRestoreFolderSelection = true;
-}
-
-/**
- * Reset the folder color to the default value.
- */
-function resetColor() {
-  inputColorClicked();
-  document.getElementById("color").value = kDefaultColor;
-  window.arguments[0].previewSelectedColorCallback(
-    window.arguments[0].folder,
-    null
-  );
-}
