@@ -636,22 +636,22 @@ nsMsgMailNewsUrl::GetSpecIgnoringRef(nsACString& result) {
 
 NS_IMETHODIMP
 nsMsgMailNewsUrl::GetDisplaySpec(nsACString& aUnicodeSpec) {
-  return GetSpec(aUnicodeSpec);
+  return m_baseURL->GetDisplaySpec(aUnicodeSpec);
 }
 
 NS_IMETHODIMP
-nsMsgMailNewsUrl::GetDisplayHostPort(nsACString& aUnicodeHostPort) {
-  return GetHostPort(aUnicodeHostPort);
+nsMsgMailNewsUrl::GetDisplayHostPort(nsACString& aHostPort) {
+  return m_baseURL->GetDisplayHostPort(aHostPort);
 }
 
 NS_IMETHODIMP
-nsMsgMailNewsUrl::GetDisplayHost(nsACString& aUnicodeHost) {
-  return GetHost(aUnicodeHost);
+nsMsgMailNewsUrl::GetDisplayHost(nsACString& aHost) {
+  return m_baseURL->GetDisplayHost(aHost);
 }
 
 NS_IMETHODIMP
 nsMsgMailNewsUrl::GetDisplayPrePath(nsACString& aPrePath) {
-  return GetPrePath(aPrePath);
+  return m_baseURL->GetDisplayPrePath(aPrePath);
 }
 
 NS_IMETHODIMP
@@ -659,6 +659,15 @@ nsMsgMailNewsUrl::GetHasRef(bool* result) {
   return m_baseURL->GetHasRef(result);
 }
 
+NS_IMETHODIMP nsMsgMailNewsUrl::GetHasUserPass(bool* aHasUserPass) {
+  nsAutoCString username;
+  GetUsername(username);
+  nsAutoCString password;
+  GetPassword(password);
+  *aHasUserPass = !username.IsEmpty() || !password.IsEmpty();
+  return NS_OK;
+}
+
 NS_IMETHODIMP nsMsgMailNewsUrl::SchemeIs(const char* aScheme, bool* _retval) {
   return m_baseURL->SchemeIs(aScheme, _retval);
 }
@@ -772,6 +781,10 @@ nsresult nsMsgMailNewsUrl::SetQueryWithEncoding(
       .Finalize(m_baseURL);
 }
 
+NS_IMETHODIMP nsMsgMailNewsUrl::GetHasQuery(bool* aHasQuery) {
+  return m_baseURL->GetHasQuery(aHasQuery);
+}
+
 NS_IMETHODIMP nsMsgMailNewsUrl::GetRef(nsACString& aRef) {
   return m_baseURL->GetRef(aRef);
 }
@@ -1048,14 +1061,6 @@ NS_IMETHODIMP nsMsgMailNewsUrl::GetFolder(nsIMsgFolder** /* aFolder */) {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-NS_IMETHODIMP nsMsgMailNewsUrl::GetIsMessageUri(bool* aIsMessageUri) {
-  NS_ENSURE_ARG(aIsMessageUri);
-  nsAutoCString scheme;
-  m_baseURL->GetScheme(scheme);
-  *aIsMessageUri = StringEndsWith(scheme, "-message"_ns);
-  return NS_OK;
-}
-
 NS_IMPL_ISUPPORTS(nsMsgMailNewsUrl::Mutator, nsIURISetters, nsIURIMutator)
 
 NS_IMETHODIMP
