@@ -5,8 +5,6 @@
 
 #include "nsMsgComposeService.h"
 #include "nsIMsgSend.h"
-#include "nsIServiceManager.h"
-#include "nsIObserverService.h"
 #include "nsIMsgIdentity.h"
 #include "nsISmtpUrl.h"
 #include "nsIURI.h"
@@ -16,7 +14,7 @@
 #include "nsISupportsPrimitives.h"
 #include "nsIWindowWatcher.h"
 #include "mozIDOMWindow.h"
-#include "nsIContentViewer.h"
+#include "nsIDocumentViewer.h"
 #include "nsIMsgWindow.h"
 #include "nsIDocShell.h"
 #include "nsPIDOMWindow.h"
@@ -24,8 +22,6 @@
 #include "nsIAppWindow.h"
 #include "nsIWindowMediator.h"
 #include "nsIDocShellTreeItem.h"
-#include "nsIDocShellTreeOwner.h"
-#include "nsIBaseWindow.h"
 #include "nsIPrefService.h"
 #include "nsIPrefBranch.h"
 #include "nsIMsgAccountManager.h"
@@ -36,17 +32,13 @@
 #include "nsIInterfaceRequestorUtils.h"
 #include "nsIMsgDatabase.h"
 #include "nsIDocumentEncoder.h"
-#include "nsContentCID.h"
 #include "mozilla/dom/Selection.h"
-#include "nsUTF8Utils.h"
 #include "mozilla/intl/LineBreaker.h"
 #include "mimemoz2.h"
 #include "nsIURIMutator.h"
 #include "mozilla/dom/Element.h"
-#include "mozilla/dom/XULFrameElement.h"
 #include "nsFrameLoader.h"
 #include "nsSmtpUrl.h"
-#include "nsUnicharUtils.h"
 #include "mozilla/NullPrincipal.h"
 
 #ifdef MSGCOMP_TRACE_PERFORMANCE
@@ -57,7 +49,6 @@
 #endif
 
 #include "nsICommandLine.h"
-#include "nsIAppStartup.h"
 #include "nsMsgUtils.h"
 #include "nsIPrincipal.h"
 #include "nsIMutableArray.h"
@@ -127,8 +118,10 @@ nsresult nsMsgComposeService::Init() {
   // Since the compose service should only be initialized once, we can
   // be pretty sure there aren't any existing compose windows open.
   MsgCleanupTempFiles("nsmail", "tmp");
-  MsgCleanupTempFiles("nsemail", "html");
   MsgCleanupTempFiles("nscopy", "tmp");
+  MsgCleanupTempFiles("nsemail", "eml");
+  MsgCleanupTempFiles("nsemail", "tmp");
+  MsgCleanupTempFiles("nsqmail", "tmp");
   return rv;
 }
 
@@ -387,8 +380,24 @@ nsMsgComposeService::OpenComposeWindow(
            type == nsIMsgCompType::ReplyToSenderAndGroup ||
            type == nsIMsgCompType::ReplyToList)) {
         nsAutoCString selHTML;
-        if (NS_SUCCEEDED(GetOrigWindowSelection(type, selection, selHTML)))
-          pMsgComposeParams->SetHtmlToQuote(selHTML);
+        if (NS_SUCCEEDED(GetOrigWindowSelection(type, selection, selHTML))) {
+          nsCOMPtr<nsINode> node = selection->GetFocusNode();
+          NS_ENSURE_TRUE(node, NS_ERROR_FAILURE);
+          IgnoredErrorResult er;
+
+          if ((node->LocalName().IsEmpty() ||
+               node->LocalName().EqualsLiteral("pre")) &&
+              node->OwnerDoc()->QuerySelector(
+                  "body > div:first-of-type.moz-text-plain"_ns, er)) {
+            // Treat the quote as <pre> for selections in moz-text-plain bodies.
+            // If focusNode.localName isn't empty, we had e.g. body selected
+            // and should not add <pre>.
+            pMsgComposeParams->SetHtmlToQuote("<pre>"_ns + selHTML +
+                                              "</pre>"_ns);
+          } else {
+            pMsgComposeParams->SetHtmlToQuote(selHTML);
+          }
+        }
       }
 
       if (!originalMsgURI.IsEmpty()) {
@@ -674,7 +683,7 @@ NS_IMETHODIMP nsMsgTemplateReplyHelper::OnStopRunningUrl(nsIURI* aUrl,
       do_CreateInstance("@mozilla.org/messengercompose/composefields;1", &rv);
 
   nsCString replyTo;
-  mHdrToReplyTo->GetStringProperty("replyTo", getter_Copies(replyTo));
+  mHdrToReplyTo->GetStringProperty("replyTo", replyTo);
   if (replyTo.IsEmpty()) mHdrToReplyTo->GetAuthor(getter_Copies(replyTo));
   compFields->SetTo(NS_ConvertUTF8toUTF16(replyTo));
 
@@ -788,7 +797,7 @@ nsMsgTemplateReplyHelper::OnDataAvailable(nsIRequest* request,
       }
       mInMsgBody = bodyOffset != 0;
       if (!mInMsgBody && readCount > 3)  // still in msg hdrs
-        strncpy(mLastBlockChars, readBuf + readCount - 3, 3);
+        memmove(mLastBlockChars, readBuf + readCount - 3, 3);
     }
     mTemplateBody.Append(readBuf + bodyOffset);
   }
@@ -847,7 +856,7 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(
   helper->mIdentity = identity;
 
   nsAutoCString replyTo;
-  aMsgHdr->GetStringProperty("replyTo", getter_Copies(replyTo));
+  aMsgHdr->GetStringProperty("replyTo", replyTo);
   if (replyTo.IsEmpty()) aMsgHdr->GetAuthor(getter_Copies(replyTo));
   if (replyTo.IsEmpty()) return NS_ERROR_FAILURE;  // nowhere to send the reply
 
