@@ -497,27 +497,32 @@ nsMailtoUrl::GetSpecIgnoringRef(nsACString& result) {
 
 NS_IMETHODIMP
 nsMailtoUrl::GetDisplaySpec(nsACString& aUnicodeSpec) {
-  return GetSpec(aUnicodeSpec);
+  return m_baseURL->GetDisplaySpec(aUnicodeSpec);
 }
 
 NS_IMETHODIMP
 nsMailtoUrl::GetDisplayHostPort(nsACString& aUnicodeHostPort) {
-  return GetHostPort(aUnicodeHostPort);
+  return m_baseURL->GetDisplayHostPort(aUnicodeHostPort);
 }
 
 NS_IMETHODIMP
 nsMailtoUrl::GetDisplayHost(nsACString& aUnicodeHost) {
-  return GetHost(aUnicodeHost);
+  return m_baseURL->GetDisplayHost(aUnicodeHost);
 }
 
 NS_IMETHODIMP
 nsMailtoUrl::GetDisplayPrePath(nsACString& aPrePath) {
-  return GetPrePath(aPrePath);
+  return m_baseURL->GetDisplayPrePath(aPrePath);
 }
 
 NS_IMETHODIMP
 nsMailtoUrl::GetHasRef(bool* result) { return m_baseURL->GetHasRef(result); }
 
+NS_IMETHODIMP nsMailtoUrl::GetHasUserPass(bool* aHasUserPass) {
+  *aHasUserPass = false;
+  return NS_OK;
+}
+
 NS_IMETHODIMP
 nsMailtoUrl::GetFilePath(nsACString& aFilePath) {
   return m_baseURL->GetFilePath(aFilePath);
@@ -561,6 +566,10 @@ nsMailtoUrl::Mutate(nsIURIMutator** aMutator) {
   return NS_OK;
 }
 
+NS_IMETHODIMP nsMailtoUrl::GetHasQuery(bool* aHasQuery) {
+  return m_baseURL->GetHasQuery(aHasQuery);
+}
+
 nsresult nsMailtoUrl::NewMailtoURI(const nsACString& aSpec, nsIURI* aBaseURI,
                                    nsIURI** _retval) {
   nsresult rv;
