@@ -4,9 +4,9 @@
  */
 
 let gMsgCompose = null;
-let numSendListenerFunctions = 7;
+const numSendListenerFunctions = 7;
 
-let gSLAll = new Array(numSendListenerFunctions + 1);
+const gSLAll = new Array(numSendListenerFunctions + 1);
 
 function sendListener() {}
 
@@ -38,7 +38,7 @@ sendListener.prototype = {
       gMsgCompose.removeMsgSendListener(this);
     }
   },
-  onGetDraftFolderURI(aFolderURI) {
+  onGetDraftFolderURI(aMsgID, aFolderURI) {
     this.mReceived |= 0x10;
     if (this.mAutoRemoveItem == 0x10) {
       gMsgCompose.removeMsgSendListener(this);
@@ -63,7 +63,7 @@ function NotifySendListeners() {
   gMsgCompose.onProgress(null, null, null);
   gMsgCompose.onStatus(null, null);
   gMsgCompose.onStopSending(null, null, null, null);
-  gMsgCompose.onGetDraftFolderURI(null);
+  gMsgCompose.onGetDraftFolderURI(null, null);
   gMsgCompose.onSendNotPerformed(null, null);
   gMsgCompose.onTransportSecurityError(null, null, null, "");
 }
@@ -72,7 +72,7 @@ function run_test() {
   gMsgCompose = Cc["@mozilla.org/messengercompose/compose;1"].createInstance(
     Ci.nsIMsgCompose
   );
-  let params = Cc[
+  const params = Cc[
     "@mozilla.org/messengercompose/composeparams;1"
   ].createInstance(Ci.nsIMsgComposeParams);
   gMsgCompose.initialize(params);
