@@ -6,7 +6,6 @@
 #include "nsAutoSyncState.h"
 #include "nsIMsgImapMailFolder.h"
 #include "nsIMsgHdr.h"
-#include "nsMsgImapCID.h"
 #include "nsIObserverService.h"
 #include "nsIMsgAccountManager.h"
 #include "nsIMsgIncomingServer.h"
@@ -16,6 +15,7 @@
 #include "nsMsgMessageFlags.h"
 #include "nsMsgUtils.h"
 #include "nsIIOService.h"
+#include "nsITimer.h"
 #include "nsComponentManagerUtils.h"
 #include "nsServiceManagerUtils.h"
 #include "mozilla/Services.h"
@@ -139,7 +139,7 @@ NS_IMETHODIMP nsDefaultAutoSyncFolderStrategy::Sort(
   bool folderAOpen = false;
   bool folderBOpen = false;
   nsCOMPtr<nsIMsgMailSession> session =
-      do_GetService(NS_MSGMAILSESSION_CONTRACTID, &rv);
+      do_GetService("@mozilla.org/messenger/services/session;1", &rv);
   if (NS_SUCCEEDED(rv) && session) {
     session->IsFolderOpenInWindow(aFolderA, &folderAOpen);
     session->IsFolderOpenInWindow(aFolderB, &folderBOpen);
@@ -201,7 +201,7 @@ nsAutoSyncManager::nsAutoSyncManager() {
   mIdleState = notIdle;
   mStartupDone = false;
   mDownloadModel = dmChained;
-  mUpdateState = completed;
+  mUpdateInProgress = false;
   mPaused = false;
 
   nsresult rv;
@@ -223,19 +223,20 @@ nsAutoSyncManager::~nsAutoSyncManager() {}
 
 void nsAutoSyncManager::InitTimer() {
   if (!mTimer) {
-    nsresult rv;
-    mTimer = do_CreateInstance(NS_TIMER_CONTRACTID, &rv);
-    NS_ASSERTION(NS_SUCCEEDED(rv),
-                 "failed to create timer in nsAutoSyncManager");
-
-    mTimer->InitWithNamedFuncCallback(
-        TimerCallback, (void*)this, kTimerIntervalInMs,
-        nsITimer::TYPE_REPEATING_SLACK, "nsAutoSyncManager::TimerCallback");
+    MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("Starting timer"));
+    nsresult rv = NS_NewTimerWithFuncCallback(
+        getter_AddRefs(mTimer), TimerCallback, (void*)this, kTimerIntervalInMs,
+        nsITimer::TYPE_REPEATING_SLACK, "nsAutoSyncManager::TimerCallback",
+        nullptr);
+    if (NS_FAILED(rv)) {
+      NS_WARNING("Could not start nsAutoSyncManager timer");
+    }
   }
 }
 
 void nsAutoSyncManager::StopTimer() {
   if (mTimer) {
+    MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("Stopping timer"));
     mTimer->Cancel();
     mTimer = nullptr;
   }
@@ -246,6 +247,7 @@ void nsAutoSyncManager::StartTimerIfNeeded() {
 }
 
 void nsAutoSyncManager::TimerCallback(nsITimer* aTimer, void* aClosure) {
+  MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("Timer callback"));
   if (!aClosure) return;
 
   nsAutoSyncManager* autoSyncMgr = static_cast<nsAutoSyncManager*>(aClosure);
@@ -257,33 +259,45 @@ void nsAutoSyncManager::TimerCallback(nsITimer* aTimer, void* aClosure) {
     autoSyncMgr->StopTimer();
   }
 
-  // process folders within the discovery queue
+  // process a folder in the discovery queue
   if (autoSyncMgr->mDiscoveryQ.Count() > 0) {
     nsCOMPtr<nsIAutoSyncState> autoSyncStateObj(autoSyncMgr->mDiscoveryQ[0]);
-    if (autoSyncStateObj) {
-      uint32_t leftToProcess;
-      nsresult rv = autoSyncStateObj->ProcessExistingHeaders(
-          kNumberOfHeadersToProcess, &leftToProcess);
+    // There should be no reason for `autoSyncStateObj` not to exist, but
+    // check anyway.
+    MOZ_ASSERT(autoSyncStateObj);
 
-      nsCOMPtr<nsIMsgFolder> folder;
-      autoSyncStateObj->GetOwnerFolder(getter_AddRefs(folder));
-      if (folder)
+    uint32_t leftToProcess = 0;
+    autoSyncStateObj->ProcessExistingHeaders(kNumberOfHeadersToProcess,
+                                             &leftToProcess);
+
+    nsCOMPtr<nsIMsgFolder> folder;
+    autoSyncStateObj->GetOwnerFolder(getter_AddRefs(folder));
+    if (folder) {
+      NOTIFY_LISTENERS_STATIC(
+          autoSyncMgr, OnDiscoveryQProcessed,
+          (folder, kNumberOfHeadersToProcess, leftToProcess));
+    }
+    if (leftToProcess == 0) {
+      autoSyncMgr->mDiscoveryQ.RemoveObjectAt(0);
+      if (folder) {
         NOTIFY_LISTENERS_STATIC(
-            autoSyncMgr, OnDiscoveryQProcessed,
-            (folder, kNumberOfHeadersToProcess, leftToProcess));
-
-      if (NS_SUCCEEDED(rv) && 0 == leftToProcess) {
-        autoSyncMgr->mDiscoveryQ.RemoveObjectAt(0);
-        if (folder)
-          NOTIFY_LISTENERS_STATIC(
-              autoSyncMgr, OnFolderRemovedFromQ,
-              (nsIAutoSyncMgrListener::DiscoveryQueue, folder));
+            autoSyncMgr, OnFolderRemovedFromQ,
+            (nsIAutoSyncMgrListener::DiscoveryQueue, folder));
       }
     }
+    if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+      nsCString folderName;
+      folder->GetURI(folderName);
+      MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+              ("%s: processed discovery q for folder=%s, "
+               "msgs left to process in folder=%d",
+               __func__, folderName.get(), leftToProcess));
+    }
   }
 
   if (autoSyncMgr->mUpdateQ.Count() > 0) {
-    if (autoSyncMgr->mUpdateState == completed) {
+    if (!autoSyncMgr->mUpdateInProgress)  // Avoids possible overlap of updates
+    {
       nsCOMPtr<nsIAutoSyncState> autoSyncStateObj(autoSyncMgr->mUpdateQ[0]);
       if (autoSyncStateObj) {
         int32_t state;
@@ -298,18 +312,25 @@ void nsAutoSyncManager::TimerCallback(nsITimer* aTimer, void* aClosure) {
             NS_ENSURE_SUCCESS_VOID(rv);
             rv = imapFolder->InitiateAutoSync(autoSyncMgr);
             if (NS_SUCCEEDED(rv)) {
-              autoSyncMgr->mUpdateState = initiated;
+              autoSyncMgr->mUpdateInProgress = true;
               NOTIFY_LISTENERS_STATIC(autoSyncMgr, OnAutoSyncInitiated,
                                       (folder));
             }
           }
+          if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+            nsCString folderName;
+            folder->GetURI(folderName);
+            MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                    ("%s: process update q for folder=%s", __func__,
+                     folderName.get()));
+          }
         }
       }
     }
     // if initiation is not successful for some reason, or
     // if there is an on going download for this folder,
     // remove it from q and continue with the next one
-    if (autoSyncMgr->mUpdateState != initiated) {
+    if (!autoSyncMgr->mUpdateInProgress) {
       nsCOMPtr<nsIMsgFolder> folder;
       autoSyncMgr->mUpdateQ[0]->GetOwnerFolder(getter_AddRefs(folder));
 
@@ -318,6 +339,13 @@ void nsAutoSyncManager::TimerCallback(nsITimer* aTimer, void* aClosure) {
       if (folder)
         NOTIFY_LISTENERS_STATIC(autoSyncMgr, OnFolderRemovedFromQ,
                                 (nsIAutoSyncMgrListener::UpdateQueue, folder));
+      if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Error)) {
+        nsCString folderName;
+        folder->GetURI(folderName);
+        MOZ_LOG(gAutoSyncLog, LogLevel::Error,
+                ("%s: update q init failed for folder=%s", __func__,
+                 folderName.get()));
+      }
     }
 
   }  // endif
@@ -470,14 +498,28 @@ NS_IMETHODIMP nsAutoSyncManager::OnStartRunningUrl(nsIURI* aUrl) {
   return NS_OK;
 }
 
+/**
+ * This is called when an update folder URL finishes. It is also called by
+ * nsAutoSyncState::OnStopRunningUrl when a folder status URL finishes.
+ */
 NS_IMETHODIMP nsAutoSyncManager::OnStopRunningUrl(nsIURI* aUrl,
                                                   nsresult aExitCode) {
-  mUpdateState = completed;
+  if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+    nsCString uri;
+    if (aUrl) uri = aUrl->GetSpecOrDefault();
+    MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+            ("nsAutoSyncManager::%s, count=%d, url=%s", __func__,
+             mUpdateQ.Count(), uri.get()));
+  }
+  mUpdateInProgress = false;  // Set false to allow next folder to update
   if (mUpdateQ.Count() > 0) mUpdateQ.RemoveObjectAt(0);
 
   return aExitCode;
 }
 
+/**
+ * This occurs on system sleep, hibernate or when TB is set offline or shutdown.
+ */
 NS_IMETHODIMP nsAutoSyncManager::Pause() {
   StopTimer();
   mPaused = true;
@@ -485,10 +527,19 @@ NS_IMETHODIMP nsAutoSyncManager::Pause() {
   return NS_OK;
 }
 
+/**
+ * This occurs on wakeup from sleep or hibernate and when TB is returned online.
+ */
 NS_IMETHODIMP nsAutoSyncManager::Resume() {
   mPaused = false;
   StartTimerIfNeeded();
-  MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("autosync resumed"));
+  // If mUpdateInProgress was true on resume it needs to be reset back to false
+  // to avoid inhibiting autosync until a restart. OnStopRunningUrl(), where it
+  // is normally reset, may not occur depending on timing and autosync will
+  // never be initiated in TimerCallback() for any folder.
+  MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+          ("autosync resumed, mUpdateInProgress=%d(bool)", mUpdateInProgress));
+  mUpdateInProgress = false;  // May already be false, that's OK
   return NS_OK;
 }
 
@@ -527,11 +578,13 @@ NS_IMETHODIMP nsAutoSyncManager::Observe(nsISupports*, const char* aTopic,
       SetIdleState(appIdle);
       if (prevIdleState != notIdle) return NS_OK;
 
+      MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("%s: in app idle", __func__));
       return StartIdleProcessing();
     }
 
     // we're back from appIdle - if already notIdle, just return;
     if (GetIdleState() == notIdle) return NS_OK;
+    MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("%s: out of app idle", __func__));
 
     SetIdleState(notIdle);
     NOTIFY_LISTENERS(OnStateChanged, (false));
@@ -549,6 +602,7 @@ NS_IMETHODIMP nsAutoSyncManager::Observe(nsISupports*, const char* aTopic,
     if (GetIdleState() != appIdle) {
       SetIdleState(notIdle);
       NOTIFY_LISTENERS(OnStateChanged, (false));
+      MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("%s: out of idle", __func__));
     }
     return NS_OK;
   } else  // we've gone system idle
@@ -564,6 +618,7 @@ NS_IMETHODIMP nsAutoSyncManager::Observe(nsISupports*, const char* aTopic,
     // in appIdle state.
     if (GetIdleState() != appIdle) SetIdleState(systemIdle);
     if (WeAreOffline()) return NS_OK;
+    MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("%s: in sys idle", __func__));
     return StartIdleProcessing();
   }
   return NS_OK;
@@ -572,6 +627,7 @@ NS_IMETHODIMP nsAutoSyncManager::Observe(nsISupports*, const char* aTopic,
 nsresult nsAutoSyncManager::StartIdleProcessing() {
   if (mPaused) return NS_OK;
 
+  MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("enter %s", __func__));
   StartTimerIfNeeded();
 
   // Ignore idle events sent during the startup
@@ -630,6 +686,14 @@ nsresult nsAutoSyncManager::StartIdleProcessing() {
     autoSyncStateObj->GetOwnerFolder(getter_AddRefs(folder));
     if (folder) NOTIFY_LISTENERS(OnDownloadCompleted, (folder));
 
+    if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+      nsCString folderName;
+      folder->GetURI(folderName);
+      MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+              ("%s: folder=%s has no pending msgs, "
+               "remove from priority q",
+               __func__, folderName.get()));
+    }
     autoSyncStateObj->SetState(nsAutoSyncState::stCompletedIdle);
 
     if (mPriorityQ.RemoveObject(autoSyncStateObj))
@@ -648,9 +712,10 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
   nsresult rv;
 
   // iterate through each imap account and update offline folders automatically
+  MOZ_LOG(gAutoSyncLog, LogLevel::Debug, ("enter %s", __func__));
 
   nsCOMPtr<nsIMsgAccountManager> accountManager =
-      do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
+      do_GetService("@mozilla.org/messenger/account-manager;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsTArray<RefPtr<nsIMsgAccount>> accounts;
@@ -669,10 +734,22 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
 
     if (!type.EqualsLiteral("imap")) continue;
 
-    // if we haven't logged onto this server yet, then skip this server.
-    bool passwordRequired;
-    incomingServer->GetServerRequiresPasswordForBiff(&passwordRequired);
-    if (passwordRequired) continue;
+    // If we haven't logged onto this server yet during this session or if the
+    // password has been removed from cache (see
+    // nsImapIncomingServer::ForgetSessionPassword) then skip autosync for
+    // this account.
+    bool notLoggedIn;
+    incomingServer->GetServerRequiresPasswordForBiff(&notLoggedIn);
+    if (notLoggedIn) {
+      if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+        nsCString serverName;
+        incomingServer->GetHostName(serverName);
+        MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                ("%s: server |%s| don't autosync; not yet logged in", __func__,
+                 serverName.get()));
+      }
+      continue;
+    }
 
     nsCOMPtr<nsIMsgFolder> rootFolder;
 
@@ -683,6 +760,27 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
       nsTArray<RefPtr<nsIMsgFolder>> allDescendants;
       rv = rootFolder->GetDescendants(allDescendants);
 
+      // Get the update time in minutes for each folder of this account/server.
+      // It will be the user configured biff time for server even if user has
+      // disabled "Check for new messages every X minutes" for the account.
+      // Update time will default to 10 minutes if an invalid value is set or
+      // if there are errors obtaining it.
+      // Specifically, the value used here is mail.server.serverX.check_time
+      // or the default mail.server.default.check_time.
+      int32_t updateMinutes = -1;
+      rv = incomingServer->GetBiffMinutes(&updateMinutes);
+      if (NS_FAILED(rv) || updateMinutes < 1)
+        updateMinutes = kDefaultUpdateInterval;
+      PRTime span = updateMinutes * (PR_USEC_PER_SEC * 60UL);
+      if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+        nsCString serverName;
+        incomingServer->GetHostName(serverName);
+        MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                ("%s: Update time set to |%d| minutes for "
+                 "folders in account |%s|",
+                 __func__, updateMinutes, serverName.get()));
+      }
+
       for (auto folder : allDescendants) {
         uint32_t folderFlags;
         rv = folder->GetFlags(&folderFlags);
@@ -717,17 +815,64 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
 
         int32_t state;
         rv = autoSyncState->GetState(&state);
-
-        if (NS_SUCCEEDED(rv) && nsAutoSyncState::stCompletedIdle == state) {
-          // ensure that we wait for at least nsMsgIncomingServer::BiffMinutes
-          // between each update of the same folder
+        nsCString folderName;
+        if (MOZ_LOG_TEST(gAutoSyncLog, LogLevel::Debug)) {
+          folder->GetURI(folderName);
+          MOZ_LOG(
+              gAutoSyncLog, LogLevel::Debug,
+              ("%s: folder=%s, state=%d", __func__, folderName.get(), state));
+        }
+        if (state == nsAutoSyncState::stCompletedIdle ||
+            state == nsAutoSyncState::stUpdateNeeded ||
+            state == nsAutoSyncState::stUpdateIssued) {
+          // Ensure that we wait for at least the "span" time set above before
+          // queuing an update of the same folder.
           PRTime lastUpdateTime;
           rv = autoSyncState->GetLastUpdateTime(&lastUpdateTime);
-          PRTime span =
-              GetUpdateIntervalFor(autoSyncState) * (PR_USEC_PER_SEC * 60UL);
           if (NS_SUCCEEDED(rv) && ((lastUpdateTime + span) < PR_Now())) {
-            if (mUpdateQ.IndexOf(autoSyncState) == -1) {
+            int32_t idx = mUpdateQ.IndexOf(autoSyncState);
+            if (state == nsAutoSyncState::stUpdateIssued) {
+              // Handle the case where an update is triggered but nothing is
+              // found to download. This can happen after messages are copied
+              // or moved between offline folders of the same server or if imap
+              // "folderstatus" URL triggers an update but no new messages
+              // are detected.
+              bool downloadQEmpty;
+              autoSyncState->IsDownloadQEmpty(&downloadQEmpty);
+              if (downloadQEmpty) {
+                MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                        ("%s: nothing to download for folder %s, "
+                         "set state to stCompletedIdle, updateQ idx=%d",
+                         __func__, folderName.get(), idx));
+                autoSyncState->SetState(nsAutoSyncState::stCompletedIdle);
+
+                // This should already be done by
+                // nsAutoSyncManager::OnStopRunningUrl() but set update state to
+                // completed and remove folder state object from update queue in
+                // case OnStopRunningUrl never occurred.
+                mUpdateInProgress = false;
+                if (idx > -1) {
+                  mUpdateQ.RemoveObjectAt(idx);
+                  idx = -1;  // re-q below
+                }
+              } else {
+                MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                        ("%s: downloadQ not empty. Why? updateQ idx=%d",
+                         __func__, idx));
+                if (idx > -1) {
+                  // Download q not empty and folder still on update q, maybe it
+                  // just needs more time so leave update q as it is to update
+                  // on next "span" interval. (Never seen this happen.)
+                  idx = 0;
+                }
+              }
+            }
+            // Now q or re-q the update for this folder unless it's still q'd.
+            if (idx < 0) {
               mUpdateQ.AppendObject(autoSyncState);
+              MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                      ("%s: folder=%s added to update q", __func__,
+                       folderName.get()));
               if (folder)
                 NOTIFY_LISTENERS(OnFolderAddedIntoQ,
                                  (nsIAutoSyncMgrListener::UpdateQueue, folder));
@@ -735,7 +880,8 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
           }
         }
 
-        // check last sync time
+        // Check if time to add folder to discovery q on kAutoSyncFreq (1 hour)
+        // time base.
         PRTime lastSyncTime;
         rv = autoSyncState->GetLastSyncTime(&lastSyncTime);
         if (NS_SUCCEEDED(rv) && ((lastSyncTime + kAutoSyncFreq) < PR_Now())) {
@@ -743,6 +889,9 @@ nsresult nsAutoSyncManager::AutoUpdateFolders() {
           // and discover messages not downloaded yet
           if (mDiscoveryQ.IndexOf(autoSyncState) == -1) {
             mDiscoveryQ.AppendObject(autoSyncState);
+            MOZ_LOG(gAutoSyncLog, LogLevel::Debug,
+                    ("%s: folder=%s added to discovery q", __func__,
+                     folderName.get()));
             if (folder)
               NOTIFY_LISTENERS(
                   OnFolderAddedIntoQ,
@@ -817,7 +966,7 @@ void nsAutoSyncManager::ScheduleFolderForOfflineDownload(
         NOTIFY_LISTENERS(OnFolderAddedIntoQ,
                          (nsIAutoSyncMgrListener::PriorityQueue, folderB));
         break;
-      }  // endwhile
+      }  // end while
     }
   }  // endif
 }
@@ -928,26 +1077,6 @@ nsresult nsAutoSyncManager::HandleDownloadErrorFor(
   return NS_OK;
 }
 
-uint32_t nsAutoSyncManager::GetUpdateIntervalFor(
-    nsIAutoSyncState* aAutoSyncStateObj) {
-  nsCOMPtr<nsIMsgFolder> folder;
-  nsresult rv = aAutoSyncStateObj->GetOwnerFolder(getter_AddRefs(folder));
-  if (NS_FAILED(rv)) return kDefaultUpdateInterval;
-
-  nsCOMPtr<nsIMsgIncomingServer> server;
-  rv = folder->GetServer(getter_AddRefs(server));
-  if (NS_FAILED(rv)) return kDefaultUpdateInterval;
-
-  if (server) {
-    int32_t interval;
-    rv = server->GetBiffMinutes(&interval);
-
-    if (NS_SUCCEEDED(rv)) return (uint32_t)interval;
-  }
-
-  return kDefaultUpdateInterval;
-}
-
 NS_IMETHODIMP nsAutoSyncManager::GetGroupSize(uint32_t* aGroupSize) {
   NS_ENSURE_ARG_POINTER(aGroupSize);
   *aGroupSize = mGroupSize;
