@@ -11,8 +11,8 @@
  * - removeIncomingServer(..., true); (cleanup files) fails.
  */
 
-var { MailServices } = ChromeUtils.import(
-  "resource:///modules/MailServices.jsm"
+var { MailServices } = ChromeUtils.importESModule(
+  "resource:///modules/MailServices.sys.mjs"
 );
 /* import-globals-from ../../../test/resources/alertTestUtils.js */
 load("../../../resources/alertTestUtils.js");
@@ -104,12 +104,12 @@ function nextTest() {
     var server = makeServer(daemon, "", {
       kAuthSchemes: thisTest.serverAuthMethods,
     });
-    server.setDebugLevel(fsDebugAll);
+    server.setDebugLevel(nsMailServer.debugAll);
 
     // If Mailnews ever caches server capabilities, delete and re-create the incomingServer here
     var incomingServer = createLocalIMAPServer(server.port);
 
-    let msgServer = incomingServer;
+    const msgServer = incomingServer;
     msgServer.QueryInterface(Ci.nsIMsgIncomingServer);
     msgServer.authMethod = thisTest.clientAuthMethod;
 
@@ -124,12 +124,11 @@ function nextTest() {
     do {
       incomingServer.closeCachedConnections();
     } while (incomingServer.serverBusy);
-    incomingServer.shutdown();
     deleteIMAPServer(incomingServer);
     incomingServer = null;
     MailServices.accounts.closeCachedConnections();
     MailServices.accounts.shutdownServers();
-    MailServices.accounts.UnloadAccounts();
+    MailServices.accounts.unloadAccounts();
     server.stop();
   } catch (e) {
     // server.stop();
@@ -156,7 +155,7 @@ function run_test() {
 }
 
 function endTest() {
-  var thread = gThreadManager.currentThread;
+  var thread = Services.tm.currentThread;
   while (thread.hasPendingEvents()) {
     thread.processNextEvent(true);
   }
