@@ -3,6 +3,17 @@ define(function (require) {
   var headerparser = require("jsmime").headerparser;
   var assert = require("assert");
 
+  function smartDeepEqual(actual, expected) {
+    assert.deepEqual(actual, expected);
+    // XXX: instanceof Map don't work for actual. Unclear why.
+    if ("entries" in actual && "entries" in expected) {
+      assert.deepEqual(
+        Array.from(actual.entries()),
+        Array.from(expected.entries())
+      );
+    }
+  }
+
   function arrayTest(data, fn) {
     fn.toString = function () {
       let text = Function.prototype.toString.call(this);
@@ -15,7 +26,7 @@ define(function (require) {
   }
   suite("headerparser", function () {
     suite("parseParameterHeader", function () {
-      let header_tests = [
+      const header_tests = [
         ["multipart/related", ["multipart/related", {}]],
         ["a ; b=v", ["a", { b: "v" }]],
         ["a ; b='v'", ["a", { b: "'v'" }]],
@@ -32,8 +43,8 @@ define(function (require) {
       ];
       header_tests.forEach(function (data) {
         arrayTest(data, function () {
-          let testMap = new Map();
-          for (let key in data[1][1]) {
+          const testMap = new Map();
+          for (const key in data[1][1]) {
             testMap.set(key, data[1][1][key]);
           }
           testMap.preSemi = data[1][0];
@@ -45,7 +56,7 @@ define(function (require) {
       });
     });
     suite("parseParameterHeader (2231/2047 support)", function () {
-      let header_tests = [
+      const header_tests = [
         // Copied from test_MIME_params.js and adapted
         ["attachment;", ["attachment", {}]],
         ["attachment; filename=basic", ["attachment", { filename: "basic" }]],
@@ -212,7 +223,7 @@ define(function (require) {
         ],
         [
           "attachment; filename=IT839\x04\xB5(m8)2.pdf;",
-          ["attachment", { filename: "IT839\u0004\u00b5(m8)2.pdf" }],
+          ["attachment", { filename: "IT839\u00b5(m8)2.pdf" }],
         ],
         ["attachment; filename*=utf-8''%41", ["attachment", { filename: "A" }]],
         // See bug 651185 and bug 703015
@@ -289,15 +300,20 @@ define(function (require) {
             "-8''5987",
           ["attachment", { filename: "5987" }],
         ],
+        // ABC\u202Etxt.zip dir switch char in middle.
+        [
+          "attachment; filename*=UTF-8''%41%42%43%E2%80%AE%2E%74%78%74%2E%7A%69%70",
+          ["attachment", { filename: "ABC .txt.zip" }],
+        ],
       ];
       header_tests.forEach(function (data) {
         arrayTest(data, function () {
-          let testMap = new Map();
-          for (let key in data[1][1]) {
+          const testMap = new Map();
+          for (const key in data[1][1]) {
             testMap.set(key, data[1][1][key]);
           }
           testMap.preSemi = data[1][0];
-          assert.deepEqual(
+          smartDeepEqual(
             headerparser.parseParameterHeader(data[0], true, true),
             testMap
           );
@@ -305,7 +321,7 @@ define(function (require) {
       });
     });
     suite("parseAddressingHeader", function () {
-      let header_tests = [
+      const header_tests = [
         ["", []],
         [
           "Joe Schmoe <jschmoe@invalid.invalid>",
@@ -742,7 +758,7 @@ define(function (require) {
       });
     });
     suite("parseAddressingHeader (RFC 2047 support)", function () {
-      let header_tests = [
+      const header_tests = [
         ["Simple <a@b.c>", [{ name: "Simple", email: "a@b.c" }]],
         ["=?UTF-8?Q?Simple?= <a@b.c>", [{ name: "Simple", email: "a@b.c" }]],
         ["=?UTF-8?Q?=3C@b.c?= <a@b.c>", [{ name: "<@b.c", email: "a@b.c" }]],
@@ -886,7 +902,7 @@ define(function (require) {
       });
     });
     suite("parseDateHeader", function () {
-      let header_tests = [
+      const header_tests = [
         // Some basic tests, derived from searching for Date headers in a mailing
         // list archive.
         ["Thu, 06 Sep 2012 08:08:21 -0700", "2012-09-06T08:08:21-0700"],
@@ -983,7 +999,7 @@ define(function (require) {
     });
 
     suite("decodeRFC2047Words", function () {
-      let header_tests = [
+      const header_tests = [
         // Some basic sanity tests for the test process
         ["Test", "Test"],
         ["Test 2", "Test 2"],
@@ -1168,7 +1184,7 @@ define(function (require) {
       });
     });
     suite("8-bit header processing", function () {
-      let header_tests = [
+      const header_tests = [
         // Non-ASCII header values
         ["oxyg\xc3\xa8ne", "oxyg\u00e8ne", "UTF-8"],
         ["oxyg\xc3\xa8ne", "oxyg\u00e8ne", "ISO-8859-1"], // UTF-8 overrides
