@@ -15,7 +15,7 @@
 #include "nsIURI.h"
 #include "nsIMsgWindow.h"
 #include "nsIMsgMailNewsUrl.h"
-#include "nsIMsgSMIMEHeaderSink.h"
+#include "nsIMsgSMIMESink.h"
 #include "nsCOMPtr.h"
 #include "nsIX509Cert.h"
 #include "nsServiceManagerUtils.h"
@@ -44,14 +44,13 @@ static void MimeCMS_free(void*);
 
 extern int SEC_ERROR_CERT_ADDR_MISMATCH;
 
-static int MimeEncryptedCMSClassInitialize(MimeEncryptedCMSClass* clazz) {
+static int MimeEncryptedCMSClassInitialize(MimeObjectClass* oclass) {
 #ifdef DEBUG
-  MimeObjectClass* oclass = (MimeObjectClass*)clazz;
   NS_ASSERTION(!oclass->class_initialized,
                "1.2 <mscott@netscape.com> 01 Nov 2001 17:59");
 #endif
 
-  MimeEncryptedClass* eclass = (MimeEncryptedClass*)clazz;
+  MimeEncryptedClass* eclass = (MimeEncryptedClass*)oclass;
   eclass->crypto_init = MimeCMS_init;
   eclass->crypto_write = MimeCMS_write;
   eclass->crypto_eof = MimeCMS_eof;
@@ -74,7 +73,7 @@ typedef struct MimeCMSdata {
   MimeObject* self;
   bool any_parent_is_encrypted_p;
   bool any_parent_is_signed_p;
-  nsCOMPtr<nsIMsgSMIMEHeaderSink> smimeHeaderSink;
+  nsCOMPtr<nsIMsgSMIMESink> smimeSink;
   nsCString url;
 
   MimeCMSdata()
@@ -128,7 +127,7 @@ bool MimeEncryptedCMS_encrypted_p(MimeObject* obj) {
     MimeEncrypted* enc = (MimeEncrypted*)obj;
     MimeCMSdata* data = (MimeCMSdata*)enc->crypto_closure;
     if (!data || !data->content_info) return false;
-    data->content_info->ContentIsEncrypted(&encrypted);
+    data->content_info->GetContentIsEncrypted(&encrypted);
     return encrypted;
   }
   return false;
@@ -145,7 +144,7 @@ bool MimeEncOrMP_CMS_signed_p(MimeObject* obj) {
     MimeEncrypted* enc = (MimeEncrypted*)obj;
     MimeCMSdata* data = (MimeCMSdata*)enc->crypto_closure;
     if (!data || !data->content_info) return false;
-    data->content_info->ContentIsSigned(&is_signed);
+    data->content_info->GetContentIsSigned(&is_signed);
     return is_signed;
   }
   return false;
@@ -234,7 +233,8 @@ class nsSMimeVerificationListener : public nsISMimeVerificationListener {
 
   nsSMimeVerificationListener(const char* aFromAddr, const char* aFromName,
                               const char* aSenderAddr, const char* aSenderName,
-                              nsIMsgSMIMEHeaderSink* aHeaderSink,
+                              const char* aMsgDate,
+                              nsIMsgSMIMESink* aHeaderSink,
                               int32_t aMimeNestingLevel,
                               const nsCString& aMsgNeckoURL,
                               const nsCString& aOriginMimePartNumber);
@@ -255,7 +255,7 @@ class nsSMimeVerificationListener : public nsISMimeVerificationListener {
    * Race-protection for XPCOM reference counting is sufficient.
    */
   bool mSinkIsNull;
-  nsMainThreadPtrHandle<nsIMsgSMIMEHeaderSink> mHeaderSink;
+  nsMainThreadPtrHandle<nsIMsgSMIMESink> mHeaderSink;
   int32_t mMimeNestingLevel;
   nsCString mMsgNeckoURL;
   nsCString mOriginMimePartNumber;
@@ -264,19 +264,20 @@ class nsSMimeVerificationListener : public nsISMimeVerificationListener {
   nsCString mFromName;
   nsCString mSenderAddr;
   nsCString mSenderName;
+  nsCString mMsgDate;
 };
 
 class SignedStatusRunnable : public mozilla::Runnable {
  public:
-  SignedStatusRunnable(
-      const nsMainThreadPtrHandle<nsIMsgSMIMEHeaderSink>& aSink,
-      int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert* aSignerCert,
-      const nsCString& aMsgNeckoURL, const nsCString& aOriginMimePartNumber);
+  SignedStatusRunnable(const nsMainThreadPtrHandle<nsIMsgSMIMESink>& aSink,
+                       int32_t aNestingLevel, int32_t aSignatureStatus,
+                       nsIX509Cert* aSignerCert, const nsCString& aMsgNeckoURL,
+                       const nsCString& aOriginMimePartNumber);
   NS_DECL_NSIRUNNABLE
   nsresult mResult;
 
  protected:
-  nsMainThreadPtrHandle<nsIMsgSMIMEHeaderSink> m_sink;
+  nsMainThreadPtrHandle<nsIMsgSMIMESink> m_sink;
   int32_t m_nestingLevel;
   int32_t m_signatureStatus;
   nsCOMPtr<nsIX509Cert> m_signerCert;
@@ -285,8 +286,8 @@ class SignedStatusRunnable : public mozilla::Runnable {
 };
 
 SignedStatusRunnable::SignedStatusRunnable(
-    const nsMainThreadPtrHandle<nsIMsgSMIMEHeaderSink>& aSink,
-    int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert* aSignerCert,
+    const nsMainThreadPtrHandle<nsIMsgSMIMESink>& aSink, int32_t aNestingLevel,
+    int32_t aSignatureStatus, nsIX509Cert* aSignerCert,
     const nsCString& aMsgNeckoURL, const nsCString& aOriginMimePartNumber)
     : mozilla::Runnable("SignedStatusRunnable"),
       mResult(NS_ERROR_UNEXPECTED),
@@ -304,10 +305,11 @@ NS_IMETHODIMP SignedStatusRunnable::Run() {
   return NS_OK;
 }
 
-nsresult ProxySignedStatus(
-    const nsMainThreadPtrHandle<nsIMsgSMIMEHeaderSink>& aSink,
-    int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert* aSignerCert,
-    const nsCString& aMsgNeckoURL, const nsCString& aOriginMimePartNumber) {
+nsresult ProxySignedStatus(const nsMainThreadPtrHandle<nsIMsgSMIMESink>& aSink,
+                           int32_t aNestingLevel, int32_t aSignatureStatus,
+                           nsIX509Cert* aSignerCert,
+                           const nsCString& aMsgNeckoURL,
+                           const nsCString& aOriginMimePartNumber) {
   RefPtr<SignedStatusRunnable> signedStatus = new SignedStatusRunnable(
       aSink, aNestingLevel, aSignatureStatus, aSignerCert, aMsgNeckoURL,
       aOriginMimePartNumber);
@@ -322,11 +324,11 @@ NS_IMPL_ISUPPORTS(nsSMimeVerificationListener, nsISMimeVerificationListener)
 
 nsSMimeVerificationListener::nsSMimeVerificationListener(
     const char* aFromAddr, const char* aFromName, const char* aSenderAddr,
-    const char* aSenderName, nsIMsgSMIMEHeaderSink* aHeaderSink,
+    const char* aSenderName, const char* aMsgDate, nsIMsgSMIMESink* aHeaderSink,
     int32_t aMimeNestingLevel, const nsCString& aMsgNeckoURL,
     const nsCString& aOriginMimePartNumber)
     : mMsgNeckoURL(aMsgNeckoURL), mOriginMimePartNumber(aOriginMimePartNumber) {
-  mHeaderSink = new nsMainThreadPtrHolder<nsIMsgSMIMEHeaderSink>(
+  mHeaderSink = new nsMainThreadPtrHolder<nsIMsgSMIMESink>(
       "nsSMimeVerificationListener::mHeaderSink", aHeaderSink);
   mSinkIsNull = !aHeaderSink;
   mMimeNestingLevel = aMimeNestingLevel;
@@ -335,6 +337,7 @@ nsSMimeVerificationListener::nsSMimeVerificationListener(
   mFromName = aFromName;
   mSenderAddr = aSenderAddr;
   mSenderName = aSenderName;
+  mMsgDate = aMsgDate;
 }
 
 NS_IMETHODIMP nsSMimeVerificationListener::Notify(
@@ -367,8 +370,33 @@ NS_IMETHODIMP nsSMimeVerificationListener::Notify(
         signature_status = nsICMSMessageErrors::VERIFY_CERT_WITHOUT_ADDRESS;
       else
         signature_status = nsICMSMessageErrors::VERIFY_HEADER_MISMATCH;
-    } else
-      signature_status = nsICMSMessageErrors::SUCCESS;
+    } else {
+      PRTime sigTime;
+      if (NS_FAILED(aVerifiedMessage->GetSigningTime(&sigTime))) {
+        // Signing time attribute is optional in CMS messages.
+        signature_status = nsICMSMessageErrors::SUCCESS;
+      } else {
+        // If it's present, check for a rough match with the message date.
+        PRTime msgTime;
+        if (PR_ParseTimeString(mMsgDate.get(), false, &msgTime) != PR_SUCCESS) {
+          signature_status = nsICMSMessageErrors::VERIFY_TIME_MISMATCH;
+        } else {
+          PRTime delta;
+
+          if (sigTime > msgTime) {
+            delta = sigTime - msgTime;
+          } else {
+            delta = msgTime - sigTime;
+          }
+
+          if (delta / PR_USEC_PER_SEC > 60 * 60 * 1) {
+            signature_status = nsICMSMessageErrors::VERIFY_TIME_MISMATCH;
+          } else {
+            signature_status = nsICMSMessageErrors::SUCCESS;
+          }
+        }
+      }
+    }
   }
 
   if (NS_IsMainThread()) {
@@ -518,7 +546,7 @@ static void* MimeCMS_init(MimeObject* obj,
         // we can learn that by looking at the additional header=filter
         // string contained in the URI.
         //
-        // If we find something, we do not set smimeHeaderSink,
+        // If we find something, we do not set smimeSink,
         // which will prevent us from giving UI feedback.
         //
         // If we do not find header=filter, we assume the result of the
@@ -530,8 +558,7 @@ static void* MimeCMS_init(MimeObject* obj,
             !strstr(data->url.get(), "&header=attach")) {
           nsCOMPtr<nsIMailChannel> mailChannel = do_QueryInterface(channel);
           if (mailChannel) {
-            mailChannel->GetSmimeHeaderSink(
-                getter_AddRefs(data->smimeHeaderSink));
+            mailChannel->GetSmimeSink(getter_AddRefs(data->smimeSink));
           }
         }
       }
@@ -558,14 +585,14 @@ static int MimeCMS_write(const char* buf, int32_t buf_size, void* closure) {
 
 void MimeCMSGetFromSender(MimeObject* obj, nsCString& from_addr,
                           nsCString& from_name, nsCString& sender_addr,
-                          nsCString& sender_name) {
+                          nsCString& sender_name, nsCString& msg_date) {
   MimeHeaders* msg_headers = 0;
 
   /* Find the headers of the MimeMessage which is the parent (or grandparent)
    of this object (remember, crypto objects nest.) */
   MimeObject* o2 = obj;
   msg_headers = o2->headers;
-  while (o2 && o2->parent &&
+  while (o2->parent &&
          !mime_typep(o2->parent, (MimeObjectClass*)&mimeMessageClass)) {
     o2 = o2->parent;
     msg_headers = o2->headers;
@@ -585,22 +612,32 @@ void MimeCMSGetFromSender(MimeObject* obj, nsCString& from_addr,
   s.Adopt(MimeHeaders_get(msg_headers, HEADER_SENDER, false, false));
   if (!s.IsEmpty())
     ExtractFirstAddress(EncodedHeader(s), sender_name, sender_addr);
+
+  msg_date.Adopt(MimeHeaders_get(msg_headers, HEADER_DATE, false, true));
 }
 
 void MimeCMSRequestAsyncSignatureVerification(
     nsICMSMessage* aCMSMsg, const char* aFromAddr, const char* aFromName,
-    const char* aSenderAddr, const char* aSenderName,
-    nsIMsgSMIMEHeaderSink* aHeaderSink, int32_t aMimeNestingLevel,
+    const char* aSenderAddr, const char* aSenderName, const char* aMsgDate,
+    nsIMsgSMIMESink* aHeaderSink, int32_t aMimeNestingLevel,
     const nsCString& aMsgNeckoURL, const nsCString& aOriginMimePartNumber,
     const nsTArray<uint8_t>& aDigestData, int16_t aDigestType) {
   RefPtr<nsSMimeVerificationListener> listener =
       new nsSMimeVerificationListener(
-          aFromAddr, aFromName, aSenderAddr, aSenderName, aHeaderSink,
+          aFromAddr, aFromName, aSenderAddr, aSenderName, aMsgDate, aHeaderSink,
           aMimeNestingLevel, aMsgNeckoURL, aOriginMimePartNumber);
+
+  long verifyFlags = 0;
+  if (mozilla::Preferences::GetBool(
+          "mail.smime.accept_insecure_sha1_message_signatures", false)) {
+    verifyFlags |= nsICMSVerifyFlags::VERIFY_ALLOW_WEAK_SHA1;
+  }
+
   if (aDigestData.IsEmpty())
-    aCMSMsg->AsyncVerifySignature(listener);
+    aCMSMsg->AsyncVerifySignature(verifyFlags, listener);
   else
-    aCMSMsg->AsyncVerifyDetachedSignature(listener, aDigestData, aDigestType);
+    aCMSMsg->AsyncVerifyDetachedSignature(verifyFlags, listener, aDigestData,
+                                          aDigestType);
 }
 
 static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
@@ -637,7 +674,7 @@ static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
 
   nsCOMPtr<nsIX509Cert> certOfInterest;
 
-  if (!data->smimeHeaderSink) return 0;
+  if (!data->smimeSink) return 0;
 
   if (aRelativeNestLevel < 0) return 0;
 
@@ -654,14 +691,14 @@ static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
     // of CMS objects, so let's make sure we replace the parent status
     // with a bad status.
     if (data->any_parent_is_signed_p) {
-      data->smimeHeaderSink->SignedStatus(aRelativeNestLevel,
-                                          nsICMSMessageErrors::GENERAL_ERROR,
-                                          nullptr, data->url, partnum);
+      data->smimeSink->SignedStatus(aRelativeNestLevel,
+                                    nsICMSMessageErrors::GENERAL_ERROR, nullptr,
+                                    data->url, partnum);
     }
     if (data->any_parent_is_encrypted_p) {
-      data->smimeHeaderSink->EncryptionStatus(
-          aRelativeNestLevel, nsICMSMessageErrors::GENERAL_ERROR, nullptr,
-          data->url, partnum);
+      data->smimeSink->EncryptionStatus(aRelativeNestLevel,
+                                        nsICMSMessageErrors::GENERAL_ERROR,
+                                        nullptr, data->url, partnum);
     }
     return 0;
   }
@@ -682,7 +719,7 @@ static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
 
     data->ci_is_encrypted = true;
   } else {
-    rv = data->content_info->ContentIsEncrypted(&data->ci_is_encrypted);
+    rv = data->content_info->GetContentIsEncrypted(&data->ci_is_encrypted);
 
     if (NS_SUCCEEDED(rv) && data->ci_is_encrypted) {
       data->content_info->GetEncryptionCert(getter_AddRefs(certOfInterest));
@@ -691,7 +728,7 @@ static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
       // signed. Make sure it indeed is signed.
 
       bool testIsSigned;
-      rv = data->content_info->ContentIsSigned(&testIsSigned);
+      rv = data->content_info->GetContentIsSigned(&testIsSigned);
 
       if (NS_FAILED(rv) || !testIsSigned) {
         // Neither signed nor encrypted?
@@ -704,20 +741,21 @@ static int MimeCMS_eof(void* crypto_closure, bool abort_p) {
       nsCString from_name;
       nsCString sender_addr;
       nsCString sender_name;
+      nsCString msg_date;
 
       MimeCMSGetFromSender(data->self, from_addr, from_name, sender_addr,
-                           sender_name);
+                           sender_name, msg_date);
 
       MimeCMSRequestAsyncSignatureVerification(
           data->content_info, from_addr.get(), from_name.get(),
-          sender_addr.get(), sender_name.get(), data->smimeHeaderSink,
+          sender_addr.get(), sender_name.get(), msg_date.get(), data->smimeSink,
           aRelativeNestLevel, data->url, partnum, {}, 0);
     }
   }
 
   if (data->ci_is_encrypted) {
-    data->smimeHeaderSink->EncryptionStatus(aRelativeNestLevel, status,
-                                            certOfInterest, data->url, partnum);
+    data->smimeSink->EncryptionStatus(aRelativeNestLevel, status,
+                                      certOfInterest, data->url, partnum);
   }
 
   return 0;
