@@ -35,7 +35,6 @@
 #include "comi18n.h"
 #include "nsIMsgAttachment.h"
 #include "nsIMsgCompFields.h"
-#include "nsMsgCompCID.h"
 #include "nsIMsgComposeService.h"
 #include "nsMsgAttachmentData.h"
 #include "nsMsgI18N.h"
@@ -43,10 +42,10 @@
 #include "nsDirectoryServiceDefs.h"
 #include "nsIMsgMessageService.h"
 #include "nsMsgUtils.h"
+#include "nsMsgCompUtils.h"
 #include "nsCExternalHandlerService.h"
 #include "nsIMIMEService.h"
 #include "nsIMsgAccountManager.h"
-#include "nsMsgBaseCID.h"
 #include "modmimee.h"  // for MimeConverterOutputCallback
 #include "mozilla/dom/Promise.h"
 #include "mozilla/mailnews/MimeHeaderParser.h"
@@ -74,7 +73,12 @@ int mime_decompose_file_output_fn(const char* buf, int32_t size,
 int mime_decompose_file_close_fn(void* stream_closure);
 extern int MimeHeaders_build_heads_list(MimeHeaders* hdrs);
 
-// CID's
+#define NS_MSGCOMPOSESERVICE_CID                    \
+  { /* 588595FE-1ADA-11d3-A715-0060B0EB39B5 */      \
+    0x588595fe, 0x1ada, 0x11d3, {                   \
+      0xa7, 0x15, 0x0, 0x60, 0xb0, 0xeb, 0x39, 0xb5 \
+    }                                               \
+  }
 static NS_DEFINE_CID(kCMsgComposeServiceCID, NS_MSGCOMPOSESERVICE_CID);
 
 mime_draft_data::mime_draft_data()
@@ -92,38 +96,6 @@ mime_draft_data::mime_draft_data()
       forwardInlineFilter(false),
       overrideComposeFormat(false),
       autodetectCharset(false) {}
-////////////////////////////////////////////////////////////////////////////////////
-////////////////////////////////////////////////////////////////////////////////////
-// THIS SHOULD ALL MOVE TO ANOTHER FILE AFTER LANDING!
-////////////////////////////////////////////////////////////////////////////////////
-////////////////////////////////////////////////////////////////////////////////////
-
-// safe filename for all OSes
-#define SAFE_TMP_FILENAME "nsmime.tmp"
-
-//
-// Create a file for the a unique temp file
-// on the local machine. Caller must free memory
-//
-nsresult nsMsgCreateTempFile(const char* tFileName, nsIFile** tFile) {
-  if (!tFileName || !*tFileName) tFileName = SAFE_TMP_FILENAME;
-
-  nsresult rv =
-      GetSpecialDirectoryWithFileName(NS_OS_TEMP_DIR, tFileName, tFile);
-
-  NS_ENSURE_SUCCESS(rv, rv);
-
-  rv = (*tFile)->CreateUnique(nsIFile::NORMAL_FILE_TYPE, 00600);
-  if (NS_FAILED(rv)) NS_RELEASE(*tFile);
-
-  return rv;
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-////////////////////////////////////////////////////////////////////////////////////
-// END OF - THIS SHOULD ALL MOVE TO ANOTHER FILE AFTER LANDING!
-////////////////////////////////////////////////////////////////////////////////////
-////////////////////////////////////////////////////////////////////////////////////
 
 typedef enum {
   nsMsg_RETURN_RECEIPT_BOOL_HEADER_MASK = 0,
@@ -181,8 +153,8 @@ nsresult CreateComposeParams(nsCOMPtr<nsIMsgComposeParams>& pMsgComposeParams,
     while (curAttachment && curAttachment->m_url) {
       rv = curAttachment->m_url->GetSpec(spec);
       if (NS_SUCCEEDED(rv)) {
-        nsCOMPtr<nsIMsgAttachment> attachment =
-            do_CreateInstance(NS_MSGATTACHMENT_CONTRACTID, &rv);
+        nsCOMPtr<nsIMsgAttachment> attachment = do_CreateInstance(
+            "@mozilla.org/messengercompose/attachment;1", &rv);
         if (NS_SUCCEEDED(rv) && attachment) {
           nsAutoString nameStr;
           rv = nsMsgI18NConvertToUnicode("UTF-8"_ns, curAttachment->m_realName,
@@ -199,14 +171,21 @@ nsresult CreateComposeParams(nsCOMPtr<nsIMsgComposeParams>& pMsgComposeParams,
           if (!curAttachment->m_cloudPartInfo.IsEmpty()) {
             nsCString provider;
             nsCString cloudUrl;
-            attachment->SetSendViaCloud(true);
+            nsCString cloudPartHeaderData;
+
             provider.Adopt(
                 MimeHeaders_get_parameter(curAttachment->m_cloudPartInfo.get(),
                                           "provider", nullptr, nullptr));
             cloudUrl.Adopt(MimeHeaders_get_parameter(
                 curAttachment->m_cloudPartInfo.get(), "url", nullptr, nullptr));
+            cloudPartHeaderData.Adopt(
+                MimeHeaders_get_parameter(curAttachment->m_cloudPartInfo.get(),
+                                          "data", nullptr, nullptr));
+
+            attachment->SetSendViaCloud(true);
             attachment->SetCloudFileAccountKey(provider);
             attachment->SetContentLocation(cloudUrl);
+            attachment->SetCloudPartHeaderData(cloudPartHeaderData);
           }
           compFields->AddAttachment(attachment);
         }
@@ -229,7 +208,8 @@ nsresult CreateComposeParams(nsCOMPtr<nsIMsgComposeParams>& pMsgComposeParams,
                    : nsIMsgCompFormat::PlainText;
   }
 
-  pMsgComposeParams = do_CreateInstance(NS_MSGCOMPOSEPARAMS_CONTRACTID, &rv);
+  pMsgComposeParams =
+      do_CreateInstance("@mozilla.org/messengercompose/composeparams;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   pMsgComposeParams->SetType(composeType);
@@ -281,7 +261,7 @@ nsresult ForwardMsgInline(nsIMsgCompFields* compFields,
   NS_ENSURE_SUCCESS(rv, rv);
   // create the nsIMsgCompose object to send the object
   nsCOMPtr<nsIMsgCompose> pMsgCompose(
-      do_CreateInstance(NS_MSGCOMPOSE_CONTRACTID, &rv));
+      do_CreateInstance("@mozilla.org/messengercompose/compose;1", &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   /** initialize nsIMsgCompose, Send the message, wait for send completion
@@ -307,14 +287,15 @@ nsresult CreateCompositionFields(
     const char* bcc, const char* fcc, const char* newsgroups,
     const char* followup_to, const char* organization, const char* subject,
     const char* references, const char* priority, const char* newspost_url,
-    char* charset, nsIMsgCompFields** _retval) {
+    const nsTArray<nsString>& otherHeaders, char* charset,
+    nsIMsgCompFields** _retval) {
   NS_ENSURE_ARG_POINTER(_retval);
 
   nsresult rv;
   *_retval = nullptr;
 
   nsCOMPtr<nsIMsgCompFields> cFields =
-      do_CreateInstance(NS_MSGCOMPFIELDS_CONTRACTID, &rv);
+      do_CreateInstance("@mozilla.org/messengercompose/composefields;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
   NS_ENSURE_TRUE(cFields, NS_ERROR_OUT_OF_MEMORY);
 
@@ -407,8 +388,19 @@ nsresult CreateCompositionFields(
     cFields->SetNewspostUrl(!val.IsEmpty() ? val.get() : newspost_url);
   }
 
+  nsTArray<nsString> cFieldsOtherHeaders;
+  cFields->GetOtherHeaders(cFieldsOtherHeaders);
+  for (auto otherHeader : otherHeaders) {
+    if (!otherHeader.IsEmpty()) {
+      MIME_DecodeMimeHeader(NS_ConvertUTF16toUTF8(otherHeader).get(), charset,
+                            false, true, val);
+      cFieldsOtherHeaders.AppendElement(NS_ConvertUTF8toUTF16(val));
+    } else {
+      cFieldsOtherHeaders.AppendElement(u""_ns);
+    }
+  }
+  cFields->SetOtherHeaders(cFieldsOtherHeaders);
   cFields.forget(_retval);
-
   return rv;
 }
 
@@ -453,12 +445,11 @@ static nsMsgAttachmentData* mime_draft_process_attachments(
   // It's possible we must treat the message body as attachment!
   bool bodyAsAttachment = false;
   if (mdd->messageBody && !mdd->messageBody->m_type.IsEmpty() &&
-      mdd->messageBody->m_type.Find("text/html", /* ignoreCase = */ true) ==
-          -1 &&
-      mdd->messageBody->m_type.Find("text/plain", /* ignoreCase = */ true) ==
-          -1 &&
-      !mdd->messageBody->m_type.LowerCaseEqualsLiteral("text"))
+      mdd->messageBody->m_type.LowerCaseFindASCII("text/html") == kNotFound &&
+      mdd->messageBody->m_type.LowerCaseFindASCII("text/plain") == kNotFound &&
+      !mdd->messageBody->m_type.LowerCaseEqualsLiteral("text")) {
     bodyAsAttachment = true;
+  }
 
   if (!mdd->attachments.Length() && !bodyAsAttachment) return nullptr;
 
@@ -491,8 +482,7 @@ static nsMsgAttachmentData* mime_draft_process_attachments(
         if (!tmpFile->m_realName.IsEmpty())
           tmp->m_realName = tmpFile->m_realName;
         else {
-          if (tmpFile->m_type.Find(MESSAGE_RFC822, /* ignoreCase = */ true) !=
-              -1)
+          if (tmpFile->m_type.LowerCaseFindASCII(MESSAGE_RFC822) != kNotFound)
             // we have the odd case of processing an e-mail that had an unnamed
             // eml message attached
             tmp->m_realName = "ForwardedMessage.eml";
@@ -1143,6 +1133,7 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
   char* draftInfo = 0;
   char* contentLanguage = 0;
   char* identityKey = 0;
+  nsTArray<nsString> readOtherHeaders;
 
   bool forward_inline = false;
   bool bodyAsAttachment = false;
@@ -1172,9 +1163,10 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
     if (mdd->options) {
       // save the override flag before it's unavailable
       charsetOverride = mdd->options->override_charset;
-      if ((!mdd->mailcharset || charsetOverride) &&
-          mdd->options->default_charset) {
-        PR_Free(mdd->mailcharset);
+      // Override the charset only if requested. If the message doesn't have
+      // one and we're not overriding, we'll detect it later.
+      if (charsetOverride && mdd->options->default_charset) {
+        PR_FREEIF(mdd->mailcharset);
         mdd->mailcharset = strdup(mdd->options->default_charset);
       }
 
@@ -1249,11 +1241,30 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
           news_host = PR_smprintf("news://%s", host);
         }
       }
+
+      // Other headers via pref.
+      nsCString otherHeaders;
+      nsTArray<nsCString> otherHeadersArray;
+      nsresult rv;
+      nsCOMPtr<nsIPrefBranch> pPrefBranch(
+          do_GetService(NS_PREFSERVICE_CONTRACTID, &rv));
+      pPrefBranch->GetCharPref("mail.compose.other.header", otherHeaders);
+      if (!otherHeaders.IsEmpty()) {
+        ToLowerCase(otherHeaders);
+        ParseString(otherHeaders, ',', otherHeadersArray);
+        for (auto otherHeader : otherHeadersArray) {
+          otherHeader.Trim(" ");
+          nsAutoCString result;
+          result.Assign(
+              MimeHeaders_get(mdd->headers, otherHeader.get(), false, false));
+          readOtherHeaders.AppendElement(NS_ConvertUTF8toUTF16(result));
+        }
+      }
     }
 
     CreateCompositionFields(from, repl, to, cc, bcc, fcc, grps, foll, org, subj,
-                            refs, priority, news_host, mdd->mailcharset,
-                            getter_AddRefs(fields));
+                            refs, priority, news_host, readOtherHeaders,
+                            mdd->mailcharset, getter_AddRefs(fields));
 
     contentLanguage =
         MimeHeaders_get(mdd->headers, HEADER_CONTENT_LANGUAGE, false, false);
@@ -1318,7 +1329,7 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
       PR_FREEIF(parm);
       parm = MimeHeaders_get_parameter(draftInfo, "deliveryformat", NULL, NULL);
       if (parm) {
-        int32_t deliveryFormat = nsIMsgCompSendFormat::AskUser;
+        int32_t deliveryFormat = nsIMsgCompSendFormat::Unset;
         sscanf(parm, "%d", &deliveryFormat);
         fields->SetDeliveryFormat(deliveryFormat);
       }
@@ -1331,7 +1342,7 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
     if (identityKey && *identityKey) {
       nsresult rv = NS_OK;
       nsCOMPtr<nsIMsgAccountManager> accountManager =
-          do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
+          do_GetService("@mozilla.org/messenger/account-manager;1", &rv);
       if (NS_SUCCEEDED(rv) && accountManager) {
         nsCOMPtr<nsIMsgIdentity> overrulingIdentity;
         rv = accountManager->GetIdentity(nsDependentCString(identityKey),
@@ -1347,11 +1358,11 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
     if (mdd->messageBody) {
       MSG_ComposeFormat composeFormat = nsIMsgCompFormat::Default;
       if (!mdd->messageBody->m_type.IsEmpty()) {
-        if (mdd->messageBody->m_type.Find("text/html",
-                                          /* ignoreCase = */ true) != -1)
+        if (mdd->messageBody->m_type.LowerCaseFindASCII("text/html") !=
+            kNotFound)
           composeFormat = nsIMsgCompFormat::HTML;
-        else if (mdd->messageBody->m_type.Find("text/plain",
-                                               /* ignoreCase = */ true) != -1 ||
+        else if (mdd->messageBody->m_type.LowerCaseFindASCII("text/plain") !=
+                     kNotFound ||
                  mdd->messageBody->m_type.LowerCaseEqualsLiteral("text"))
           composeFormat = nsIMsgCompFormat::PlainText;
         else
@@ -1400,12 +1411,24 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
             mimeCharset = MimeHeaders_get_parameter(
                 mdd->messageBody->m_type.get(), "charset", nullptr, nullptr);
           // If no charset is specified in the header then use the default.
-          char* bodyCharset = mimeCharset ? mimeCharset : mdd->mailcharset;
-          if (bodyCharset) {
+          nsAutoCString bodyCharset;
+          if (mimeCharset) {
+            bodyCharset.Adopt(mimeCharset);
+          } else if (mdd->mailcharset) {
+            bodyCharset.Assign(mdd->mailcharset);
+          }
+          if (bodyCharset.IsEmpty()) {
+            nsAutoCString detectedCharset;
+            // We need to detect it.
+            rv = MIME_detect_charset(body, bodyLen, detectedCharset);
+            if (NS_SUCCEEDED(rv) && !detectedCharset.IsEmpty()) {
+              bodyCharset = detectedCharset;
+            }
+          }
+          if (!bodyCharset.IsEmpty()) {
             nsAutoString tmpUnicodeBody;
-            rv = nsMsgI18NConvertToUnicode(nsDependentCString(bodyCharset),
-                                           nsDependentCString(body),
-                                           tmpUnicodeBody);
+            rv = nsMsgI18NConvertToUnicode(
+                bodyCharset, nsDependentCString(body), tmpUnicodeBody);
             if (NS_FAILED(rv))  // Tough luck, ASCII/ISO-8859-1 then...
               CopyASCIItoUTF16(nsDependentCString(body), tmpUnicodeBody);
 
@@ -1415,7 +1438,6 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
               body = newBody;
             }
           }
-          PR_FREEIF(mimeCharset);
         }
       }
 
@@ -1454,11 +1476,14 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
 
       MSG_ComposeType msgComposeType = 0;  // Keep compilers happy.
       if (mdd->format_out == nsMimeOutput::nsMimeMessageEditorTemplate) {
-        if (PL_strstr(mdd->url_name, "&redirect=true"))
+        if (PL_strstr(mdd->url_name, "?redirect=true") ||
+            PL_strstr(mdd->url_name, "&redirect=true"))
           msgComposeType = nsIMsgCompType::Redirect;
-        else if (PL_strstr(mdd->url_name, "&editasnew=true"))
+        else if (PL_strstr(mdd->url_name, "?editasnew=true") ||
+                 PL_strstr(mdd->url_name, "&editasnew=true"))
           msgComposeType = nsIMsgCompType::EditAsNew;
-        else if (PL_strstr(mdd->url_name, "&edittempl=true"))
+        else if (PL_strstr(mdd->url_name, "?edittempl=true") ||
+                 PL_strstr(mdd->url_name, "&edittempl=true"))
           msgComposeType = nsIMsgCompType::EditTemplate;
         else
           msgComposeType = nsIMsgCompType::Template;
@@ -1593,8 +1618,8 @@ static void mime_parse_stream_complete(nsMIMESession* stream) {
     }
   } else {
     CreateCompositionFields(from, repl, to, cc, bcc, fcc, grps, foll, org, subj,
-                            refs, priority, news_host, mdd->mailcharset,
-                            getter_AddRefs(fields));
+                            refs, priority, news_host, readOtherHeaders,
+                            mdd->mailcharset, getter_AddRefs(fields));
     if (fields)
       CreateTheComposeWindow(fields, newAttachData, nsIMsgCompType::New,
                              nsIMsgCompFormat::Default, mdd->identity,
@@ -1807,18 +1832,6 @@ int mime_decompose_file_init_fn(void* stream_closure, MimeHeaders* headers) {
   newAttachment->m_cloudPartInfo.Adopt(
       MimeHeaders_get(headers, HEADER_X_MOZILLA_CLOUD_PART, false, false));
 
-  // There's no file in the message if it's a cloud part.
-  if (!newAttachment->m_cloudPartInfo.IsEmpty()) {
-    nsAutoCString fileURL;
-    fileURL.Adopt(MimeHeaders_get_parameter(
-        newAttachment->m_cloudPartInfo.get(), "file", nullptr, nullptr));
-    if (!fileURL.IsEmpty())
-      nsMimeNewURI(getter_AddRefs(newAttachment->m_origUrl), fileURL.get(),
-                   nullptr);
-    mdd->tmpFile = nullptr;
-    return 0;
-  }
-
   nsCOMPtr<nsIFile> tmpFile = nullptr;
   {
     // Let's build a temp file with an extension based on the content-type:
