@@ -110,14 +110,9 @@
 #include "nsMimeTypes.h"
 #include "mimebuf.h"
 #include "nsMsgUtils.h"
+#include "nsMsgCompUtils.h"
 #include <ctype.h>
 
-//
-// External Defines...
-//
-
-extern nsresult nsMsgCreateTempFile(const char* tFileName, nsIFile** tFile);
-
 #define MIME_SUPERCLASS mimeMultipartClass
 MimeDefClass(MimeMultipartRelated, MimeMultipartRelatedClass,
              mimeMultipartRelatedClass, &MIME_SUPERCLASS);
@@ -393,9 +388,6 @@ static bool MimeMultipartRelated_output_child_p(MimeObject* obj,
                                                 MimeObject* child) {
   MimeMultipartRelated* relobj = (MimeMultipartRelated*)obj;
 
-  /* rhp - Changed from "if (relobj->head_loaded)" alone to support the
-           start parameter
-   */
   if ((relobj->head_loaded) ||
       (MimeStartParamExists(obj, child) && !MimeThisIsStartPart(obj, child))) {
     /* This is a child part.  Just remember the mapping between the URL
@@ -422,10 +414,9 @@ static bool MimeMultipartRelated_output_child_p(MimeObject* obj,
     }
 
     if (location) {
-      char* absolute;
       char* base_url =
           MimeHeaders_get(child->headers, HEADER_CONTENT_BASE, false, false);
-      absolute =
+      char* absolute =
           MakeAbsoluteURL(base_url ? base_url : relobj->base_url, location);
 
       PR_FREEIF(base_url);
@@ -469,6 +460,21 @@ static bool MimeMultipartRelated_output_child_p(MimeObject* obj,
           if (part) {
             char* name = MimeHeaders_get_name(child->headers, child->options);
             // let's stick the filename in the part so save as will work.
+            if (!name) {
+              // Mozilla platform code will correct the file extension
+              // when copying the embedded image. That doesn't work
+              // since our MailNews URLs don't allow setting the file
+              // extension. So provide a filename and valid extension.
+              char* ct = MimeHeaders_get(child->headers, HEADER_CONTENT_TYPE,
+                                         false, false);
+              if (ct) {
+                name = ct;
+                char* slash = strchr(name, '/');
+                if (slash) *slash = '.';
+                char* semi = strchr(name, ';');
+                if (semi) *semi = 0;
+              }
+            }
             if (name) {
               char* savePart = part;
               part = PR_smprintf("%s&filename=%s", savePart, name);
@@ -530,25 +536,26 @@ static bool MimeMultipartRelated_output_child_p(MimeObject* obj,
     }
   } else {
     /* Ah-hah!  We're the head object.  */
-    char* base_url;
     relobj->head_loaded = true;
     relobj->headobj = child;
     relobj->buffered_hdrs = MimeHeaders_copy(child->headers);
-    base_url =
+    char* base_url =
         MimeHeaders_get(child->headers, HEADER_CONTENT_BASE, false, false);
-    /* rhp: need this for supporting Content-Location */
     if (!base_url) {
       base_url = MimeHeaders_get(child->headers, HEADER_CONTENT_LOCATION, false,
                                  false);
     }
-    /* rhp: need this for supporting Content-Location */
 
     if (base_url) {
       /* If the head object has a base_url associated with it, use
          that instead of any base_url that may have been associated
          with the multipart/related. */
       PR_FREEIF(relobj->base_url);
-      relobj->base_url = base_url;
+      nsCOMPtr<nsIURI> url;
+      nsresult rv = nsMimeNewURI(getter_AddRefs(url), base_url, nullptr);
+      if (NS_SUCCEEDED(rv)) {
+        relobj->base_url = base_url;
+      }
     }
   }
   if (obj->options && !obj->options->write_html_p
@@ -1087,10 +1094,8 @@ FAIL:
   return status;
 }
 
-static int MimeMultipartRelatedClassInitialize(
-    MimeMultipartRelatedClass* clazz) {
-  MimeObjectClass* oclass = (MimeObjectClass*)clazz;
-  MimeMultipartClass* mclass = (MimeMultipartClass*)clazz;
+static int MimeMultipartRelatedClassInitialize(MimeObjectClass* oclass) {
+  MimeMultipartClass* mclass = (MimeMultipartClass*)oclass;
   PR_ASSERT(!oclass->class_initialized);
   oclass->initialize = MimeMultipartRelated_initialize;
   oclass->finalize = MimeMultipartRelated_finalize;
