@@ -1,17 +1,17 @@
-/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /* import-globals-from searchTerm.js */
 
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-var { MailServices } = ChromeUtils.import(
-  "resource:///modules/MailServices.jsm"
+var { MailServices } = ChromeUtils.importESModule(
+  "resource:///modules/MailServices.sys.mjs"
 );
-var { MailUtils } = ChromeUtils.import("resource:///modules/MailUtils.jsm");
-var { PluralForm } = ChromeUtils.import(
-  "resource://gre/modules/PluralForm.jsm"
+var { MailUtils } = ChromeUtils.importESModule(
+  "resource:///modules/MailUtils.sys.mjs"
+);
+var { PluralForm } = ChromeUtils.importESModule(
+  "resource:///modules/PluralForm.sys.mjs"
 );
 
 // The actual filter that we're editing if it is a _saved_ filter or prefill;
@@ -54,16 +54,12 @@ var gFilterActionStrings = [
 
 // A temporary filter with the current state of actions in the UI.
 var gTempFilter = null;
-// A nsIArray of the currently defined actions in the order they will be run.
+// nsIMsgRuleAction[] - the currently defined actions in the order they will be run.
 var gActionListOrdered = null;
 
 var gFilterEditorMsgWindow = null;
 
-var nsMsgFilterAction = Ci.nsMsgFilterAction;
-var nsMsgFilterType = Ci.nsMsgFilterType;
-var nsIMsgRuleAction = Ci.nsIMsgRuleAction;
-var nsMsgSearchScope = Ci.nsMsgSearchScope;
-
+window.addEventListener("DOMContentLoaded", filterEditorOnLoad, { once: true });
 document.addEventListener("dialogaccept", onAccept);
 
 function filterEditorOnLoad() {
@@ -80,7 +76,7 @@ function filterEditorOnLoad() {
       gFilterList = args.filterList;
       // the postPlugin filters cannot be applied to servers that are
       // deferred, (you must define them on the deferredTo server instead).
-      let server = gFilterList.folder.server;
+      const server = gFilterList.folder.server;
       if (server.rootFolder != server.rootMsgFolder) {
         gFilterTypeSelector.disableDeferredAccount();
       }
@@ -137,29 +133,29 @@ function filterEditorOnLoad() {
         // for everything else, it's MoveToFolder
         var filterAction = gFilter.createAction();
         filterAction.type =
-          getScopeFromFilterList(gFilterList) == nsMsgSearchScope.newsFilter
-            ? nsMsgFilterAction.Delete
-            : nsMsgFilterAction.MoveToFolder;
+          getScopeFromFilterList(gFilterList) == Ci.nsMsgSearchScope.newsFilter
+            ? Ci.nsMsgFilterAction.Delete
+            : Ci.nsMsgFilterAction.MoveToFolder;
         gFilter.appendAction(filterAction);
         initializeDialog(gFilter);
       } else if ("copiedFilter" in args) {
         // we are copying a filter
-        let copiedFilter = args.copiedFilter;
-        let copiedName = gFilterBundle.getFormattedString(
+        const copiedFilter = args.copiedFilter;
+        const copiedName = gFilterBundle.getFormattedString(
           "copyToNewFilterName",
           [copiedFilter.filterName]
         );
-        let newFilter = gFilterList.createFilter(copiedName);
+        const newFilter = gFilterList.createFilter(copiedName);
 
         // copy the actions
         for (let i = 0; i < copiedFilter.actionCount; i++) {
-          let filterAction = copiedFilter.getActionAt(i);
+          const filterAction = copiedFilter.getActionAt(i);
           newFilter.appendAction(filterAction);
         }
 
         // copy the search terms
-        for (let searchTerm of copiedFilter.searchTerms) {
-          let newTerm = newFilter.createTerm();
+        for (const searchTerm of copiedFilter.searchTerms) {
+          const newTerm = newFilter.createTerm();
           newTerm.attrib = searchTerm.attrib;
           newTerm.op = searchTerm.op;
           newTerm.booleanAnd = searchTerm.booleanAnd;
@@ -188,7 +184,7 @@ function filterEditorOnLoad() {
   if (!gFilter) {
     // This is a new filter. Set to both Incoming and Manual contexts.
     gFilterTypeSelector.setType(
-      nsMsgFilterType.Incoming | nsMsgFilterType.Manual
+      Ci.nsMsgFilterType.Incoming | Ci.nsMsgFilterType.Manual
     );
   }
 
@@ -218,7 +214,7 @@ function onAccept(event) {
       return;
     }
   } catch (e) {
-    Cu.reportError(e);
+    console.error(e);
     event.preventDefault();
     return;
   }
@@ -244,7 +240,7 @@ function duplicateFilterNameExists(filterName) {
 function getScopeFromFilterList(filterList) {
   if (!filterList) {
     dump("yikes, null filterList\n");
-    return nsMsgSearchScope.offlineMail;
+    return Ci.nsMsgSearchScope.offlineMail;
   }
   return filterList.folder.server.filterScope;
 }
@@ -279,37 +275,37 @@ function initializeFilterTypeSelector() {
 
     /**
      * Returns the currently set filter type (checkboxes) in terms
-     * of a Ci.nsMsgFilterType value.
+     * of a Ci.Ci.nsMsgFilterType value.
      */
     getType() {
-      let type = nsMsgFilterType.None;
+      let type = Ci.nsMsgFilterType.None;
 
       if (this.checkBoxManual.checked) {
-        type |= nsMsgFilterType.Manual;
+        type |= Ci.nsMsgFilterType.Manual;
       }
 
       if (this.checkBoxIncoming.checked) {
         if (this.menulistIncoming.selectedItem == this.menuitemAfterPlugins) {
-          type |= nsMsgFilterType.PostPlugin;
+          type |= Ci.nsMsgFilterType.PostPlugin;
         } else if (
-          getScopeFromFilterList(gFilterList) == nsMsgSearchScope.newsFilter
+          getScopeFromFilterList(gFilterList) == Ci.nsMsgSearchScope.newsFilter
         ) {
-          type |= nsMsgFilterType.NewsRule;
+          type |= Ci.nsMsgFilterType.NewsRule;
         } else {
-          type |= nsMsgFilterType.InboxRule;
+          type |= Ci.nsMsgFilterType.InboxRule;
         }
       }
 
       if (this.checkBoxArchive.checked) {
-        type |= nsMsgFilterType.Archive;
+        type |= Ci.nsMsgFilterType.Archive;
       }
 
       if (this.checkBoxOutgoing.checked) {
-        type |= nsMsgFilterType.PostOutgoing;
+        type |= Ci.nsMsgFilterType.PostOutgoing;
       }
 
       if (this.checkBoxPeriodic.checked) {
-        type |= nsMsgFilterType.Periodic;
+        type |= Ci.nsMsgFilterType.Periodic;
       }
 
       return type;
@@ -319,29 +315,29 @@ function initializeFilterTypeSelector() {
      * Sets the checkboxes to represent the filter type passed in.
      *
      * @param aType  the filter type to set in terms
-     *               of Ci.nsMsgFilterType values.
+     *               of Ci.Ci.nsMsgFilterType values.
      */
     setType(aType) {
       // If there is no type (event) requested, force "when manually run"
-      if (aType == nsMsgFilterType.None) {
-        aType = nsMsgFilterType.Manual;
+      if (aType == Ci.nsMsgFilterType.None) {
+        aType = Ci.nsMsgFilterType.Manual;
       }
 
-      this.checkBoxManual.checked = aType & nsMsgFilterType.Manual;
+      this.checkBoxManual.checked = aType & Ci.nsMsgFilterType.Manual;
 
       this.checkBoxIncoming.checked =
-        aType & (nsMsgFilterType.PostPlugin | nsMsgFilterType.Incoming);
+        aType & (Ci.nsMsgFilterType.PostPlugin | Ci.nsMsgFilterType.Incoming);
 
       this.menulistIncoming.selectedItem =
-        aType & nsMsgFilterType.PostPlugin
+        aType & Ci.nsMsgFilterType.PostPlugin
           ? this.menuitemAfterPlugins
           : this.menuitemBeforePlugins;
 
-      this.checkBoxArchive.checked = aType & nsMsgFilterType.Archive;
+      this.checkBoxArchive.checked = aType & Ci.nsMsgFilterType.Archive;
 
-      this.checkBoxOutgoing.checked = aType & nsMsgFilterType.PostOutgoing;
+      this.checkBoxOutgoing.checked = aType & Ci.nsMsgFilterType.PostOutgoing;
 
-      this.checkBoxPeriodic.checked = aType & nsMsgFilterType.Periodic;
+      this.checkBoxPeriodic.checked = aType & Ci.nsMsgFilterType.Periodic;
       const periodMinutes = gFilterList.folder.server.getIntValue(
         "periodicFilterRateMinutes"
       );
@@ -376,11 +372,11 @@ function initializeDialog(filter) {
   gFilterNameElement.value = filter.filterName;
   gFilterTypeSelector.setType(filter.filterType);
 
-  let numActions = filter.actionCount;
+  const numActions = filter.actionCount;
   for (let actionIndex = 0; actionIndex < numActions; actionIndex++) {
-    let filterAction = filter.getActionAt(actionIndex);
+    const filterAction = filter.getActionAt(actionIndex);
 
-    let newActionRow = document.createXULElement("richlistitem", {
+    const newActionRow = document.createXULElement("richlistitem", {
       is: "ruleaction-richlistitem",
     });
     newActionRow.setAttribute("initialActionIndex", actionIndex);
@@ -388,7 +384,7 @@ function initializeDialog(filter) {
     gFilterActionList.appendChild(newActionRow);
     newActionRow.setAttribute(
       "value",
-      filterAction.type == nsMsgFilterAction.Custom
+      filterAction.type == Ci.nsMsgFilterAction.Custom
         ? filterAction.customId
         : gFilterActionStrings[filterAction.type]
     );
@@ -407,7 +403,7 @@ function initializeDialog(filter) {
 function ensureActionRow() {
   // make sure we have at least one action row visible to the user
   if (!gFilterActionList.getRowCount()) {
-    let newActionRow = document.createXULElement("richlistitem", {
+    const newActionRow = document.createXULElement("richlistitem", {
       is: "ruleaction-richlistitem",
     });
     newActionRow.className = "ruleaction";
@@ -419,7 +415,7 @@ function ensureActionRow() {
 // move to overlay
 function saveFilter() {
   // See if at least one filter type (activation event) is selected.
-  if (gFilterType == nsMsgFilterType.None) {
+  if (gFilterType == Ci.nsMsgFilterType.None) {
     Services.prompt.alert(
       window,
       gFilterBundle.getString("mustHaveFilterTypeTitle"),
@@ -428,7 +424,7 @@ function saveFilter() {
     return false;
   }
 
-  let filterName = gFilterNameElement.value;
+  const filterName = gFilterNameElement.value;
   // If we think have a duplicate, then we need to check that if we
   // have an original filter name (i.e. we are editing a filter), then
   // we must check that the original is not the current as that is what
@@ -460,26 +456,26 @@ function saveFilter() {
 
   let invalidRule = false;
   for (let index = 0; index < gSearchTerms.length; index++) {
-    let obj = gSearchTerms[index].obj;
+    const obj = gSearchTerms[index].obj;
     // We don't need to check validity of matchAll terms
     if (obj.matchAll) {
       continue;
     }
 
     // the term might be an offscreen one that we haven't initialized yet
-    let searchTerm = obj.searchTerm;
+    const searchTerm = obj.searchTerm;
     if (!searchTerm && !gSearchTerms[index].initialized) {
       continue;
     }
 
     if (isNaN(obj.searchattribute.value)) {
       // is this a custom term?
-      let customTerm = MailServices.filters.getCustomTerm(
+      const customTerm = MailServices.filters.getCustomTerm(
         obj.searchattribute.value
       );
       if (!customTerm) {
         invalidRule = true;
-        Cu.reportError(
+        console.error(
           "Filter not saved because custom search term '" +
             obj.searchattribute.value +
             "' in rule " +
@@ -490,7 +486,7 @@ function saveFilter() {
         !customTerm.getAvailable(obj.searchScope, obj.searchattribute.value)
       ) {
         invalidRule = true;
-        Cu.reportError(
+        console.error(
           "Filter not saved because custom search term '" +
             customTerm.name +
             "' in rule " +
@@ -499,8 +495,8 @@ function saveFilter() {
         );
       }
     } else {
-      let otherHeader = Ci.nsMsgSearchAttrib.OtherHeader;
-      let attribValue =
+      const otherHeader = Ci.nsMsgSearchAttrib.OtherHeader;
+      const attribValue =
         obj.searchattribute.value > otherHeader
           ? otherHeader
           : obj.searchattribute.value;
@@ -511,7 +507,7 @@ function saveFilter() {
         )
       ) {
         invalidRule = true;
-        Cu.reportError(
+        console.error(
           "Filter not saved because standard search term '" +
             attribValue +
             "' in rule " +
@@ -616,7 +612,7 @@ function _checkActionsReorder() {
   gActionListOrdered = gTempFilter.sortedActionList;
 
   // Compare the two lists.
-  let statusBar = document.getElementById("statusbar");
+  const statusBar = document.getElementById("statusbar");
   for (let index = 0; index < gActionListOrdered.length; index++) {
     if (index != gTempFilter.getActionIndex(gActionListOrdered[index])) {
       // If the lists are not the same unhide the status bar and show warning.
@@ -636,14 +632,14 @@ function _checkActionsReorder() {
  */
 function showActionsOrder() {
   // Fetch the actions and arguments as a string.
-  let actionStrings = [];
+  const actionStrings = [];
   for (let i = 0; i < gFilterActionList.itemCount; i++) {
-    let ruleAction = gFilterActionList.getItemAtIndex(i);
-    let actionTarget = ruleAction.children[1];
-    let actionItem = actionTarget.ruleactiontargetElement;
-    let actionItemLabel = actionItem && actionItem.children[0].label;
+    const ruleAction = gFilterActionList.getItemAtIndex(i);
+    const actionTarget = ruleAction.children[1];
+    const actionItem = actionTarget.ruleactiontargetElement;
+    const actionItemLabel = actionItem && actionItem.children[0].label;
 
-    let actionString = {
+    const actionString = {
       label: ruleAction.mRuleActionType.label,
       argument: "",
     };
@@ -660,8 +656,8 @@ function showActionsOrder() {
   // Present a nicely formatted list of action names and arguments.
   let actionList = gFilterBundle.getString("filterActionOrderExplanation");
   for (let i = 0; i < gActionListOrdered.length; i++) {
-    let actionIndex = gTempFilter.getActionIndex(gActionListOrdered[i]);
-    let action = actionStrings[actionIndex];
+    const actionIndex = gTempFilter.getActionIndex(gActionListOrdered[i]);
+    const action = actionStrings[actionIndex];
     actionList += gFilterBundle.getFormattedString("filterActionItem", [
       i + 1,
       action.label,
@@ -684,7 +680,7 @@ function showActionsOrder() {
 
 function AssignMeaningfulName() {
   // termRoot points to the first search object, which is the one we care about.
-  let termRoot = gSearchTerms[0].obj;
+  const termRoot = gSearchTerms[0].obj;
   // stub is used as the base name for a filter.
   let stub;
 
@@ -693,49 +689,14 @@ function AssignMeaningfulName() {
     stub = gFilterBundle.getString("matchAllFilterName");
   } else {
     // Assign a name based on the first search term.
-    let searchValue = termRoot.searchvalue;
-    let activeItem = searchValue.findActiveItem();
-
-    // Values are either popup menu items or edit fields.
-    // For popup menus use activeItem.label; for
-    // edit fields, activeItem.value
-    let value;
-    switch (Number(termRoot.searchattribute.value)) {
-      case Ci.nsMsgSearchAttrib.Priority:
-      case Ci.nsMsgSearchAttrib.MsgStatus:
-      case Ci.nsMsgSearchAttrib.Keywords:
-      case Ci.nsMsgSearchAttrib.HasAttachmentStatus:
-      case Ci.nsMsgSearchAttrib.JunkStatus:
-      case Ci.nsMsgSearchAttrib.JunkScoreOrigin:
-        value = activeItem ? activeItem.label : "";
-        break;
-
-      default:
-        try {
-          value = activeItem.value;
-        } catch (ex) {
-          // We should never get here, but for safety's sake,
-          // let's name the filter "Untitled Filter".
-          stub = gFilterBundle.getString("untitledFilterName");
-          // Do not 'Return'. Instead fall through and deal with the untitled filter below.
-        }
-        break;
-    }
-    // We are now ready to name the filter.
-    // If at this point stub is empty, we know that this is not a Match All Filter
-    // and is not an "untitledFilterName" Filter, so assign it a name using
-    // a string format from the Filter Bundle.
-    if (!stub) {
-      // Term, Operator and Value are the three parts of a filter match.
-      // Term and Operator are easy to retrieve.
-      let term = termRoot.searchattribute.label;
-      let operator = termRoot.searchoperator.label;
-      stub = gFilterBundle.getFormattedString("filterAutoNameStr", [
-        term,
-        operator,
-        value,
-      ]);
-    }
+    const term = termRoot.searchattribute.label;
+    const operator = termRoot.searchoperator.label;
+    const value = termRoot.searchvalue.getReadableValue();
+    stub = gFilterBundle.getFormattedString("filterAutoNameStr", [
+      term,
+      operator,
+      value,
+    ]);
   }
 
   // Whatever name we have used, 'uniquify' it.
@@ -743,7 +704,7 @@ function AssignMeaningfulName() {
   let count = 1;
   while (duplicateFilterNameExists(tempName)) {
     count++;
-    tempName = stub + " " + count;
+    tempName = `${stub} ${count}`;
   }
   gFilter.filterName = tempName;
 }
@@ -752,20 +713,6 @@ function UpdateAfterCustomHeaderChange() {
   updateSearchAttributes();
 }
 
-// if you use msgWindow, please make sure that destructor gets called when you close the "window"
-function GetFilterEditorMsgWindow() {
-  if (!gFilterEditorMsgWindow) {
-    var msgWindowContractID = "@mozilla.org/messenger/msgwindow;1";
-    var nsIMsgWindow = Ci.nsIMsgWindow;
-    gFilterEditorMsgWindow = Cc[msgWindowContractID].createInstance(
-      nsIMsgWindow
-    );
-    gFilterEditorMsgWindow.domWindow = window;
-    gFilterEditorMsgWindow.rootDocShell.appType = Ci.nsIDocShell.APP_TYPE_MAIL;
-  }
-  return gFilterEditorMsgWindow;
-}
-
 function SetBusyCursor(window, enable) {
   // setCursor() is only available for chrome windows.
   // However one of our frames is the start page which
@@ -808,7 +755,7 @@ function updateFilterType() {
 
 // Given a filter type, set the global search scope to the filter scope
 function setFilterScope(aFilterType, aFilterList) {
-  let filterScope = getFilterScope(
+  const filterScope = getFilterScope(
     getScopeFromFilterList(aFilterList),
     aFilterType,
     aFilterList
@@ -822,17 +769,17 @@ function setFilterScope(aFilterType, aFilterList) {
 // hierarchy of contexts, with incoming the most restrictive,
 // followed by manual and post-plugin.
 function getFilterScope(aServerFilterScope, aFilterType, aFilterList) {
-  if (aFilterType & nsMsgFilterType.Incoming) {
+  if (aFilterType & Ci.nsMsgFilterType.Incoming) {
     return aServerFilterScope;
   }
 
   // Manual or PostPlugin
   // local mail allows body and junk types
-  if (aServerFilterScope == nsMsgSearchScope.offlineMailFilter) {
-    return nsMsgSearchScope.offlineMail;
+  if (aServerFilterScope == Ci.nsMsgSearchScope.offlineMailFilter) {
+    return Ci.nsMsgSearchScope.offlineMail;
   }
   // IMAP and NEWS online don't allow body
-  return nsMsgSearchScope.onlineManual;
+  return Ci.nsMsgSearchScope.onlineManual;
 }
 
 /**
