@@ -4,8 +4,8 @@
 
 // Tests that custom headers like "Sender" work (bug 404489)
 
-var { MailServices } = ChromeUtils.import(
-  "resource:///modules/MailServices.jsm"
+var { MailServices } = ChromeUtils.importESModule(
+  "resource:///modules/MailServices.sys.mjs"
 );
 
 var Contains = Ci.nsMsgSearchOp.Contains;
@@ -182,8 +182,6 @@ function TestSearchx(aFolder, aValue, aAttrib, aOp, aHitCount, onDone) {
     value.size = aValue;
   } else if (aAttrib == Ci.nsMsgSearchAttrib.AgeInDays) {
     value.age = aValue;
-  } else if (aAttrib == Ci.nsMsgSearchAttrib.Label) {
-    value.label = aValue;
   } else if (aAttrib == Ci.nsMsgSearchAttrib.JunkStatus) {
     value.junkStatus = aValue;
   } else if (aAttrib == Ci.nsMsgSearchAttrib.HasAttachmentStatus) {
